<?php

namespace FoodSearch\Dashboard\Customer;

use FoodSearch\Common_Functions;
use FoodSearch\user_orders as FoodSearch_Orders;

class Orders {
    
    public function __construct() {
        
        add_filter('foodsearch_customer_dash_orders_html', [$this, 'content'], 10, 4);
        
        add_action('rest_api_init', [$this, 'register_api'], 5);
    }
    
    public function register_api() {

        register_rest_route('wp/v1', 'customer-orders-load-more', array(
            'methods' => 'GET',
            'callback' => [$this, 'load_more_orders_list'],
           'permission_callback' =>  'admin_permissions_check',
        ));   
        register_rest_route('wp/v1', 'customer-order-detail-html', array(
            'methods' => 'POST',
            'callback' => array($this, 'get_customer_orderdetail'),
            'permission_callback' => 'admin_permissions_check',
        ));    
    }
    public function content($html, $menu_data, $section_key, $element_key) {
        
        global $foodsearch_user_orders_obj;
        
        wp_enqueue_style('jquery-datetimepicker');
        wp_enqueue_script('jquery-datetimepicker');
        
        $element_data = $menu_data['sections'][$section_key]['elements'][$element_key];
        $element_label = isset($element_data['label']) ? $element_data['label'] : '';
        if ($element_label == '') {
            $element_label = esc_html__('my orders', 'wp-foodsearch');
        }
        
        $user_id = get_current_user_id();
        
        $order_statuses = FoodSearch_Orders::get_order_statuses();
        
        //
        $per_page = get_option( 'posts_per_page' );
        $total_orders = $foodsearch_user_orders_obj->get_customer_orders_total_count($user_id, $_GET);
        $orders_list = $foodsearch_user_orders_obj->get_customer_filtered_orders($user_id, $_GET);

        ob_start();
        ?>
        <div class="fds-section-title-wrap fds-restaurant-orders-page">
            <?php
            if ($element_label != '') {
                ?>
                <h2 class="fds-heading-title"><?php esc_html_e('my orders', 'wp-foodsearch'); ?></h2>
                <?php
            }
            $get_tab = get_query_var('tab');

            $get_keyword = isset($_GET['filter_orders_keyword']) ? foodsearch_esc_html($_GET['filter_orders_keyword']) : '';
            $get_order_type = isset($_GET['filter_orders_type']) ? foodsearch_esc_html($_GET['filter_orders_type']) : '';
            $get_order_status = isset($_GET['filter_orders_status']) ? foodsearch_esc_html($_GET['filter_orders_status']) : '';
            $get_order_date = isset($_GET['filter_orders_date']) ? foodsearch_esc_html($_GET['filter_orders_date']) : '';
            ?>
            <div class="fds-order-filters">
                <form class="restaurant-filter-orders-form" method="get" autocomplete="off">
                    <span class="fds-dashboard-inner-top-filter"><?php esc_html_e('filter by', 'wp-foodsearch'); ?>:</span>
                    <div class="fds-form-field">
                        <div class="fds-select-field">
                            <select class="fds-select-dropdown" name="filter_orders_type" data-placeholder="<?php esc_html_e('order type', 'wp-foodsearch'); ?>">
                                <option value=""><?php esc_html_e('order type', 'wp-foodsearch'); ?></option>
                                <option value="delivery"<?php echo ($get_order_type == 'delivery' ? ' selected' : '') ?>><?php esc_html_e('delivery', 'wp-foodsearch'); ?></option>
                                <option value="take_away"<?php echo ($get_order_type == 'take_away' ? ' selected' : '') ?>><?php esc_html_e('take away', 'wp-foodsearch'); ?></option>
                            </select>
                        </div>
                    </div>
                    <div class="fds-form-field">
                        <div class="fds-select-field">
                            <select class="fds-select-dropdown" name="filter_orders_status" data-placeholder="<?php esc_html_e('order status', 'wp-foodsearch'); ?>">
                                <option value=""><?php esc_html_e('order status', 'wp-foodsearch'); ?></option>
                                <?php
                                foreach ($order_statuses as $status_key => $status_label) {
                                    if ($status_key == 'trash' || $status_key == 'on-hold' || $status_key == 'refunded' || $status_key == 'failed') {
                                        continue;
                                    }
                                    ?>
                                    <option value="<?php echo ($status_key) ?>"<?php echo ($get_order_status == $status_key ? ' selected' : '') ?>><?php echo ($status_label) ?></option>
                                    <?php
                                }
                                ?>
                            </select>
                        </div>
                    </div>
                    <div class="fds-form-field">
                        <input type="text" name="filter_orders_date" class="fds-input-style fds-filter-orders-date" value="<?php echo ($get_order_date) ?>" placeholder="<?php esc_html_e('order date', 'wp-foodsearch'); ?>">
                    </div>
                    <div class="fds-form-field">
                        <div class="fds-search-field">
                            <input type="hidden" name="tab" value="<?php echo ($get_tab) ?>">
                            <input type="text" name="filter_orders_keyword" class="fds-input-style" value="<?php echo ($get_keyword) ?>" placeholder="<?php esc_html_e('order id/restaurant', 'wp-foodsearch'); ?>">
                            <input type="submit" value="">
                            <i class="fds-icon fds-search"></i>
                        </div>
                    </div>
                </form>
                <i class="fds-dashboard-inner-top-money fds-icon fds-shopping-cart"></i>
            </div>
            <?php
            //
            add_action('wp_footer', function() {
                ?>
                <script>
                    jQuery(document).ready(function () {
                        jQuery('.fds-filter-orders-date').datetimepicker({
                            format: 'd-m-Y',
                            timepicker: false,
                            maxDate: '<?php echo current_time('d-m-Y') ?>'
                        });
                    });
                </script>
                <?php
            }, 99);
            ?>
        </div>
        <?php
        if (!empty($orders_list)) {
            ?>
            <div class="fds-myorder-listing">
                <div class="fds-myorder-listing-thead">
                    <div class="fds-myorder-listing-cell"><?php esc_html_e('restaurant info', 'wp-foodsearch'); ?></div>
                    <div class="fds-myorder-listing-cell"><?php esc_html_e('date/time', 'wp-foodsearch'); ?></div>
                    <div class="fds-myorder-listing-cell"><?php esc_html_e('status', 'wp-foodsearch'); ?></div>
                    <div class="fds-myorder-listing-cell"><?php esc_html_e('price', 'wp-foodsearch'); ?></div>
                    <div class="fds-myorder-listing-cell"><?php esc_html_e('detail', 'wp-foodsearch'); ?></div>
                </div>
                <div id="fds-user-orders-mainlist" class="fds-myorder-listing-inner">
                    <?php
                    foreach ($orders_list as $order_result) {
                        $order_id = $order_result['order_id'];

                        $this->order_itm_detail($order_id, $order_result, $user_id);
                    }
                    ?>
                </div>
            </div>
            <?php
            if ($total_orders > $per_page) {
                $total_pages = ceil($total_orders / $per_page);
                ?>
                <div id="fds-customer-orders-morebtn" class="fds-lodmore-btnsec">
                    <div class="fds-btn fds-medium-btn">
                        <a href="#" class="fds-lodmore-btn fds-has-bg fds-link" data-nid="<?php echo ($user_id) ?>" data-tpages="<?php echo($total_pages) ?>" data-gtopage="2"><?php esc_html_e('load more', 'wp-foodsearch') ?></a>
                    </div>
                </div>
                <?php
            }
            echo apply_filters('foodsearch_customer_dash_orders_list_after', '');
            add_action('wp_footer', function() {
                ?>
                <div id="fds-orderdet-mpopup" class="fds-modal-popup fds-popup-hide fds-orderdet-modal">
                    <div class="fds-modal-container">
                        <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                        <div class="fds-modal-inner-area">
                            <div class="fds-modal-content-area">
                                <div class="fds-dynm-modal-content">
                                    <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <?php
            }, 20);
        } else {
            ?>
            <div class="foodsearch-noitm-found">
                <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                <p><?php esc_html_e('no record found.', 'wp-foodsearch') ?></p>
            </div>
            <?php
        }
        $html = ob_get_clean();
        
        return $html;
    }
    public function get_customer_orderdetail($post_data) {
        
        global $table_prefix, $wpdb, $foodsearch_user_orders_obj, $foodsearch_plugin_settings;

        $user_id = $post_data['t_id'];
        $order_id = $post_data['n_id'];
        
        $table_name = $table_prefix . 'fds_orders';
        $order_result = $wpdb->get_row("SELECT * FROM $table_name WHERE order_id=$order_id", 'ARRAY_A');
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
        $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');
        $billing_email = FoodSearch_Orders::order_meta_value($order_meta, 'billing_email');
        $billing_phone = FoodSearch_Orders::order_meta_value($order_meta, 'billing_phone');
        $billing_address = FoodSearch_Orders::order_meta_value($order_meta, 'billing_address');

        $customer_name = '';
        if ($first_name != '') {
            $customer_name .= $first_name;
            if ($last_name != '') {
                $customer_name .= ' ' . $last_name;
            }
        }

        $order_status = $order_result['status'];
        
        $status_list = FoodSearch_Orders::get_order_statuses();
        
        $order_status_label = $foodsearch_user_orders_obj->get_order_status_tclr($order_status);
        
        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));
        $create_time_formate = date_i18n(get_option('time_format'), strtotime($create_date));

        ob_start();
        ?>
        <div class="fds-booking-detail-title">
            <h2 class="fds-heading-title"><?php esc_html_e('order detail', 'wp-foodsearch'); ?></h2>
            <span><?php printf(esc_html__('status: %s', 'wp-foodsearch'), $order_status_label); ?></span>
        </div>
        
        <div class="fds-plugin-modal-box-inner">
            <?php
            $order_items = $foodsearch_user_orders_obj->get_order_items($order_id, 'menu_items');
            if (!empty($order_items)) {

                $order_subtotal = $order_result['total_sales'];
                $order_net_total = $order_result['net_total'];
                ?>
                <div id="fds-order-items-list" class="orderdet-items-wrap">
                    <div class="orderdet-items-inside">
                        <div class="fds-table-items-wrapper">
                            <ul class="fds-table-item-row item-row-heder fds-options-wrap">
                                <li class="table-item-heditm itm-name fds-list-item"><?php esc_html_e('item', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-cost fds-list-item"><?php esc_html_e('cost', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-qty fds-list-item"><?php esc_html_e('qty', 'wp-foodsearch'); ?></li>
                                <li class="table-item-heditm itm-totl fds-list-item"><?php esc_html_e('total', 'wp-foodsearch'); ?></li>
                            </ul>
                            <?php
                            $items_counter = 1;
                            $total_order_items = count($order_items);
                            $menu_itms_open = false;
                            foreach ($order_items as $order_item) {
                                $order_item_id = $order_item['order_item_id'];
                                $order_item_name = $order_item['order_item_name'];
                                $order_item_type = $order_item['order_item_type'];
                                if ($order_item_type == 'menu_item' || $order_item_type == 'menu_item_extra') {
                                    $order_item_meta = $foodsearch_user_orders_obj->get_order_item_meta($order_item_id);
                                    $item_menu_id = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'menu_id');
                                    $item_qty = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'qty');
                                    $item_subtotal = $foodsearch_user_orders_obj->order_item_meta_value($order_item_meta, 'subtotal');

                                    $table_name = $table_prefix . 'menu_items';
                                    $menu_itmsql = "SELECT * FROM $table_name WHERE id=$item_menu_id";
                                    $menu_itm_obj = $wpdb->get_row($menu_itmsql);

                                    $image_src = '';
                                    $image_id = $menu_itm_obj->attachment_id;
                                    if ($image_id > 0) {
                                        $image_thumb = wp_get_attachment_image_src($image_id);
                                        $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                    }
                                    $menu_itm_label = $menu_itm_obj->name;

                                    $item_alltotal = $item_subtotal * $item_qty;
                                    
                                    if ($items_counter > 1) {
                                        if ($order_item_type == 'menu_item_extra' && $menu_itms_open === false) {
                                            echo '<div class="fds-table-list-items active-list-itms items-con-' . $rand_num . '">';
                                            $menu_itms_open = true;
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === false) {
                                            $rand_num = rand(1000000, 9999999);
                                            echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        } else if ($order_item_type == 'menu_item' && $menu_itms_open === true) {
                                            $rand_num = rand(1000000, 9999999);
                                            $menu_itms_open = false;
                                            echo '</div><div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                        }
                                    } else {
                                        $rand_num = rand(1000000, 9999999);
                                        echo '<div class="fds-item-table-list fds-to-list-itms" data-id="' . $rand_num . '">';
                                    }
                                    ?>
                                    <ul class="fds-order-item-row fds-options-wrap">
                                        <li class="table-item-cell itm-name fds-list-item">
                                            <img src="<?php echo ($image_src) ?>" class="order-itm-thumbnail" alt="">
                                            <span class="order-name"><?php echo ($menu_itm_label) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-cost fds-list-item">
                                            <span class="order-itm-amount"><?php echo (Common_Functions::get_formatted_price($item_subtotal)) ?></span>
                                        </li>
                                        <li class="table-item-cell itm-qty fds-list-item">
                                            <small class="times">x</small> <?php echo ($item_qty) ?>
                                        </li>
                                        <li class="table-item-cell itm-totl fds-list-item">
                                            <span class="order-itm-total"><?php echo (Common_Functions::get_formatted_price($item_alltotal)) ?></span>
                                        </li>
                                    </ul>
                                    <?php
                                    if ($items_counter > 1) {
                                        if ($items_counter == $total_order_items && $menu_itms_open === true) {
                                            echo '</div>';
                                        }
                                        if ($order_item_type == 'menu_item') {
                                            echo '</div>';
                                        }
                                    } else {
                                        echo '</div>';
                                    }
                                    $items_counter++;
                                }
                            }
                            ?>
                        </div>
                        <div class="fds-order-totals-items">
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('items subtotal:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_subtotal)) ?></span>
                                </li>
                            </ul>
                            <?php
                            $delivery_fee = isset($order_result['shipping_total']) ? $order_result['shipping_total'] : '';
                            if ($delivery_fee > 0) {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('delivery charges:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($delivery_fee)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            
                            $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
                            
                            $order_tax_amount = isset($order_result['tax_total']) ? $order_result['tax_total'] : '';
                            
                            $vat_amount = 0;
                            if ($order_tax_amount > 0) {
                                $vat_amount = $order_tax_amount;
                            }
                            if ($vat_amount > 0 || $order_vat_switch == 'on') {
                                ?>
                                <ul class="fds-total-itmscon fds-options-wrap fds-list-item">
                                    <li class="ordrtotl-label fds-list-item"><?php esc_html_e('vat:', 'wp-foodsearch'); ?></li>
                                    <li class="fds-list-item">
                                        <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($vat_amount)) ?></span>
                                    </li>
                                </ul>
                                <?php
                            }
                            ?>
                            <ul class="fds-total-itmscon fds-options-wrap">
                                <li class="ordrtotl-label fds-list-item"><?php esc_html_e('order total:', 'wp-foodsearch'); ?></li>
                                <li class="fds-list-item">
                                    <span class="ordrtotl-amount"><?php echo (Common_Functions::get_formatted_price($order_net_total)) ?></span>
                                </li>
                            </ul>
                        </div>
                    </div>
                </div>
                <?php
            }
            ?>
        </div>
        <?php
        $html = ob_get_clean();
        
        wp_send_json(array('html' => $html, 'msg' => '', 'error' => '0'));
    }
    public function order_itm_detail($order_id, $order_result, $user_id) {
        
        global $foodsearch_user_orders_obj;

        $order_id = $order_result['order_id'];
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');

        $billing_address = FoodSearch_Orders::order_meta_value($order_meta, 'billing_address');

        $restaurant_user_id = Common_Functions::restaurant_user_id($restaurant_id);

        $logo_url = foodsearch_restaurant_logo_url($restaurant_user_id, $restaurant_id);
        $order_status = $order_result['status'];

        $status_label = $foodsearch_user_orders_obj->get_order_status_tclr($order_status);
        $status_color = $foodsearch_user_orders_obj->get_order_status_tclr($order_status, 'color');

        $create_date = $order_result['date_created'];
        $create_date_formate = date_i18n(get_option('date_format'), strtotime($create_date));

        $order_net_total = $order_result['net_total'];
        ?>
        <div class="fds-myorder-listing-row">
            <div class="fds-myorder-listing-cell">
                <div class="fds-order-inner">
                    <div class="fds-order-thumb">
                        <a href="<?php echo get_permalink($restaurant_id) ?>" class="fds-myorder-listing-thumb fds-link"><img src="<?php echo ($logo_url) ?>" alt=""></a>
                    </div>
                    <div class="fds-order-content">
                        <a class="fds-myorder-listing-title fds-link" href="<?php echo get_permalink($restaurant_id) ?>"><?php echo get_the_title($restaurant_id) ?></a>
                        <?php
                        echo apply_filters('foodsearch_customer_dash_orders_list_after_title', '', $order_id, $order_meta);
                        $restaurant_cats = get_the_terms($restaurant_id, 'food_item_cat');
                        if (!empty($restaurant_cats)) {
                            ?>
                            <div class="fds-myorder-listing-tag">
                                <?php
                                foreach ($restaurant_cats as $tag) {
                                    ?>
                                    <a class="fds-link"><?php echo ($tag->name) ?>, </a>
                                    <?php
                                }
                                ?>
                            </div>
                            <?php
                        }
                        ?>
                        <span class="fds-myorder-listing-location"><i class="fds-icon fds-marker-line"></i> <?php echo foodsearch_esc_html($billing_address) ?></span>
                    </div>
                </div>
            </div>
            <div class="fds-myorder-listing-cell"><?php echo ($create_date_formate) ?></div>
            <div class="fds-myorder-listing-cell"><span class="fds-myorder-listing-status" style="background-color: <?php echo ($status_color) ?>;"><?php echo ($status_label) ?></span></div>
            <div class="fds-myorder-listing-cell"><span class="fds-myorder-listing-price"><?php echo (Common_Functions::get_formatted_price($order_net_total)) ?></span></div>
            <div class="fds-myorder-listing-cell"><a href="#" class="fds-myorder-listing-btn fds-get-userorderdet-popup fds-link" data-nid="<?php echo ($order_id) ?>" data-tid="<?php echo ($user_id) ?>"><i class="fds-icon fds-plus-circle-o"></i> <?php esc_html_e('order detail', 'wp-foodsearch'); ?></a></div>
        </div>
        <?php
    }
    
    public function load_more_orders_list() {
        $user_id = $_REQUEST['n_id'];
        $page_num = $_REQUEST['page_num'];
        
        global $foodsearch_user_orders_obj;

        $orders_list = $foodsearch_user_orders_obj->get_customer_filtered_orders($user_id, '', $page_num);
        
        ob_start();
        foreach ($orders_list as $order_result) {
            $order_id = $order_result['order_id'];

            $this->order_itm_detail($order_id, $order_result, $user_id);
        }
        $html = ob_get_clean();
        
        wp_send_json(array('error' => '0', 'html' => $html));
    }

}

new Orders;
