<?php

namespace FoodSearch\Dashboard;
use FoodSearch\Dashboard\Common_Functions;
use FoodSearch\Dashboard\Restaurant\Choice_Groups;

class API_Hooks {
    
    public function __construct() {
        add_action('rest_api_init', array($this, 'register_api'));
    }
    
    public function register_api() {
        register_rest_route('wp/v1', 'foodsearch-choose-user-type', array(
            'methods' => 'POST',
            'callback' => array($this, 'choose_user_type'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'foodsearch-save-dashboard-settings', array(
            'methods' => 'POST',
            'callback' => array($this, 'saving_dash_settings'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'foodsearch-user-change-password', array(
            'methods' => 'POST',
            'callback' => array($this, 'change_password'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'foodsearch-user-cover-upload', array(
            'methods' => 'POST',
            'callback' => array($this, 'upload_restaurant_cover'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'foodsearch-user-change-photo', array(
            'methods' => 'POST',
            'callback' => array($this, 'change_photo'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'foodsearch-remove-user-img', array(
            'methods' => 'POST',
            'callback' => array($this, 'remove_user_photo'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'adding-choice-group-html', array(
            'methods' => 'POST',
            'callback' => array($this, 'addin_choice_group'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'updatin-choice-group-html', array(
            'methods' => 'POST',
            'callback' => array($this, 'updatin_choice_group'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'remove-choice-group-byid', array(
            'methods' => 'POST',
            'callback' => array($this, 'remove_choice_group'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'dashboard-choice-groups-list', array(
            'methods' => 'POST',
            'callback' => array($this, 'choice_groups_list'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'restaurant-nutrition-popup-html', array(
            'methods' => 'POST',
            'callback' => array($this, 'nutrition_popup_html'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'add-nutrition-to-restaurant', array(
            'methods' => 'POST',
            'callback' => array($this, 'nutrition_add_in_list'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'remove-nutrition-item-byid', array(
            'methods' => 'POST',
            'callback' => array($this, 'remove_nutrition_item'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'get-restaurant-nutritions-list', array(
            'methods' => 'GET',
            'callback' => array($this, 'get_restaurant_nutritions'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'restaurant-order-detail-html', array(
            'methods' => 'POST',
            'callback' => array($this, 'get_restaurant_orderdet'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'restaurant-update-order-status', array(
            'methods' => 'POST',
            'callback' => array($this, 'restaurant_update_order_status'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', 'change-user-dashboard-type', array(
            'methods' => 'POST',
            'callback' => array($this, 'change_user_type'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', 'restaurant_possible_tags_list', array(
            'methods' => 'GET',
            'callback' => array($this, 'restaurant_tags_list'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', '/restaurant_list', array(
            'methods' => 'GET',
            'callback' => array($this, 'restaurant_list'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', '/restaurant_list_filter', array(
            'methods' => 'GET',
            'callback' => array($this, 'restaurant_list_filter'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        register_rest_route('wp/v1', '/restaurant_basis_detail', array(
            'methods' => 'GET',
            'callback' => array($this, 'restaurant_basis_detail'),
            'permission_callback' =>  'admin_permissions_check',
        ));
        
        register_rest_route('wp/v1', '/restaurant_menu_list', array(
            'methods' => 'GET',
            'callback' => array($this, 'restaurant_menu_list'),
            'permission_callback' =>  'admin_permissions_check',
        ));
    }
    
    public function restaurant_menu_list(){
    
        $common_functions = new Common_Functions;
        $restaurant_list = $common_functions->restaurant_menu_list($_GET);
        wp_send_json($restaurant_list);
    }
    public function restaurant_basis_detail(){
    
        $common_functions = new Common_Functions;
        $restaurant_list = $common_functions->restaurant_basis_detail($_GET);
        wp_send_json($restaurant_list);
    }
    public function restaurant_list_filter(){
    
        $common_functions = new Common_Functions;
        $restaurant_list = $common_functions->restaurant_list_filter($_GET);
        wp_send_json($restaurant_list);
    }
    public function restaurant_list(){
        $common_functions = new Common_Functions;
        $restaurant_list = $common_functions->restaurant_listing($_GET);
        wp_send_json($restaurant_list);
    }
    public function choose_user_type() {
        $user_id = get_current_user_id();
        
        if (metadata_exists('user', $user_id, 'foodsearch_user_type')) {
            wp_send_json(array('msg' => esc_html__('you have already choosed your account type.', 'wp-foodsearch'), 'error' => '1'));
        } else {
            $common_functions = new Common_Functions;
            $common_functions->save_user_type($_POST);
            wp_send_json(array('msg' => esc_html__('thank you for choosing account type.', 'wp-foodsearch'), 'error' => '0'));
        }
    }
    
    public function saving_dash_settings() {

        $common_functions = new Common_Functions;
        $common_functions->saving_dashboard_settings($_POST);
        wp_send_json(array('msg' => esc_html__('settings saved successfully.', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function change_password() {

        $common_functions = new Common_Functions;
        $common_functions->change_password($_POST);
        wp_send_json(array('msg' => esc_html__('your password is changed successfully.', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function upload_restaurant_cover() {

        $common_functions = new Common_Functions;
        $common_functions->upload_cover_image();
    }
    
    public function change_photo() {

        $common_functions = new Common_Functions;
        $common_functions->change_user_photo();
    }
    
    public function remove_user_photo() {
        $common_functions = new Common_Functions;
        $common_functions->remove_user_photo($_POST);
    }
    
    public function addin_choice_group() {
        $choice_groups = new Choice_Groups;
        $choice_groups->add_choice_group($_POST);
    }
    
    public function updatin_choice_group() {
        $choice_groups = new Choice_Groups;
        $choice_groups->update_choice_group($_POST);
    }
    
    public function remove_choice_group() {
        $choice_groups = new Choice_Groups;
        $choice_groups->remove_choice_group($_POST);
    }
    
    public function choice_groups_list() {
        
        $restaurant_id = $_POST['restaurant'];
        
        $choice_groups = new Choice_Groups;
        $choice_groups->choice_groups_list($restaurant_id);
    }
    
    public function nutrition_popup_html() {
        $common_functions = new Common_Functions;
        $common_functions->add_nutrition_popup($_POST);
    }
    
    public function nutrition_add_in_list() {
        $common_functions = new Common_Functions;
        $common_functions->save_nutrition_item($_POST);
    }
    
    public function remove_nutrition_item() {
        $common_functions = new Common_Functions;
        $common_functions->remove_nutrition_item($_POST);
    }
    
    public function get_restaurant_nutritions() {
        $common_functions = new Common_Functions;
        $common_functions->get_restaurant_nutritions($_REQUEST);
    }
    
    public function get_restaurant_orderdet() {
        $common_functions = new Common_Functions;
        $common_functions->get_restaurant_orderdetail($_POST);
    }
    
    public function get_customer_orderdet() {
        $common_functions = new Common_Functions;
        $common_functions->get_customer_orderdetail($_POST);
    }
    
    public function restaurant_update_order_status() {
        $common_functions = new Common_Functions;
        $common_functions->restaurant_update_order_status($_POST);
    }
    
    public function restaurant_tags_list() {
        $responsedata = array();
        $responsedata['status'] = 'success';
        $responsedata['results'] = array();
        
        global $table_prefix, $wpdb;

        $keyword = isset($_GET['search']) ? $_GET['search'] : '';

        $tags_query = "SELECT terms.term_id,terms.name FROM $wpdb->terms AS terms";
        $tags_query .= " LEFT JOIN $wpdb->term_taxonomy AS term_tax ON(terms.term_id = term_tax.term_id) ";

        $tags_query .= " WHERE term_tax.taxonomy=%s";
        if ($keyword != '') {
            $tags_query .= " AND terms.name LIKE '$keyword%'";
        }

        $tags_query .= " GROUP BY terms.term_id";
        $tags_query .= " ORDER BY terms.term_id DESC LIMIT 100";

        $tag_terms = $wpdb->get_results($wpdb->prepare($tags_query, 'restaurant_tag'), 'ARRAY_A');

        if (!empty($tag_terms)) {

            foreach ($tag_terms as $tag_term) {
                $tag_id = $tag_term['name'];
                $tag_title = $tag_term['name'];
                $responsedata['results'][] = array('id' => $tag_id, 'text' => $tag_title);
            }
        }

        wp_send_json($responsedata);
    }
    
    public function change_user_type() {
        global $wpdb;
        
        $user_id = $_POST['nid'];
        
        $user_obj = get_user_by('id', $user_id);
        
        $display_name = isset($user_obj->display_name) ? $user_obj->display_name : '';
        
        $selcted_type = $_POST['utype'];
        
        if ($selcted_type == 'restaurant') {
            update_user_meta($user_id, 'foodsearch_user_type', 'restaurant');
            $post_query = "SELECT COUNT(*) FROM $wpdb->posts AS posts WHERE post_type='restaurants' AND post_author={$user_id}";
            $post_count = $wpdb->get_var($post_query);
            if ($post_count == 0) {
                $restaurant_post = array(
                    'post_title' => wp_strip_all_tags($display_name),
                    'post_type' => 'restaurants',
                    'post_status' => 'publish',
                    'post_author' => $user_id,
                );
                wp_insert_post($restaurant_post);
            }
        } else {
            update_user_meta($user_id, 'foodsearch_user_type', 'customer');
            $post_query = "SELECT COUNT(*) FROM $wpdb->posts AS posts WHERE post_type='customers' AND post_author={$user_id}";
            $post_count = $wpdb->get_var($post_query);
            if ($post_count == 0) {
                $customer_post = array(
                    'post_title' => wp_strip_all_tags($display_name),
                    'post_type' => 'customers',
                    'post_status' => 'publish',
                    'post_author' => $user_id,
                );
                wp_insert_post($customer_post);
            }
        }
        
        $foodsearch_options = get_option('foodsearch_plugin_settings');
        $dash_page = isset($foodsearch_options['dashboard_settings']['dashboard_page']) ? $foodsearch_options['dashboard_settings']['dashboard_page'] : '';
        
        $dash_page_id = foodsearch__get_post_id($dash_page);
        if ($dash_page_id > 0) {
            $url = get_permalink($dash_page_id);
        } else {
            $url = home_url('/');
        }
        
        wp_send_json(array('error' => '0', 'msg' => esc_html__('type changed successfully.', 'wp-foodsearch'), 'url' => $url));
    }
    

}

new API_Hooks;
