<?php

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 */
class FoodSearch_Plugin {

    public static $unique_id;

    /**
     * The unique identifier of this plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $plugin_name The string used to uniquely identify this plugin.
     */
    protected $plugin_name;

    /**
     * The current version of the plugin.
     *
     * @since    1.0.0
     * @access   protected
     * @var      string $version The current version of the plugin.
     */
    public static $version;

    /**
     * Define the core functionality of the plugin.
     *
     * Set the plugin name and the plugin version that can be used throughout the plugin.
     * Load the dependencies, define the locale, and set tohe hooks fr the admin area and
     * the public-facing side of the site.
     *
     * @since    1.0.0
     */
    public function __construct() {

        self::$version = '1.0';

        self::$unique_id = uniqid();

        add_action('init', [$this, 'start_session'], 1);
        $this->includes();

        $this->load_post_types();
        add_action('wp_enqueue_scripts', array($this, 'front_select2_scripts'), 1);
        add_action('wp_enqueue_scripts', array($this, 'front_style_scripts'));
        add_action('wp_print_styles', array($this, 'front_style_start'), 999);
        add_action('admin_enqueue_scripts', array($this, 'admin_style_start'), 999);
        add_action('admin_enqueue_scripts', array($this, 'admin_style_scripts'));

        add_filter('single_template', array($this, 'custom_templates'));

        add_filter('add_menu_classes', array($this, 'show_pending_number'));

        add_action('body_class', array($this, 'body_class'));
        
        add_action('admin_menu', array($this, 'admin_menu'));

        add_filter('custom_menu_order', '__return_true');
        add_filter('menu_order', array($this, 'menu_order'), 9);
    }

    public function includes() {
        $foodsearch_plugin_settings = get_option('foodsearch_plugin_settings');
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/countries.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/currencies.php';
        
        // demo data
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'envato-setup/envato-setup.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'envato-setup/envato-setup-init.php';
            
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/common-functions.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/user-orders.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-email-settings.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-email.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/user-forms/shortcode.php';
        // single restaurant class
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-single-restaurant.php';

        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-user-geolocation.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-location-check.php';
        //locations
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-user-locations.php';
        //maps
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-google-maps.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-mapbox.php';

        // reviews
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-user-reviews.php';
        
        // user media
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-user-media.php';

        // templates
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/templates.php';
        
        // block templates
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/block-templates/block-utils.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/block-templates/block-functions.php';

        //icon picker
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'modules/icon-picker/icon-picker.php';

        include plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/class-menu-templates.php';

        require plugin_dir_path(dirname(dirname(__FILE__))) . 'helper/classes/class-form-fields.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'helper/common-functions.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'helper/classes/api-hooks.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'admin/settings/plugin-settings.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'admin/dashboard-builder/dashboard-builder.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'admin/admin-pages.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'dashboard/dashboard.php';
        require plugin_dir_path(dirname(dirname(__FILE__))) . 'dashboard/cart.php';
        
       if(isset($foodsearch_plugin_settings['payment_settings']['wc_cart_active']) && $foodsearch_plugin_settings['payment_settings']['wc_cart_active']=='on' &&  class_exists( 'WooCommerce' )){
            require plugin_dir_path(dirname(dirname(__FILE__))) . 'includes/classes/woocommerce/cart.php';
       }
    }
    
    public function admin_menu() {
        global $foodsearch_settings_main_page;
        add_menu_page(esc_html__('FoodSearch Settings', 'wp-foodsearch'), esc_html__('FoodSearch', 'wp-foodsearch'), 'manage_options', 'foodsearch-plugin-settings', array($foodsearch_settings_main_page, 'settings_page'));
    }

    public function menu_order($menu_order) {

        $foodsearch_posts_arr = array(
            'edit.php?post_type=restaurants',
            'edit.php?post_type=customers',
            'foodsearch-plugin-settings',
        );

        $foodsearch_posts_arr = apply_filters('foodsearch_main_wp_menu_list', $foodsearch_posts_arr);

        $foodsearch_menu_order = array();

        $cus_menu_order = array();

        foreach ($menu_order as $index => $item) {

            if ('edit.php?post_type=restaurants' === $item) {
                $cus_menu_order[] = $item;
                $cus_menu_order[] = 'edit.php?post_type=customers';
                $cus_menu_order[] = 'foodsearch-plugin-settings';
                //
                $cus_menu_order = apply_filters('foodsearch_main_wp_menu_order', $cus_menu_order);
                $foodsearch_menu_order = array_merge($foodsearch_menu_order, $cus_menu_order);
                //
            } else if (!in_array($item, $foodsearch_posts_arr, true)) {
                $foodsearch_menu_order[] = $item;
            }
        }

        return $foodsearch_menu_order;
    }

    public function body_class($classes) {

        $classes[] = 'wp-foodsearch foodsearch-default';
        if (is_user_logged_in()) {
            $classes[] = 'foodsearch-user-islogged';
        } else {
            $classes[] = 'foodsearch-user-notlogged';
        }

        return $classes;
    }

    public static function get_uniquid() {
        return self::$unique_id;
    }

    /**
     * The name of the plugin used to uniquely identify it within the context of
     * WordPress and to define internationalization functionality.
     *
     * @since     1.0.0
     * @return    string    The name of the plugin.
     */
    public function get_plugin_name() {
        return $this->plugin_name;
    }

    /**
     * Retrieve the version number of the plugin.
     *
     * @since     1.0.0
     * @return    string    The version number of the plugin.
     */
    public static function get_version() {
        return self::$version;
    }

    public function load_post_types() {

        /**
         * The class responsible for loading post types
         * of the plugin.
         */
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'post-types/restaurants.php';
        include plugin_dir_path(dirname(dirname(__FILE__))) . 'post-types/customers.php';
    }

    public function front_select2_scripts() {

       
        wp_enqueue_style('select2', foodsearch_plugin_get_url('assets/scss/build/css/select2.min.css'), array(), SELF::get_version());

        wp_enqueue_script('select2', foodsearch_plugin_get_url('assets/js/select2.min.js'), array('jquery'), SELF::get_version(), true);
    }

    public function front_style_start() {

        wp_enqueue_style('foodsearch-components', foodsearch_plugin_get_url('assets/scss/build/css/component.css'), array(), SELF::get_version());
        wp_enqueue_style('dashboard-common', foodsearch_plugin_get_url('assets/scss/build/css/dashboard-common.css'), array(), SELF::get_version());
        wp_register_style('jquery-datetimepicker', foodsearch_plugin_get_url('assets/scss/build/css/jquery.datetimepicker.css', __FILE__), false);
        wp_register_style('foodsearch-croppie', foodsearch_plugin_get_url('assets/scss/build/css/croppie.css', __FILE__), array(), SELF::get_version());
        wp_enqueue_style('common-style', foodsearch_plugin_get_url('assets/scss/build/css/common.css', __FILE__), false);
        wp_enqueue_style('typography', foodsearch_plugin_get_url('assets/scss/build/css/typography.css', __FILE__), false);
        wp_enqueue_style('listing-detail', foodsearch_plugin_get_url('assets/scss/build/css/listing-detail.css', __FILE__), false);
        wp_enqueue_style('listing-list', foodsearch_plugin_get_url('assets/scss/build/css/listing-list.css', __FILE__), false);
        wp_enqueue_style('plugin-packages', foodsearch_plugin_get_url('assets/scss/build/css/plugin-packages.css', __FILE__), false);
        wp_enqueue_style('restaurant-dashboard', foodsearch_plugin_get_url('assets/scss/build/css/resturant-dashboard.css', __FILE__), false);
        wp_enqueue_style('user-dashboard', foodsearch_plugin_get_url('assets/scss/build/css/user-dashboard.css', __FILE__), false);
        wp_enqueue_style('options-popup-style', foodsearch_plugin_get_url('assets/scss/build/css/options-popup-style.css', __FILE__), false);
        if (is_rtl()) {
            wp_enqueue_style('foodsearch-rtl', foodsearch_plugin_get_url('assets/scss/build/css/foodsearch-rtl.css', __FILE__), false);
        }
    }

    public function front_style_scripts() {

        wp_register_script('foodsearch-croppie', foodsearch_plugin_get_url('assets/js/croppie.min.js'), array('jquery'), SELF::get_version(), true);
        
        wp_register_script('foodsearch-addthis', 'https://s7.addthis.com/js/250/addthis_widget.js', array('jquery'), SELF::get_version(), true);
        
        wp_enqueue_script('foodsearch-common-script', foodsearch_plugin_get_url('assets/js/foodsearch-common.js'), array('jquery', 'password-strength-meter'), SELF::get_version(), true);
        $accptable_pass_strength = array('strong', 'medium', 'weak');
        $script_str_arr = array(
            'site_url' => esc_url_raw( rest_url() ),
            'ajax_url' => esc_url_raw(home_url('/?fds_form=1')),
            'wpnonce' => wp_create_nonce('wp_rest'),            
            'adminCheck' => (is_admin()?'true':'false'),
            'form_submitting_msg' => esc_html__('submitting...', 'wp-foodsearch'),
            'pass_length_short' => esc_html__('too short password', 'wp-foodsearch'),
            'pass_length_med' => esc_html__('bad password', 'wp-foodsearch'),
            'pass_length_good' => esc_html__('good password', 'wp-foodsearch'),
            'pass_length_strng' => esc_html__('strong password', 'wp-foodsearch'),
            'acptable_pass_strnth' => json_encode($accptable_pass_strength),
            'no_search_menu_found' => esc_html__('no food item found.', 'wp-foodsearch'),
            'plugin_url' => foodsearch_plugin_get_url(),
        );
        wp_localize_script('foodsearch-common-script', 'foodsearch_common_vars', $script_str_arr);

        wp_register_script('foodsearch-dashboard-common', foodsearch_plugin_get_url('assets/js/dashboard-common.js'), array(), SELF::get_version(), true);
        $script_str_arr = array(
            'site_url' => esc_url_raw( rest_url() ),
            'delete_conf_msg' => esc_html__('do you realy want to delete it?', 'wp-foodsearch'),
            'becom_rest' => esc_html__('do you realy want to become a restaurant?', 'wp-foodsearch'),
            'becom_cust' => esc_html__('do you realy want to become a customer?', 'wp-foodsearch'),
            'nonce' => wp_create_nonce('foodsearch-userdash-nonce'),
            'wpnonce' => wp_create_nonce('wp_rest'),
            'adminCheck' => (is_admin()?'true':'false'),
        );
        wp_localize_script('foodsearch-dashboard-common', 'dashboard_common_vars', $script_str_arr);
        
        wp_register_script('foodsearch-restaurant-single', foodsearch_plugin_get_url('assets/js/restaurant-single.js'), array(), SELF::get_version(), true);
        wp_register_script('foodsearch-restaurant-cart', foodsearch_plugin_get_url('assets/js/restaurant-cart.js'), array(), SELF::get_version(), true);
    }

    public function admin_style_start() {

        wp_enqueue_style('monolith-pickr', foodsearch_plugin_get_url('assets/scss/build/css/monolith.min.css'), array(), SELF::get_version());
        wp_enqueue_style('foodsearch-components', foodsearch_plugin_get_url('assets/scss/build/css/component.css'), array(), SELF::get_version());
        wp_enqueue_style('dashboard-common', foodsearch_plugin_get_url('assets/scss/build/css/dashboard-common.css'), array(), SELF::get_version());
        wp_enqueue_style('foodsearch-admin', foodsearch_plugin_get_url('assets/admin/css/build/css/admin-common.css'), array(), SELF::get_version());
        wp_enqueue_style('select2', foodsearch_plugin_get_url('assets/scss/build/css/select2.min.css'), array(), SELF::get_version());
        wp_enqueue_style('dashbaord_style', foodsearch_plugin_get_url('assets/scss/build/css/dashboard-style.css'), array(), SELF::get_version(), 'all');

        wp_enqueue_style('admin_listing_style', foodsearch_plugin_get_url('assets/scss/build/css/listing-list.css'), array(), SELF::get_version());
        wp_enqueue_style('admin_listing_detail_style', foodsearch_plugin_get_url('assets/scss/build/css/listing-detail.css'), array(), SELF::get_version());
    }

    public function admin_style_scripts() {
        if (!did_action('wp_enqueue_media')) {
            wp_enqueue_media();
        }
        wp_enqueue_style('jquery-ui');
        wp_enqueue_script('foodsearch_admin_script', foodsearch_plugin_get_url('assets/admin/js/foodsearch-common.js'), array('jquery'), SELF::get_version(), true);
        $script_str_arr = array(
            'site_url' => esc_url_raw( rest_url() ),
            'ajax_url' => esc_url_raw(home_url('/?fds_settings=1')),
            'wpnonce' => wp_create_nonce('wp_rest'),
            'adminCheck' => (is_admin()?'true':'false'),
            'seting_change_msg' => esc_html__('settings have changed, you should save them!', 'wp-foodsearch'),
            'reset_all_setings' => esc_html__('do you realy want to reset all settings? it will override all of your custom settings.', 'wp-foodsearch'),
            'reset_sec_setings' => esc_html__('do you realy want to reset this section settings? it will override your custom settings for this section.', 'wp-foodsearch'),
        );
        wp_localize_script('foodsearch_admin_script', 'fds_admin_script_vars', $script_str_arr);

        wp_enqueue_script('jquery-ui');
        wp_enqueue_script('select2', foodsearch_plugin_get_url('assets/js/select2.min.js'), array('jquery'), SELF::get_version(), true);
        wp_register_script('pickr', foodsearch_plugin_get_url('assets/script/pickr.es5.min.js'), array('jquery'), SELF::get_version(), true);
    }

    public function custom_templates($single) {
        global $post;
        //echo $post->post_type ;
        /* Checks for single template by post type */
        if ($post->post_type == 'restaurants' && apply_filters('foodsearch_load_custom_restaurant_single', true)) {

            if (file_exists(foodsearch_plugin_get_path('templates/restaurant/restaurant-single.php'))) {
                return foodsearch_plugin_get_path('templates/restaurant/restaurant-single.php');
            }
        }
        return $single;
    }

    function show_pending_number($menu) {
        $type = "restaurants";
        $status = "pending";
        $pending_count = 0;

        $cachetime = 600;
        $transient = 'wp_foodsearch_admin_menu_counts';

        $check_transient = get_transient($transient);
        if (!empty($check_transient)) {
            $pending_count = get_option('foodsearch_pending_restaurant_count');
        } else {
            $num_posts = wp_count_posts($type, 'readable');
            if (!empty($num_posts->$status)) {
                $pending_count = $num_posts->$status;
            }
            update_option('foodsearch_pending_restaurant_count', $pending_count);
            set_transient($transient, true, $cachetime);
        }
        // build string to match in $menu array
        if ($type == 'post') {
            $menu_str = 'edit.php';
            // support custom post types
        } else {
            $menu_str = 'edit.php?post_type=' . $type;
        }

        // loop through $menu items, find match, add indicator
        foreach ($menu as $menu_key => $menu_data) {
            if ($menu_str != $menu_data[2])
                continue;
            $menu[$menu_key][0] .= " <span class='update-plugins count-$pending_count'><span class='plugin-count'>" . number_format_i18n($pending_count) . '</span></span>';
        }
        return $menu;
    }
    function start_session() {       
       // if (session_id() == '' && session_status() === PHP_SESSION_NONE && session_status() !== PHP_SESSION_ACTIVE) {
            if(!headers_sent() && session_id() == ''){
            session_start();
        } 
    }

}
