<?php

namespace FoodSearch;

class Emails {

    public static $codes = array(
        array(
            'var' => '{SITE_NAME}',
            'display_text' => 'Site Name',
            'function_callback' => array(__CLASS__, 'get_site_name'),
        ),
        array(
            'var' => '{ADMIN_EMAIL}',
            'display_text' => 'Admin Email',
            'function_callback' => array(__CLASS__, 'get_admin_email'),
        ),
        array(
            'var' => '{SITE_URL}',
            'display_text' => 'SITE URL',
            'function_callback' => array(__CLASS__, 'get_site_url'),
        ),
    );
    
    public function __construct() {

        $this->includes();
    }

    public function includes() {
        // email classes
        
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/forgot-password.php';
        
        //
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/new-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/complete-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/processing-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/pending-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/on-hold-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/failed-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/cancelled-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/restaurant/refund-order.php';
        
        //
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/new-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/complete-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/processing-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/pending-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/on-hold-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/failed-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/cancelled-order.php';
        include plugin_dir_path(dirname(__FILE__)) . 'classes/emails/customer/refund-order.php';
    }

    public static function get_site_name() {
        return get_bloginfo('name');
    }

    public static function get_admin_email() {
        global $foodsearch_plugin_settings;
        
        $admin_email = isset($foodsearch_plugin_settings['email_settings']['email_from_address']) ? $foodsearch_plugin_settings['email_settings']['email_from_address'] : '';
        if ($admin_email == '') {
            $admin_email = get_bloginfo('admin_email');
        }
        return sanitize_email($admin_email);
    }

    public static function get_site_url() {
        return get_bloginfo('url');
    }

    public function replace_variables($template, $variables) {
        // Add general variables to the list
        $variables = array_merge(self::$codes, $variables);
        foreach ($variables as $key => $variable) {
            $callback_exists = false;

            if (isset($variable['direct_value'])) {
                $value = $variable['direct_value'];
                if (false != $value && !is_array($value)) {
                    $template = str_replace($variable['var'], $value, $template);
                }
            } else {
                // Check if function/method exists.
                if (is_array($variable['function_callback'])) { // If it is a method of a class.
                    $callback_exists = method_exists($variable['function_callback'][0], $variable['function_callback'][1]);
                } else { // If it is a function.
                    $callback_exists = function_exists($variable['function_callback']);
                }
                // Substitute values in place of tags if callback exists.
                if (true == $callback_exists) {
                    // Make a call to callback to get value.                
                    $value = call_user_func($variable['function_callback']);
                    // If we have some value to substitute then use that.
                    if (false != $value) {
                        $template = str_replace($variable['var'], $value, $template);
                    }
                }
            }
        }
        return $template;
    }

    public function get_from_name($from_name = '') {
        global $foodsearch_plugin_settings;
        
        $from_name = isset($foodsearch_plugin_settings['email_settings']['email_from_name']) ? $foodsearch_plugin_settings['email_settings']['email_from_name'] : '';
        if ($from_name == '') {
            $from_name = get_bloginfo('name');
        }
        return wp_specialchars_decode(esc_html($from_name), ENT_QUOTES);
    }

    public function get_from_address($from_email = '') {
        global $foodsearch_plugin_settings;
        
        $from_email = isset($foodsearch_plugin_settings['email_settings']['email_from_address']) ? $foodsearch_plugin_settings['email_settings']['email_from_address'] : '';
        if ($from_email == '') {
            $from_email = get_bloginfo('admin_email');
        }
        return sanitize_email($from_email);
    }

    public function send($to, $subject, $message, $headers, $attachments, $email_obj) {
        add_filter('wp_mail_from', array($this, 'get_from_address'));
        add_filter('wp_mail_from_name', array($this, 'get_from_name'));
        add_filter('wp_mail_content_type', array($email_obj, 'get_content_type'));

        $message = $message;
        $mail_callback = apply_filters('foodsearch_mail_callback', 'wp_mail', $email_obj);
        $mail_callback_params = apply_filters('foodsearch_mail_callback_params', array($to, $subject, $message, $headers, $attachments), $email_obj);
        $return = $mail_callback(...$mail_callback_params);

        remove_filter('wp_mail_from', array($this, 'get_from_address'));
        remove_filter('wp_mail_from_name', array($this, 'get_from_name'));
        remove_filter('wp_mail_content_type', array($email_obj, 'get_content_type'));

        return $return;
    }

}

new Emails;