<?php

namespace FoodSearch;

use FoodSearch\Common_Functions;

class Single_Restaurant {

    public function __construct() {
        
        add_shortcode('fds_single_restaurant', array($this, 'single_restaurant_shortcode'));
    }
    
    public function html() {
        global $post, $foodsearch_plugin_settings, $foodsearch_common_functions;
        
        $restaurant_id = get_the_id();

        $user_id = get_current_user_id();

        $common_functions = $foodsearch_common_functions;

        $restaurant_user_id = Common_Functions::restaurant_user_id($restaurant_id);
        $restaurant_user_obj = get_user_by('id', $restaurant_user_id);

        $contact_num = get_post_meta($restaurant_id, 'foodsearch_contact_number', true);

        $restaurant_logo_url = foodsearch_restaurant_logo_url($restaurant_user_id, $restaurant_id);

        $restaurant_addrss = $common_functions->get_member_locs_address($restaurant_id);

        $customer_id = Common_Functions::user_customer_id($user_id);
        
        $detail_container = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container'] : '';
        $detail_container_width = isset($foodsearch_plugin_settings['restaurant_settings']['detail_container_width']) ? $foodsearch_plugin_settings['restaurant_settings']['detail_container_width'] : '';
        
        $social_sharing = isset($foodsearch_plugin_settings['restaurant_settings']['social_share']) ? $foodsearch_plugin_settings['restaurant_settings']['social_share'] : '';
        $facebook_share = isset($foodsearch_plugin_settings['restaurant_settings']['facebook_share']) ? $foodsearch_plugin_settings['restaurant_settings']['facebook_share'] : '';
        $twitter_share = isset($foodsearch_plugin_settings['restaurant_settings']['twitter_share']) ? $foodsearch_plugin_settings['restaurant_settings']['twitter_share'] : '';
        $linkedin_share = isset($foodsearch_plugin_settings['restaurant_settings']['linkedin_share']) ? $foodsearch_plugin_settings['restaurant_settings']['linkedin_share'] : '';
        $more_share_btn = isset($foodsearch_plugin_settings['restaurant_settings']['more_share']) ? $foodsearch_plugin_settings['restaurant_settings']['more_share'] : '';

        wp_enqueue_script('foodsearch-restaurant-single');
        wp_enqueue_script('foodsearch-restaurant-cart');
        
        if ($social_sharing == 'on') {
            wp_enqueue_script('foodsearch-addthis');
        }
        
        ob_start();
        ?>
        <div class="fds-restaurant-detail"<?php echo ($detail_container == 'on' && $detail_container_width > 0 ? ' style="width: ' . absint($detail_container_width) . 'px; margin:0 auto;"' : '') ?>>

            <!--// Search //-->
            <div class="fds-restaurant-listing-detail">
                <div class="fds-restaurant-listing-detail-inner">
                    <div class="fds-resturant-logo">
                        <a class="fds-restaurant-listing-detail-logo fds-link"><img src="<?php echo ($restaurant_logo_url) ?>" alt=""></a>
                        <div class="fds-resturant-content">
                            <h1 class="fds-heading-title"><?php the_title(); ?></h1>
                            <span class="fds-restaurant-listing-detail-loc"><i class="fds-icon fds-pin-fill"></i> <?php echo get_post_meta($restaurant_id, 'restaurant_address', true); ?></span>
                            <?php
                            if (isset($restaurant_addrss['address']) && $restaurant_addrss['address'] != '') {
                                ?>
                                <div class="fds-restaurant-detail-loc">
                                    <i class="fds-icon fds-marker-fill"></i> <span><?php echo ($restaurant_addrss['address']) ?></span>
                                </div>
                                <?php
                            }
                            ?>
                            <span class="fds-restaurant-listing-detail-links">
                                <?php
                                $tags = get_the_terms($post->ID, 'restaurant_tag');
                                $tagList = array();
                                if (!empty($tags)) :
                                    foreach ($tags as $tag) {
                                        $tagList[] = $tag->name;
                                    }

                                endif;
                                if (!empty($tagList) && count($tagList) > 0) {
                                    $tags_list_str = implode(', ', $tagList);
                                    printf(esc_html__('specialties: %s', 'wp-foodsearch'), $tags_list_str);
                                }
                                ?>
                            </span>
                            <div class="fds-restaurant-listing-detail-bottom">
                                <div class="fds-restaurant-listing-detail-btn fds-btn fds-medium-btn">
                                    <?php
                                    if (isset($restaurant_user_obj->user_email)) {
                                        ?>
                                        <a href="mailto:<?php echo ($restaurant_user_obj->user_email) ?>" class="fds-has-bg fds-link"><i class="fds-icon fds-envelope-line-1"></i> <?php esc_html_e('email', 'wp-foodsearch') ?></a>
                                        <?php
                                    }
                                    Common_Functions::restaurant_fav_btn_html($restaurant_id);
                                    ?>
                                </div>
                                <?php
                                if ($social_sharing == 'on') {
                                    ?>
                                    <div class="fds-restaurant-listing-detail-social">
                                        <span><?php esc_html_e('share:', 'wp-foodsearch') ?></span>
                                        <?php
                                        if ($facebook_share == 'on') {
                                            ?>
                                            <a href="#" class="fds-icon fds-facebook-f fds-link addthis_button_facebook"></a>
                                            <?php
                                        }
                                        if ($twitter_share == 'on') {
                                            ?>
                                            <a href="#" class="fds-icon fds-twitter-simple fds-link addthis_button_twitter"></a>
                                            <?php
                                        }
                                        if ($linkedin_share == 'on') {
                                            ?>
                                            <a href="#" class="fds-icon fds-linkedin-simple fds-link addthis_button_linkedin"></a>
                                            <?php
                                        }
                                        if ($more_share_btn == 'on') {
                                            ?>
                                            <a href="#" class="fds-icon fds-plus-simple fds-link addthis_button_compact"></a>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                }
                                ?>
                            </div>
                        </div>
                    </div>
                    <div class="fds-restaurant-listing-detail-sub">
                        <?php
                        $min_order = get_post_meta($restaurant_id, 'foodsearch_min_delivery_order', true);
                        if ($min_order != '') {
                            ?>
                            <small><?php printf(esc_html__('min. order: %s', 'wp-foodsearch'), Common_Functions::get_formatted_price($min_order)) ?></small>
                            <?php
                        }
                        echo apply_filters('foodsearch_restaurant_detail_top_after_min_order', '', $restaurant_id);

                        //
                        if ($contact_num != '') {
                            ?>
                            <span class="fds-restaurant-listing-detail-subloc"><i class="fds-icon fds-phone-circle-line"></i> <?php esc_html_e('tel:', 'wp-foodsearch') ?> <strong><a href="tel:<?php echo ($contact_num) ?>"><?php echo ($contact_num) ?></a></strong></span>
                            <?php
                        }
                        ?>
                        <span class="fds-restaurant-listing-detail-subloc"><i class="fds-icon fds-clock"></i>
                            <?php
                            $Today = strtolower(date('l'));
                            $currentTime = strtotime(date('H:i'));
                            $openToday = get_post_meta($restaurant_id, 'restaurant_' . $Today . '_status', true);
                            $openingtime = get_post_meta($restaurant_id, 'restaurant_' . $Today . '_opening_hour', true);
                            $closetime = get_post_meta($restaurant_id, 'restaurant_' . $Today . '_closing_hour', true);
                            if ($openToday == 1 && $currentTime >= strtotime($openingtime) && $currentTime <= strtotime($closetime)) {
                                echo esc_html__('open today', 'wp-foodsearch') . ' ' . foodsearch_getampmtime($openingtime) . ' - ' . foodsearch_getampmtime($closetime);
                            } else {
                                echo '<strong>' . esc_html__('now closed', 'wp-foodsearch') . '</strong>';
                            }
                            ?>
                        </span>
                    </div>
                </div>
            </div>
            <!--// Search //-->

            <div class="fds-main-content">

                <!--// Main Section //-->
                <div class="fds-main-section fds-typo-wrap">
                    <div class="fds-row">
                        <!--// Content Section //-->
                        <div class="fds-column-9">
                            <!--// Restaurant Listing Tab //-->
                            <div class="fds-restaurant-listing-tab">
                                <ul class="fds-restaurant-nav fds-options-wrap">
                                    <li class="fds-list-item"><a class="active fds-link" id="tab1" data-toggle="tab" href="#tabref1"><i class="fds-icon fds-menu-one"></i> <?php esc_html_e('menu', 'wp-foodsearch') ?></a></li>
                                    <?php
                                    echo apply_filters('foodsearch_restaurant_single_after_tab_1_itm', '', $restaurant_id);
                                    ?>
                                    <li class="fds-list-item"><a class="fds-link" id="tab3" data-toggle="tab" href="#tabref3"><i class="fds-icon fds-info"></i> <?php esc_html_e('info', 'wp-foodsearch') ?></a></li>
                                </ul>
                                <div class="fds-restaurant-tab-content">
                                    <div class="tab-pane active" id="tabref1" aria-labelledby="tab1">
                                        <?php
                                        if ($openToday == 1 && $currentTime >= strtotime($openingtime) && $currentTime <= strtotime($closetime)) {
                                            $id = $restaurant_id;

                                            $where = ' where restaurant_id =' . $id;
                                            global $table_prefix, $wpdb;
                                            $table_name = $table_prefix . 'menus';
                                            $sql = "SELECT * FROM $table_name $where";
                                            $results = $wpdb->get_results($sql, ARRAY_A);

                                            $responsedata = array('status' => 'error', 'results' => array());
                                            if (!empty($results)) {
                                                $responsedata['status'] = 'success';
                                                $responsedata['results'] = $results;
                                            }

                                            $categories = array();
                                            $menus = array();
                                            $menu = array();
                                            $menuitems = array('status' => 'error', 'msg' => 'Nothing Found', 'results' => array());
                                            foreach ($responsedata['results'] as $key => $postdata) {
                                                $res = array();
                                                $menus[$key] = $postdata;
                                                $menus[$key]['menu_opening_days'] = json_decode($postdata['menu_opening_days'], true);
                                                if (in_array($Today, $menus[$key]['menu_opening_days']) && $currentTime >= strtotime($menus[$key]['menu_start_time']) && $currentTime <= strtotime($menus[$key]['menu_end_time'])) {
                                                    $table_name = $table_prefix . 'menu_items';
                                                    $sql = "SELECT * FROM $table_name where menu_id = {$menus[$key]['id']} AND status=2 ORDER BY sort_order ASC";
                                                    $results = $wpdb->get_results($sql);
                                                    if (!empty($results)) {
                                                        $menuitems['status'] = 'success';
                                                        foreach ($results as $row) {
                                                            $res[$row->category_id][] = $row;
                                                            if (!in_array($row->category_id, $categories)) {
                                                                $categories[] = $row->category_id;
                                                            }
                                                        }
                                                        $menuitems['results'] += $res;
                                                    }
                                                }
                                            }
                                            
                                            $cats = array();
                                            if (!empty($categories) && count($categories) > 0) {
                                                foreach ($categories as $key => $category) {
                                                    $term = get_term_by('id', $category, 'food_item_cat');
                                                    $cats[$category]['id'] = $category;
                                                    $cats[$category]['name'] = isset($term->name) ? $term->name : '';
                                                    $catDesc = get_term_meta($category,'_'.$restaurant_id.'_cat_item_desc');
                                                    $cats[$category]['description'] = isset($catDesc[0]) ? $catDesc[0] : '';
                                                }
                                            }
                                            ?>
                                            <!--// Detail Listing Tab //-->
                                            <div class="fds-restaurant-detail-tab">
                                                <ul class="fds-restaurant-detailnav fds-options-wrap">
                                                    <li class="fds-list-item"><a class="active product-filter-btn fds-link" id="all" href="#"><?php esc_html_e('all', 'wp-foodsearch') ?></a>
                                                    </li>
                                                    <?php
                                                    foreach ($cats as $cat) {
                                                        echo '<li class="fds-list-item"><a class="product-filter-btn fds-link" id="cat-' . $cat['id'] . '" href="#">' . $cat['name'] . '</a></li>';
                                                    }
                                                    ?>
                                                </ul>
                                                <div class="fds-restaurant-tab-detailcontent">
                                                    <div class="fds-restaurant-menu-search">
                                                        <div class="fds-menu-search-field">
                                                            <a href="#" class="restaurant-food-menu-srchbtn fds-link"><i class="fds-icon fds-filter"></i></a>
                                                            <input type="text" id="restaurant-search-input" class="fds-input-style" placeholder="<?php esc_html_e('search for food', 'wp-foodsearch') ?>">
                                                        </div>
                                                    </div>
                                                    <?php
                                                    foreach ($menuitems['results'] as $key => $menusList) {
                                                        
                                                        ?>
                                                        <div class="fds-restaurant-detail-list cat-<?= $key; ?>">
                                                            <div class="fds-item-cat-wrap">
                                                                <span class="fds-menu-title"><?= $cats[$key]['name']; ?></span>
                                                                <?php if($cats[$key]['description']){ ?>
                                                                <p class="fds-cat-detail"><?= $cats[$key]['description']; ?></p>
                                                                <?php }?>
                                                            </div>
                                                            <div class="fds-menu-list-wrap">
                                                                <input type="hidden" name="restaurant" id="menuRestaurantId" value="<?= $id; ?>">
                                                                <?php
                                                                foreach ($menusList as $menuitem) {
                                                                    $restaurant_id = $menuitem->restaurant_id;
                                                                    $menu_id = $menuitem->id;

                                                                    $menu_nutritions = $common_functions->get_menu_item_nutritions($restaurant_id, $menu_id);
                                                                    $nutritions_html = '';
                                                                    if (!empty($menu_nutritions)) {
                                                                        foreach ($menu_nutritions as $nutri_key => $nutri_item) {
                                                                            $nutri_label = $nutri_item['title'];
                                                                            $nutri_img = $nutri_item['image'];
                                                                            $image_thumb = wp_get_attachment_image_src($nutri_img);
                                                                            $image_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                                                                            $nutritions_html .= '<span class="fds-nutrition-item"><small class="fds-nutrition-item-title">' . $nutri_label . '</small><img src="' . $image_src . '" alt=""></span>';
                                                                        }
                                                                    }
                                                                    ?>
                                                                    <div class="fds-menu-item">
                                                                        <div class="fds-item-thumb">
                                                                            <a href="#" class="fds-restaurant-detail-list-thumb fds-link" style="background-image: url(<?= wp_get_attachment_url($menuitem->attachment_id); ?>)"></a>
                                                                            <div class="fds-item-content">
                                                                                <a href="#" class="fds-menu-item-title fds-link"><?= $menuitem->name; ?> <?php echo ($menuitem->offer_status == 1 ? '<small class="fds-special-offer">' . esc_html__('special offer', 'wp-foodsearch') . '</small>' : '') ?></a>
                                                                                <span class="fds-restaurant-detail-list-subtitle"><?= $menuitem->details; ?></span>
                                                                                <?php echo ($nutritions_html) ?>
                                                                            </div>
                                                                        </div>
                                                                        <div class="fds-restaurant-detail-list-option">
                                                                            <?= isset($menuitem->discount_price) && $menuitem->discount_price > 0 ? '<span class="fds-item-price fds-actual-price">' . Common_Functions::get_formatted_price($menuitem->price) . '</span><strong class="fds-discount-price">' . Common_Functions::get_formatted_price($menuitem->discount_price) . '</strong>' : '<span class="fds-item-price">' . Common_Functions::get_formatted_price($menuitem->price) . '</span>' ?>
                                                                            <?php
                                                                            $choice_group_results = '';
                                                                            if (!empty($choice_group_id)) {
                                                                                $choice_group_id = $menuitem->choice_groups_id;
                                                                                $table_name = $table_prefix . 'menu_choice_group';
                                                                                $sql = "SELECT menuItem_id FROM $table_name where id IN ({$choice_group_id}) AND restaurant_id={$restaurant_id} AND status=2";
                                                                                $choice_group_results = $wpdb->get_col($sql);
                                                                            }

                                                                            if (isset($menuitem->variations)) {
                                                                                $variations = json_decode($menuitem->variations, true);
                                                                            } else {
                                                                                $variations = array();
                                                                            }
                                                                            if (!empty($variations) && count($variations) > 0 || !empty($choice_group_results)) {
                                                                                ?>
                                                                                <a href="#" class="fds-item-add-cart fds-icon fds-plus-simple popupbutton fds-link" data-id="<?= $menuitem->id; ?>"></a>
                                                                                <?php
                                                                            } else {
                                                                                ?>
                                                                                <form class="add_to_cart_form">
                                                                                    <input type="hidden" name="productid" value="<?= $menuitem->id; ?>">
                                                                                    <input type="hidden" name="restaurant" value="<?= $menuitem->restaurant_id; ?>">
                                                                                    <input type="hidden" name="price" value="<?= isset($menuitem->discount_price) && $menuitem->discount_price > 0 ? $menuitem->discount_price : $menuitem->price ?>">
                                                                                    <a class="add_to_cart fds-item-add-cart fds-icon fds-plus-simple fds-link fds-nmb-btn"></a>
                                                                                </form>
                                                                                <?php
                                                                            }
                                                                            ?>
                                                                        </div>
                                                                    </div>
                                                                    <?php
                                                                }
                                                                ?>
                                                            </div>
                                                        </div>
                                                        <?php
                                                    }
                                                    ?>
                                                </div>
                                            </div>
                                            <?php
                                        } else {
                                            ?>
                                            <div class="foodsearch-noitm-found">
                                                <img src="<?php echo foodsearch_plugin_get_url('assets/images/not-found.svg') ?>" alt="">
                                                <p><?php esc_html_e("restaurant is currently closed.", "wp-foodsearch") ?></p>
                                            </div>
                                            <?php
                                        }
                                        ?>
                                    </div>
                                    <?php
                                    echo apply_filters('foodsearch_restaurant_single_after_tab_1_content', '', $restaurant_id);
                                    ?>
                                    <div class="tab-pane" id="tabref3">
                                        <div class="contact-info-detail">
                                            <h5><?php esc_html_e('overview', 'wp-foodsearch') ?> <?php the_title(); ?></h5>
                                            <span class="restaurant-desc"><?php the_content(); ?></span>
                                            <div class="fds-row">
                                                <div class="fds-col-2">
                                                    <div class="contact-info">
                                                        <h5><?php esc_html_e('contact details', 'wp-foodsearch') ?></h5>
                                                       

                                                        <ul class="fds-options-wrap">
                                                        <?php
                                                        if (isset($restaurant_addrss['address']) && $restaurant_addrss['address'] != '') { ?>

                                                           <li class="fds-loc fds-list-item">
                                                            <i class="fds-icon fds-pin-line"></i>
                                                            <div class="fds-contact-detail-box">
                                                            <span> <?php esc_html_e('Address', 'wp-foodsearch') ?></span>
                                                            <p><?=$restaurant_addrss['address'];?></p>
                                                        </div>
                                                        </li>
                                                          
                                                           <?php
                                                        }
                                                        
                                                            if (isset($restaurant_user_obj->user_email)) {
                                                                ?>
                                                                <li class="fds-email fds-list-item">
                                                                    <i class="fds-icon fds-envelope-line-1"></i>
                                                                    <div class="fds-contact-detail-box">
                                                            <span> <?php esc_html_e('Email Us', 'wp-foodsearch') ?></span>
                                                                    <a class="text-color fds-link"
                                                                    href="mailto:<?php echo ($restaurant_user_obj->user_email) ?>">
                                                                    <?php esc_html_e('send enquiry by email', 'wp-foodsearch') ?></a>
                                                            </div>
                                                                </li>
                                                                <?php
                                                            }
                                                            if ($contact_num != '') {
                                                                ?>
                                                                <li class="fds-cell fds-list-item">
                                                                    <i class="fds-icon fds-phone-line"></i>
                                                                    <div class="fds-contact-detail-box">
                                                            <span> <?php esc_html_e('Call Us', 'wp-foodsearch') ?></span>
                                                                    <a href="tel:<?php echo ($contact_num) ?>" class="fds-link">
                                                                        <?php echo ($contact_num) ?>
                                                                    </a>
                                                            </div>
                                                                </li>
                                                                <?php
                                                            }
                                                            
                                                            ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                                <div class="fds-col-2">
                                                    <div class="widget widget-timing">
                                                        <h5><?php esc_html_e('opening hours', 'wp-foodsearch') ?></h5>
                                                        <ul class="fds-options-wrap">
                                                            <?php
                                                            $daysArray = array(array('day' => 'Monday', 'key' => 'monday'),
                                                                array('day' => 'Tuesday', 'key' => 'tuesday'),
                                                                array('day' => 'Wednesday', 'key' => 'wednesday'),
                                                                array('day' => 'Thursday', 'key' => 'thursday'),
                                                                array('day' => 'Friday', 'key' => 'friday'),
                                                                array('day' => 'Saturday', 'key' => 'saturday'),
                                                                array('day' => 'Sunday', 'key' => 'sunday')
                                                            );
                                                            foreach ($daysArray as $day) {
                                                                $openingTime = get_post_meta($restaurant_id, "restaurant_" . $day['key'] . "_opening_hour", true);
                                                                $opentime = $openingTime != '' ? foodsearch_getampmtime($openingTime) : '';
                                                                $closeingTime = get_post_meta($restaurant_id, "restaurant_" . $day['key'] . "_closing_hour", true);
                                                                $closetime = $closeingTime != '' ? foodsearch_getampmtime($closeingTime) : '';

                                                                $timing_str = esc_html__('closed', 'wp-foodsearch');
                                                                if ($opentime != '' && $closetime != '') {
                                                                    $timing_str = $opentime . ' - ' . $closetime;
                                                                }
                                                                ?>
                                                                <li class="fds-list-item"><span><?= $day['day']; ?></span> <?php echo ($timing_str) ?></li>
                                                                <?php
                                                            };
                                                            ?>
                                                        </ul>
                                                    </div>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                            <br>

                        </div>
                        <!--// Content Section //-->

                        <!--// SideBaar //-->
                        <div class="fds-column-3">
                            <?php
                            $delivery_mins = get_post_meta($restaurant_id, 'foodsearch_delivery_time', true);
                            $order_process_type = get_post_meta($restaurant_id, 'foodsearch_order_process_type', true);
                            //echo '<pre>'.print_r($foodsearch_plugin_settings,true).'</pre>';
                            if($foodsearch_plugin_settings['payment_settings']['wc_cart_active']=='on' &&  class_exists( 'WooCommerce' )){
                                $fds_order_form_class ='fds-wc-userorder-cart-form';
                            }
                            else{
                                $fds_order_form_class ='fds-userorder-cart-form';
                            }
                            ?>
                            <!--// Baskit Cart Status //-->
                            <form class="fds-baskit-cart-status <?=$fds_order_form_class;?>">
                                <span class="fds-baskit-cart-status-title"><?php esc_html_e('your basket', 'wp-foodsearch') ?> <i class="fds-icon fds-shopping-basket"></i></span>
                                <div class="fds-filter-radio-view2">
                                    <ul class="fds-options-wrap">
                                        <?php
                                        $is_delivry_enable = false;
                                        if ($order_process_type == 'delivery' || $order_process_type == 'both') {
                                            $is_delivry_enable = true;
                                            ?>
                                            <li class="fds-list-item">
                                                <input id="radio1" type="radio" name="order_type" value="1" checked="checked">
                                                <label for="radio1" class="fds-input-label">
                                                    <span><span>
                                                        </span></span>
                                                    <?php esc_html_e('delivery', 'wp-foodsearch') ?>
                                                    <?php
                                                    if ($delivery_mins != '') {
                                                        ?>
                                                        <small><?php printf(esc_html__('%s min', 'wp-foodsearch'), $delivery_mins) ?></small>
                                                        <?php
                                                    }
                                                    ?>
                                                </label>
                                            </li>
                                            <?php
                                        }
                                        if ($order_process_type == 'takeaway' || $order_process_type == 'both') {
                                            ?>
                                            <li class="fds-list-item">
                                                <input id="radio2" type="radio" name="order_type" value="2"<?php echo (!$is_delivry_enable ? ' checked="checked"' : '') ?>>
                                                <label for="radio2" class="fds-input-label">
                                                    <span><span>
                                                        </span></span>
                                                    <?php esc_html_e('takeaway', 'wp-foodsearch') ?>
                                                    
                                                </label>
                                            </li>
                                            <?php
                                        }
                                        ?>
                                    </ul>
                                </div>
                                <div class="cartmenuitems">
                                    <?php
                                    $order_vat_switch = isset($foodsearch_plugin_settings['payment_settings']['order_vat_tax']) ? $foodsearch_plugin_settings['payment_settings']['order_vat_tax'] : '';
                                    $order_vat_percentage = isset($foodsearch_plugin_settings['payment_settings']['vat_tax_amount']) ? $foodsearch_plugin_settings['payment_settings']['vat_tax_amount'] : '';

                                    $content = '';
                                    $tprice = 0;
                                    
                                    if (isset($_SESSION['cartitems'])) {
                                        $content = '<input type="hidden" name="restaurant" value="'.$_SESSION['restaurant'].'" id="sidebarRestaurantId">';
                                        foreach ($_SESSION['cartitems'] as $keys => $item) {
                                            $variation = '';
                                            $price = 0;
                                            if (isset($item['variation'])) {
                                                $variation = ' (' . $item['variation']['name'] . ')';
                                                $price = $item['variation']['price'];
                                            } else {
                                                $price = $item['basicprice'];
                                            }
                                            $content .= '<ul class="fds-baskit-cart-status-list fds-options-wrap">
                                            <li class="fds-cart-menuitem fds-list-item"><a href="#" class="sidebarmenuitem fds-link" data-id="' . $keys . '"><i class="fds-cross-icon fds-icon fds-cross-circle"></i> ' . foodsearch_menuItemNameByID($item['id']) . $variation . '</a> X ' . $item['qty'] . '<span>' . Common_Functions::get_formatted_price($price) . '</span></li>';
                                            if (isset($item['extras'])) {
                                                foreach ($item['extras'] as $key => $extras) {
                                                    foreach ($extras as $k => $extra) {
                                                        $content .= '<li class="fds-list-item"><a href="#">' . $extra['name'] . ' : </a>
                                                        <small>' . Common_Functions::get_formatted_price($extra['price']) . '</small>
                                                        </li>';
                                                        $price += (int) $extra['price'];
                                                    }
                                                }
                                            }
                                            $content .= '<li class="fds-list-item fds-qty-cart"><div class="fds-restaurant-list-number">
                                            <button type="button"  class="fds-nmb-btn" data-quantity="minus-c" data-field="quantity" data-id="' . $keys . '"><i class="fds-icon fds-minus-simple"></i></button>
                                            <input type="number" id="fds_popup_qty" name="quantity" value="'.$item['qty'].'" min="1">
                                            <button type="button" data-quantity="plus-c" class="fds-nmb-btn" data-field="quantity" data-id="' . $keys . '"><i class="fds-icon fds-plus-simple"></i></button>
                                          </div></li></ul>';
                                            $tprice += $price*$item['qty'];
                                        }
                                        
                                    }
                                    $net_total = $tprice;
                                    $content .= '<ul class="fds-baskit-cart-subtotal fds-options-wrap">
                                        <li class="fds-list-item">' . esc_html__('subtotal', 'wp-foodsearch') . ' <span>' . Common_Functions::get_formatted_price($tprice) . '</span></li>';

                                        $delivery_charges = get_post_meta($restaurant_id, 'foodsearch_delivery_fee', true);
                                        $order_process_type = get_post_meta($restaurant_id, 'foodsearch_order_process_type', true);
                                        $order_type = isset($_SESSION['foodsearch_order_type']) ? $_SESSION['foodsearch_order_type'] : '';
                                        if ($delivery_charges > 0 && ($order_process_type == 'delivery' || $order_process_type == 'both') && $order_type != 'take_away' && $tprice > 0) {
                                            $net_total += $delivery_charges;
                                            $content .= '<li class="fds-list-item">' . esc_html__('delivery fee', 'wp-foodsearch') . ' <span>' . Common_Functions::get_formatted_price($delivery_charges) . '</span></li>';
                                        }
                                        $total_vat_amount = 0;
                                        if ($order_vat_switch == 'on' && $order_vat_percentage > 0 && $tprice > 0&& !(isset($foodsearch_plugin_settings['payment_settings']['wc_cart_active']) && $foodsearch_plugin_settings['payment_settings']['wc_cart_active']=='on' &&  class_exists( 'WooCommerce' ))) {
                                            $total_vat_amount = $net_total * ($order_vat_percentage/100);
                                            $net_total += $total_vat_amount;
                                        }
                                        else{
                                            $order_vat_switch = 'off';
                                        }
                                        if ($order_vat_switch == 'on' && $tprice > 0) {
                                            $content .= '<li class="fds-list-item">' . sprintf(esc_html__('vat (%s)', 'wp-foodsearch'), $order_vat_percentage . '%') . ' <span>' . Common_Functions::get_formatted_price($total_vat_amount) . '</span></li>';
                                        }
                                        $content .= '<li class="active fds-list-item">' . esc_html__('total', 'wp-foodsearch') . ' <span>' . common_functions::get_formatted_price($net_total) . '</span></li>
                                    </ul>';
                                    echo $content;
                                    ?>
                                </div>
                                <?php
                                wp_nonce_field('cart_to_order', '_nonce');
                                ?>
                                <input type="hidden" name="restaurant_id" value="<?php echo ($restaurant_id) ?>">
                                <input type="hidden" name="n_id" value="<?php echo absint($user_id) ?>">
                                <div class="fds-btn fds-large-btn">
                                    <input type="submit" class="fds-has-bg" value="<?php esc_html_e('order now', 'wp-foodsearch') ?>">
                                </div>
                            </form>

                            <a class="openOrderCartPopup fds-link" href="#order-checkout-popup" style="display: none"></a>
                            <div id="order-checkout-popup" class="fds-plugin-modal-box fds-booking-detail-modal addtocart-popup fds-checkout-popup fds-typo-wrap" style="display: none">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                            <?php
                            if ($contact_num != '') {
                                ?>
                                <div class="fds-restaurant-detail-information">
                                    <i class="fds-icon fds-question"></i>
                                    <span><?php esc_html_e('need help?', 'wp-foodsearch') ?></span>
                                    <strong><a href="tel:<?php echo ($contact_num) ?>"><?php echo ($contact_num) ?></a></strong>
                                </div>
                                <?php
                            }
                            ?>
                        </div>

                    </div>
                </div>

            </div>

        </div>
        <?php
        $html = ob_get_clean();
        
        add_action('wp_footer', function() {
            ?>
            <div id="product-popup" class="fds-modal-popup fds-popup-hide fds-product-selection-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }, 20);
        
        return $html;
    }
    
    public function single_restaurant_shortcode($atts) {
        return $this->html();
    }

}

new Single_Restaurant();

