<?php

namespace FoodSearch;
use FoodSearch\Common_Functions;
use FoodSearch\Google_Maps;
use FoodSearch\MapBox;
use FoodSearch\User_Geolocation;

class User_Locations {
    
    public $default_lat = '51.51';

    public $default_lng = '-0.15';

    public function __construct() {
        add_action('wp_enqueue_scripts', array($this, 'enqueue_style_scripts'), 50);
        add_action('admin_enqueue_scripts', array($this, 'enqueue_style_scripts'), 50);
        
        add_action('rest_api_init', array($this, 'register_api'));
    }
    
    public function register_api() {
        register_rest_route('wp/v1', 'foodsearch-add-user-location', array(
            'methods' => 'POST',
            'callback' => [$this, 'add_new_location'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        register_rest_route('wp/v1', 'foodsearch-edit-loc-form', array(
            'methods' => 'POST',
            'callback' => [$this, 'open_update_form'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        register_rest_route('wp/v1', 'foodsearch-update-user-location', array(
            'methods' => 'POST',
            'callback' => [$this, 'update_address_location'],
            'permission_callback' =>  'admin_permissions_check'
        ));        
        register_rest_route('wp/v1', 'foodsearch-saved-location-list', array(
            'methods' => 'POST',
            'callback' => [$this, 'saved_location_list'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        register_rest_route('wp/v1', 'foodsearch-remove-user-location', array(
            'methods' => 'POST',
            'callback' => [$this, 'remove_address_location'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        register_rest_route('wp/v1', 'get-map-cords-addres', array(
            'methods' => 'POST',
            'callback' => [$this, 'get_map_cords_address'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        
        register_rest_route('wp/v1', 'get-location-lat-lng-on-address', array(
            'methods' => 'POST',
            'callback' => [$this, 'get_location_lat_lng_on_address'],
            'permission_callback' =>  'admin_permissions_check'
        ));
        
    }   
    function get_location_lat_lng_on_address(){
        return $this->get_latlng_from_address($_POST['address']);
    }
    public function to_check_nonce() {
        if (defined("WP_CACHE")) {
            return false;
        }
    }
    
    public function enqueue_style_scripts() {
        global $foodsearch_plugin_settings;
        
        $location_maps = isset($foodsearch_plugin_settings['location_settings']['loc_maps']) ? $foodsearch_plugin_settings['location_settings']['loc_maps'] : '';
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        
        $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';
        $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
        $mapbox_style = isset($foodsearch_plugin_settings['location_settings']['mapbox_style']) ? $foodsearch_plugin_settings['location_settings']['mapbox_style'] : '';
        
        $map_zoom = isset($foodsearch_plugin_settings['location_settings']['default_map_zoom']) ? $foodsearch_plugin_settings['location_settings']['default_map_zoom'] : '';
        $map_zoom = $map_zoom > 0 ? $map_zoom : 6;
        
        $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
        
        $countries_json = '';
        if ($default_country != '') {
            $countries_json = json_encode(array($default_country));
        }
        
        wp_register_script('foodsearch-locations-js', foodsearch_plugin_get_url('assets/js/locations.js'), array('jquery'), \FoodSearch_Plugin::get_version(), true);
        $script_str_arr = array(
            'site_url' => esc_url_raw( rest_url() ),
            'wpnonce' => wp_create_nonce('wp_rest'),
            'loc_maps' => $location_maps,
            'maps_type' => $map_type,
            'google_api' => $google_api_key,
            'mapbox_api' => $mapbox_api_key,
            'mapbox_style' => $mapbox_style,
            'map_zoom' => $map_zoom,
            'add_new_loctxt' => esc_html__('add new location', 'wp-foodsearch'),
            'delete_msg' => esc_html__('do you really wants to delete this?', 'wp-foodsearch'),
            'def_countries' => $countries_json,
        );
        wp_localize_script('foodsearch-locations-js', 'dashboard_location_vars', $script_str_arr);
    }
    
    public function loc_labels() {
        $labels = array(
            'home' => array(
                'label' => esc_html__('home', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-home-line',
            ),
            'work' => array(
                'label' => esc_html__('work', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-briefcase-line',
            ),
            'friend' => array(
                'label' => esc_html__('friend', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-head-line',
            ),
            'other' => array(
                'label' => esc_html__('other', 'wp-foodsearch'),
                'icon' => 'fds-icon fds-plus-simple',
            ),
        );
        
        return $labels;
    }

    public function add_locations($user_id, $object_id = 0, $atts = array()) {
        global $foodsearch_plugin_settings;
        $is_checkout = false;
        if (isset($atts['place']) && $atts['place'] == 'checkout') {
            $is_checkout = true;
        }
        
        $show_addres_itm = '';
        $show_addres_locid = '';
        
        $add_newaddres_title = $is_checkout ? esc_html__('delivery address', 'wp-foodsearch') : esc_html__('add address', 'wp-foodsearch');
        $have_address = false;
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        
        $common_functions = new Common_Functions;
        
        
        $force_obj_id = false;
        if ($object_id > 0) {
            $post_id = $object_id;
            $force_obj_id = true;
        }
        else{
            $user_type = Common_Functions::user_type($user_id);
            if ($user_type == 'restaurant') {
                $post_id = Common_Functions::user_restaurant_id($user_id);
            } else {
                $post_id = Common_Functions::user_customer_id($user_id);
            }
        }
        if(empty($post_id)){
            $post_id = $user_id;
        }
        $address_list = get_saved_location_on_id($post_id);
        if (is_array($address_list) && count($address_list)>0) {
            $have_address = true;
            $add_newaddres_title = esc_html__('add new address', 'wp-foodsearch');
        }
        ?>
        <div class="fds-user-locations">
            <div class="fds-user-formpart fds-locations-list fds-saved-locations-list" <?php echo (!$have_address ? ' style="display: none;"' : '') ?>>
                <div class="fds-formpart-hding"><strong class="fds-locs-hding"><?php echo ($is_checkout ? esc_html__('delivery address', 'wp-foodsearch') : esc_html__('address', 'wp-foodsearch')) ?></strong></div>
                <div class="fds-all-saved-locs">
                    <?php
                   if (is_array($address_list) && count($address_list)>0) {
                        $user_or_obj_id = $force_obj_id ? $object_id : $user_id;
                        $adres_counter = 1;
                        foreach ($address_list as $addres_id => $address_itm) {
                            if ($is_checkout && $adres_counter == 1) {
                                $details = unserialize($address_itm['detail']);
                                $address_itm_loc = $details['address'];
                                $show_addres_locid = $address_itm['id'];
                            }
                           
                            $details = unserialize($address_itm['detail']);
                            $address_itm_loc = $details['address'];
                            $this->saved_list_address($address_itm_loc, $address_itm['id'], $user_or_obj_id, $is_checkout);
                            $adres_counter++;
                        }
                    }
                    ?>
                </div>
                <div class="fds-addnew-adres-con">
                    <a href="#" class="fds-add-loc-triger fds-link"><i class="fds-icon fds-plus-simple"></i> <?php esc_html_e('add new address', 'wp-foodsearch') ?></a>
                </div>
            </div>
            <?php
            $is_updating = false;
            $address_val = $address_lat_val = $address_lng_val = $address_floor_val = $address_notes_val = $address_labl_val = $address_lablother_val = '';
            if (!empty($show_addres_itm) && isset($show_addres_itm['address'])) {
                $is_updating = true;
                $address_val = $show_addres_itm['address'];
                $address_floor_val = isset($show_addres_itm['floor_unit']) ? $show_addres_itm['floor_unit'] : '';
                $address_lat_val = isset($show_addres_itm['lat']) ? $show_addres_itm['lat'] : '';
                $address_lng_val = isset($show_addres_itm['lng']) ? $show_addres_itm['lng'] : '';
                $address_notes_val = isset($show_addres_itm['notes']) ? $show_addres_itm['notes'] : '';
                $address_labl_val = isset($show_addres_itm['label']) ? $show_addres_itm['label'] : '';
                $address_lablother_val = isset($show_addres_itm['label_other']) ? $show_addres_itm['label_other'] : '';
            }

            if ($address_lat_val == '' || $address_lng_val == '') {
                $def_latlng = $this->get_default_latlng();
                
                $address_lat_val = $def_latlng[0];
                $address_lng_val = $def_latlng[1];
            }
            $is_addrs_form_open = true;
            if (!$is_checkout && $have_address) {
                $is_addrs_form_open = false;
            }
            ?>
            <div class="fds-user-formpart fds-addupd-location"<?php echo (!$is_checkout && $have_address ? ' style="display: none;"' : '') ?>>
                <div class="fds-formpart-hding">
                    <strong class="fds-locs-hding"<?php echo ($is_updating ? ' style="display: none;"' : '') ?>><?php echo ($add_newaddres_title) ?></strong>
                    <strong class="fds-locs-hding update-loc-hding"<?php echo (!$is_updating ? ' style="display: none;"' : '') ?>><?php esc_html_e('update address', 'wp-foodsearch') ?></strong>
                    <a href="#" class="fds-get-current-location fds-link"><i class="fds-icon fds-plane-loc-line"></i> <span><?php esc_html_e('use my current location', 'wp-foodsearch') ?></span></a>
                </div>
                <?php
                if ($map_type == 'mapbox') {
                    $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
                    $mapbox_map_style = isset($foodsearch_plugin_settings['location_settings']['mapbox_style']) ? $foodsearch_plugin_settings['location_settings']['mapbox_style'] : '';
                    $maps_obj = new MapBox;
                } else {
                    $maps_obj = new Google_Maps;
                }
                $maps_obj->dash_loc_map($user_id);
                ?>
                <div class="fds-address-fields<?php echo ($is_addrs_form_open ? ' adres-fields-open' : '') ?>">
                    <div class="fds-form-field">
                        <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('street address *', 'wp-foodsearch') ?></label></div>
                        <?php
                        if ($map_type == 'mapbox' && $mapbox_api_key != '' && $mapbox_map_style != '') {
                            ?>
                            <div class="fds-mapbox-loc-geocoder"></div>
                            <?php
                        } else {
                            ?>
                            <input type="text" name="fds_loc_address" class="fds-input-style fds-loc-address-field"<?php echo ($is_addrs_form_open ? ' required' : '') ?> value="<?php echo ($address_val) ?>">
                            <?php
                        }
                        ?>
                        <input type="hidden" name="fds_location_lat" class="fds-map-lat-field" value="<?php echo ($address_lat_val) ?>">
                        <input type="hidden" name="fds_location_lng" class="fds-map-lng-field" value="<?php echo ($address_lng_val) ?>">
                        <input type="hidden" name="nid" value="<?php echo ($force_obj_id ? $object_id : $user_id) ?>">
                        <?php
                        if ($have_address && $is_checkout) {
                            ?>
                            <input type="hidden" name="fds_loc_id" class="fds-loc-id-field" value="<?php echo ($show_addres_locid) ?>">
                            <?php
                        }
                        ?>
                    </div>
                    <div class="fds-form-field">
                        <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('floor/unit (optional)', 'wp-foodsearch') ?></label></div>
                        <input type="text" name="fds_address_floor" class="fds-input-style fds-address-floor-field" value="<?php echo ($address_floor_val) ?>">
                    </div>
                    <div class="fds-form-field">
                        <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('rider notes (optional)', 'wp-foodsearch') ?></label></div>
                        <textarea type="text" name="fds_address_notes" class="fds-textarea-style fds-address-notes-field"><?php echo ($address_notes_val) ?></textarea>
                    </div>
                </div>
                <?php
                $loc_labels = $this->loc_labels();
                ?>
                 <div class="addres-con-box">
                <div class="addres-labels-con">
                    <label class="fds-input-label"><?php esc_html_e('address label', 'wp-foodsearch') ?></label>
                    <div class="loc-label-itms">
                        <?php
                        $i=1;
                        foreach ($loc_labels as $labl_key => $labl_item) {
                            $labl_rand = rand(100000, 999999);
                            //echo 'address_labl_val: '.$address_labl_val.' labl_key: '.$labl_key
                            ?>
                            <div class="labl-itm<?php echo (($address_labl_val == $labl_key ||($address_labl_val != $labl_key && $i==1)) ? ' active-labl' : '') ?>">
                                <label for="loc-labl-<?php echo ($labl_rand) ?>">
                                    <i class="<?php echo ($labl_item['icon']) ?>"<?php echo (($address_labl_val == $labl_key ||($address_labl_val != $labl_key && $i==1)) ? ' style="background-color: rgb(228, 42, 69); color: rgb(255, 255, 255)"' : '') ?>></i>
                                    <input id="loc-labl-<?php echo ($labl_rand) ?>" type="radio" required name="fds_address_label" class="fds-addres-labl-field"<?php echo ($address_labl_val == $labl_key ? ' checked' : '') ?> value="<?php echo ($labl_key) ?>">
                                    <span><?php echo ($labl_item['label']) ?></span>
                                </label>
                            </div>
                            <?php
                            $i++;
                        }
                        ?>
                    </div>
                    <div class="other-label-text"<?php echo ($address_labl_val == 'other' ? '' : ' style="display:none;"') ?>>
                        <div class="fds-form-field">
                            <div class="label_wrap"><label class="fds-input-label"><?php esc_html_e('other label', 'wp-foodsearch') ?></label></div>
                            <input type="text" name="fds_address_label_other" class="fds-input-style fds-addres-labl-other" value="">
                        </div>
                    </div>
                </div>
                <?php
                if (!$is_checkout) {
                    ?>
                    <div class="fds-location-btncon fds-btn fds-medium-btn">
                        <?php
                        wp_nonce_field('foodsearch_user_location_address', '_nonce');
                        ?>
                        <button class="fds-has-bg fds-location-addbtn add-location-btn fds-update-anything-action"><?php esc_html_e('add new address', 'wp-foodsearch') ?></button>
                        <button class="fds-has-bg fds-location-addbtn update-location-btn fds-update-anything-action" style="display: none;"><?php esc_html_e('update address', 'wp-foodsearch') ?></button>
                    </div>
                    <?php
                }
                ?>
                 </div>
            </div>
        </div>
        <?php
        
        wp_enqueue_script('foodsearch-locations-js');
    } 
    
    public function add_new_location() {
        $rand_num = rand(100000, 999999);
        
        $user_or_obj_id = $_POST['nid'];
        $address = foodsearch_esc_html($_POST['fds_loc_address']);
        $lat = foodsearch_esc_html($_POST['fds_location_lat']);
        $lng = foodsearch_esc_html($_POST['fds_location_lng']);
        $map_zoom = isset($_POST['fds_location_map_zoom']) ? foodsearch_esc_html($_POST['fds_location_map_zoom']) : '';
        $floor_unit = foodsearch_esc_html($_POST['fds_address_floor']);
        $adres_notes = foodsearch_esc_html($_POST['fds_address_notes']);
        $adres_label = isset($_POST['fds_address_label'])?foodsearch_esc_html($_POST['fds_address_label']):'';
        $adres_label_other = foodsearch_esc_html($_POST['fds_address_label_other']);
        
        if ($this->to_check_nonce()) {
            if (!isset($_POST['_nonce']) || !wp_verify_nonce($_POST['_nonce'], 'foodsearch_user_location_address')) {
                $responsedata = array('error' => '1', 'msg' => esc_html__('Session token has expired, please reload the page and try again.', 'wp-foodsearch'));
                wp_send_json($responsedata);
            }
        }

        if ($address == '') {
            wp_send_json(array('error' => '1', 'msg' => esc_html__('address field cannot be empty.', 'wp-foodsearch'), 'html' => ''));
        }
        
        $common_functions = new Common_Functions;
        
        $user_type = Common_Functions::user_type($user_or_obj_id);
        if ($user_type == 'restaurant') {
            $post_id = Common_Functions::user_restaurant_id($user_or_obj_id);
        } else {
           $post_id = Common_Functions::user_customer_id($user_or_obj_id);
        }
        if(empty($post_id)){
            $post_id = $user_or_obj_id;
        }
        $locs_list = get_saved_location_on_id($post_id);
        
        $locs_list = !empty($locs_list) ? $locs_list : array();
        
        if (!empty($locs_list)) {
            foreach ($locs_list as $loc_itm) {
                if (isset($loc_itm['address']) && $loc_itm['address'] == $address || (isset($floor_unit) && isset($loc_itm['floor_unit']) && $loc_itm['floor_unit']==$floor_unit)|| (isset($floor_unit) && isset($loc_itm['label_other']) && $loc_itm['label_other']==$adres_label_other)|| (isset($floor_unit) && isset($loc_itm['label'])&& $loc_itm['label']==$adres_label) ) {
                    wp_send_json(array('error' => '2', 'msg' => esc_html__('this address is already exist.', 'wp-foodsearch'), 'html' => ''));
                    break;
                }
            }
        }
        $loc_item = array(
            'address' => $address,
            'floor_unit' => $floor_unit,
            'lat' => $lat,
            'lng' => $lng,
            'map_zoom' => $map_zoom,
            'notes' => $adres_notes,
            'label' => $adres_label,
            'label_other' => $adres_label_other,
        );
        
        $this->add_adress_to_list($post_id,  $loc_item);
        
        ob_start();
        $this->saved_list_address($address,$rand_num, $user_or_obj_id);
        $html = ob_get_clean();
        
        wp_send_json(array('error' => '0', 'post_id' =>$user_or_obj_id, 'msg' => esc_html__('address added successfully.', 'wp-foodsearch'), 'html' => $html));
    }
    public function add_adress_to_list($post_id,  $loc_item, $loc_id='') {
        
        $locs_list = get_saved_location_on_id($post_id);
       
        $can_add_address = true;
        if (!is_array($locs_list)) {
            $can_add_address = false;
            wp_send_json(array('error' => '1', 'msg' => esc_html__('address not found.', 'wp-foodsearch'), 'html' => ''));
        }
        
        if (!empty($locs_list) && is_array($locs_list)) {
            $address = $loc_item['address'];
            foreach ($locs_list as $loc_itm) {
                $adrs = unserialize($loc_itm['detail']);
                if ($loc_itm['id'] != $loc_id && isset($adrs['address']) && $adrs['address'] == $address) {
                    $can_add_address = false;
                    wp_send_json(array('error' => '2', 'msg' => esc_html__('this address is already exist.', 'wp-foodsearch'), 'html' => ''));
                    break;
                }
            }
        }        
        if ($can_add_address) {
             self::save_address($post_id, $loc_item,$loc_id);
        }
    }
    public function save_address($post_id, $locs_list,$itemId = '') {
       
        global $wpdb,$table_prefix;
        $tblname = 'fds_locations';
        $table_name = $table_prefix . "$tblname";
        if(!empty($itemId)){
            $lat = $locs_list['lat'];            
            $lng = $locs_list['lng'];
            unset($locs_list['lat']);
            unset($locs_list['lng']);
            $result =  $wpdb->query($wpdb->prepare("UPDATE $table_name SET `lat`='".$lat."',`lng`='".$lng."',`detail`='".maybe_serialize($locs_list)."' WHERE id=$itemId"));
        }
        else{
            $lat = $locs_list['lat'];            
            $lng = $locs_list['lng'];
            unset($locs_list['lat']);
            unset($locs_list['lng']);
           $result =  $wpdb->insert( $table_name, array(
                'post_id' => $post_id,
                'lat' => $lat,
                'lng' => $lng,
                'detail' => maybe_serialize($locs_list),
            ));     
        }
        if($result > 0){
         return "Successfully Updated";
        }
        else{
            exit( var_dump( $wpdb->last_query ) );
        }
    } 
    
    public function saved_location_list() {
        $post_id = $_POST['pid'];
        $locationList = get_saved_location_on_id($post_id);
        $html = '';
        foreach($locationList as $loc_itm){
            $id = $loc_itm['id'];
            $adrs = unserialize($loc_itm['detail']);
        
            $html.='<div id="loc-adress-itm-'.$id.'" class="saved-loc-item">
            <span class="address-con"><i class="fds-icon fds-marker-thin"></i> '.$adrs['address'].'</span>
            <div class="fds-menu-ations">
             <a href="#" class="fds-body-action fds-edit-user-loc fds-update-anything-action fds-link" data-id="'.$id.'" data-nid="'.$post_id.'>"><i class="fds-icon fds-edit"></i></a>
             <a href="#" class="fds-body-action fds-remove-action fds-remove-user-loc fds-link" data-id="'.$id.'" data-nid="'.$post_id.'"><i class="fds-icon fds-time-simple"></i></a>
            </div>
        </div>';        
         
        }
        wp_send_json(array('error' => '0', 'html' => $html));
    }   
    private function saved_list_address($address, $id, $user_or_obj_id, $is_checkout = false) {
        
        ?>
        <div id="loc-adress-itm-<?php echo ($id) ?>" class="saved-loc-item">
            <?php
            if ($is_checkout === true) {
                ?>
                <a href="#" class="fds-edit-user-loc fds-update-anything-action fds-link" data-id="<?php echo ($id) ?>" data-nid="<?php echo ($user_or_obj_id) ?>"><span class="address-con"><i class="fds-icon fds-marker-thin"></i> <?php echo ($address) ?></span></a>
                <?php
            } else {
                ?>
                <span class="address-con"><i class="fds-icon fds-marker-thin"></i> <?php echo ($address) ?></span>
                <?php
            }
            ?>
            <div class="fds-menu-ations">
                <?php
                if ($is_checkout == false) {
                    ?>
                    <a href="#" class="fds-body-action fds-edit-user-loc fds-update-anything-action fds-link" data-id="<?php echo ($id) ?>" data-nid="<?php echo ($user_or_obj_id) ?>"><i class="fds-icon fds-edit"></i></a>
                    <?php
                }
                ?>
                <a href="#" class="fds-body-action fds-remove-action fds-remove-user-loc fds-link" data-id="<?php echo ($id) ?>" data-nid="<?php echo ($user_or_obj_id) ?>"><i class="fds-icon fds-time-simple"></i></a>
            </div>
        </div>
        <?php
    }    
    public function open_update_form() {
        $user_id = $_POST['nid'];
        $loc_id = $_POST['loc_id'];
        
        $common_functions = new Common_Functions;
       
        $user_type = Common_Functions::user_type($user_id);
        if ($user_type == 'restaurant') {
            $post_id = Common_Functions::user_restaurant_id($user_id);
        } else {
            $post_id = Common_Functions::user_customer_id($user_id);
        }
        if(!$post_id){
            $post_id = $user_id;
        }
        $locs_list = get_saved_location_on_id($post_id,$loc_id);
       // echo 'post_id: '.$post_id.'<pre>loc_id: '.$loc_id.' user_id:'.$user_id.': '.print_r($locs_list,true).'</pre>';
        $address = $lat = $lng = $map_zoom = $floor_unit = $notes = $labl = $labl_other = '';
        if ($loc_id != '' && isset($locs_list) && is_array($locs_list) && count($locs_list)>0 ) {
            $list = unserialize($locs_list[0]['detail']);
            $address = $list['address'];
            $lat = $locs_list[0]['lat'];
            $lng = $locs_list[0]['lng'];
            $map_zoom = $list['map_zoom'];
            $floor_unit = $list['floor_unit'];
            $notes = $list['notes'];
            $labl = $list['label'];
            $labl_other = $list['label_other'];
            wp_send_json(array('address' => $address, 'lat' => $lat, 'lng' => $lng, 'map_zoom' => $map_zoom, 'floor_unit' => $floor_unit, 'notes' => $notes, 'label' => $labl, 'label_other' => $labl_other));

        }
        wp_send_json(array('error' => '1', 'msg' => esc_html__('address data not found.', 'wp-foodsearch'), 'html' => ''));
       // wp_send_json(array('address' => '', 'lat' => '', 'lng' => '', 'map_zoom' => '', 'floor_unit' => '', 'notes' => '', 'label' => '', 'label_other' => ''));
    }    
    public function update_address_location() {
        $loc_id = $_POST['id'];
        $user_or_obj_id = $_POST['nid'];
        $address = foodsearch_esc_html($_POST['fds_loc_address']);
        $lat = foodsearch_esc_html($_POST['fds_location_lat']);
        $lng = foodsearch_esc_html($_POST['fds_location_lng']);
        $map_zoom = isset($_POST['fds_location_map_zoom']) ? foodsearch_esc_html($_POST['fds_location_map_zoom']) : '';
        $floor_unit = foodsearch_esc_html($_POST['fds_address_floor']);
        $adres_notes = foodsearch_esc_html($_POST['fds_address_notes']);
        $adres_label = isset($_POST['fds_address_label'])?foodsearch_esc_html($_POST['fds_address_label']):'';
        $adres_label_other = foodsearch_esc_html($_POST['fds_address_label_other']);
        
        if ($this->to_check_nonce()) {
            if (!isset($_POST['_nonce']) || !wp_verify_nonce($_POST['_nonce'], 'foodsearch_user_location_address')) {
                $responsedata = array('error' => '1', 'msg' => esc_html__('Session token has expired, please reload the page and try again.', 'wp-foodsearch'));
                wp_send_json($responsedata);
            }
        }

        if ($address == '') {
            wp_send_json(array('error' => '1', 'msg' => esc_html__('address field cannot be empty.', 'wp-foodsearch'), 'html' => ''));
        }
        $common_functions = new Common_Functions;
        
        $user_type = Common_Functions::user_type($user_or_obj_id);
        if ($user_type == 'restaurant') {
            $post_id = Common_Functions::user_restaurant_id($user_or_obj_id);
        } else {
            $post_id = Common_Functions::user_customer_id($user_or_obj_id);
        }
        
        $locs_list = get_saved_location_on_id($post_id);
        if (!is_array($locs_list)) {
            wp_send_json(array('error' => '1', 'post_id' => $post_id,'msg' => esc_html__('address not found.', 'wp-foodsearch'), 'html' => ''));
        }
        
        if (!empty($locs_list) && is_array($locs_list)) {
            foreach ($locs_list as $loc_itm) {
                $adrs = unserialize($loc_itm['detail']);
                if ($loc_itm['id'] != $loc_id && isset($adrs['address']) && $adrs['address'] == $address) {
                    wp_send_json(array('error' => '2', 'msg' => esc_html__('this address is already exist.', 'wp-foodsearch'), 'html' => ''));
                    break;
                }
            }
        }
        
        $loc_item = array(
            'address' => $address,
            'floor_unit' => $floor_unit,
            'lat' => $lat,
            'lng' => $lng,
            'map_zoom' => $map_zoom,
            'notes' => $adres_notes,
            'label' => $adres_label,
            'label_other' => $adres_label_other,
        );
        
        $this->add_adress_to_list($user_or_obj_id, $loc_item,$loc_id);
        
        wp_send_json(array('error' => '0', 'post_id' => $user_or_obj_id, 'msg' => esc_html__('address updated successfully.', 'wp-foodsearch'), 'address' => '<i class="fds-icon fds-marker-thin"></i> ' . $address));
    }    
    public function remove_address_location() {
        $loc_id = $_POST['loc_id'];
        $user_or_obj_id = $_POST['n_id'];
        global $wpdb;
        $sql = 'DELETE FROM `'. $wpdb->prefix .'fds_locations` WHERE `id` = %d AND `post_id` = %d;';

    try {
        $wpdb->query($wpdb->prepare($sql, array($loc_id,$user_or_obj_id)));
        wp_send_json(array('error' => '0', 'msg' => esc_html__('address removed successfully.', 'wp-foodsearch')));
    } catch (Exception $e) {
        wp_send_json(array('error' => '1', 'msg' => esc_html__('Error! '. $wpdb->last_error, 'wp-foodsearch')));        
    }      
       
    }    
       
    public function get_address_from_latlng($lat, $lng) {
        global $foodsearch_plugin_settings;

        $response_array = array();
        $response_array['address'] = '';
        
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        if ($map_type == 'mapbox') {
            $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';

            $geo_loc_url = 'https://api.mapbox.com/geocoding/v5/mapbox.places/' . $lng . ',' . $lat . '.json?access_token=' . $mapbox_api_key;
            $location_geo = wp_remote_get($geo_loc_url);
            if (!is_wp_error($location_geo)) {
                if (isset($location_geo['body'])) {
                    $cords_info = json_decode($location_geo['body'], true);
                    $format_address = isset($cords_info['features'][0]['place_name']) ? $cords_info['features'][0]['place_name'] : '';
                    $cords = isset($cords_info['features'][0]['geometry']['coordinates']) ? $cords_info['features'][0]['geometry']['coordinates'] : '';
                    $latitude = isset($cords[1]) ? $cords[1] : '';
                    $longitude = isset($cords[0]) ? $cords[0] : '';

                    $response_array['address'] = $format_address;
                }
            }
        } else {
            $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';

            if ($google_api_key != '') {

                $wp_remote_get_args = array(
                    'timeout' => 50,
                    'compress' => false,
                    'decompress' => true,
                );
                $response = wp_remote_get('https://maps.googleapis.com/maps/api/geocode/json?key=' . $google_api_key . '&latlng=' . $lat . ',' . $lng . '&sensor=true', $wp_remote_get_args);
                if (!is_wp_error($response)) {
                    $data = json_decode($response['body']);

                    $location_data = $data->results[0];
                    $response_array['address'] = $location_data->formatted_address;
                }

                if ($response_array['address'] == '' || $response_array['address'] == null) {
                    $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';

                    $geo_loc_url = 'https://api.mapbox.com/geocoding/v5/mapbox.places/' . $lng . ',' . $lat . '.json?access_token=' . $mapbox_api_key;
                    $location_geo = wp_remote_get($geo_loc_url);
                    if (!is_wp_error($location_geo)) {
                        if (isset($location_geo['body'])) {
                            $cords_info = json_decode($location_geo['body'], true);
                            $format_address = isset($cords_info['features'][0]['place_name']) ? $cords_info['features'][0]['place_name'] : '';
                            $cords = isset($cords_info['features'][0]['geometry']['coordinates']) ? $cords_info['features'][0]['geometry']['coordinates'] : '';
                            $latitude = isset($cords[1]) ? $cords[1] : '';
                            $longitude = isset($cords[0]) ? $cords[0] : '';

                            $response_array['address'] = $format_address;
                        }
                    }
                }
            }
        }
        
        return $response_array;
    }    
    public function get_latlng_from_address($address) {
        
        global $foodsearch_plugin_settings;
        
        $cords_array = array(
            'lat' => '',
            'lng' => '',
        );
        
        $map_type = isset($foodsearch_plugin_settings['location_settings']['map_type']) ? $foodsearch_plugin_settings['location_settings']['map_type'] : '';
        
        if ($map_type == 'mapbox') {
            $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
            $geo_loc_url = 'https://api.mapbox.com/geocoding/v5/mapbox.places/' . urlencode($address) . '.json?access_token=' . $mapbox_api_key;
            $location_geo = wp_remote_get($geo_loc_url);
            if (!is_wp_error($location_geo)) {
                if (isset($location_geo['body'])) {
                    $cords_info = json_decode($location_geo['body'], true);
                    $format_address = isset($cords_info['features'][0]['place_name']) ? $cords_info['features'][0]['place_name'] : '';
                    $cords = isset($cords_info['features'][0]['geometry']['coordinates']) ? $cords_info['features'][0]['geometry']['coordinates'] : '';
                    $latitude = isset($cords[1]) ? $cords[1] : '';
                    $longitude = isset($cords[0]) ? $cords[0] : '';
                    if (!empty($latitude) && !empty($longitude)) {
                        $cords_array['lat'] = $latitude;
                        $cords_array['lng'] = $longitude;
                    }
                }
            }
        } else {
            $google_api_key = isset($foodsearch_plugin_settings['api_settings']['google_api']) ? $foodsearch_plugin_settings['api_settings']['google_api'] : '';
            $geo_loc_url = 'https://maps.googleapis.com/maps/api/geocode/json?address=' . urlencode($address) . '&sensor=false' . ($google_api_key != '' ? '&key=' . $google_api_key : '');
            $location_geo = wp_remote_get($geo_loc_url);
            if (!is_wp_error($location_geo)) {
                if (isset($location_geo['body'])) {
                    $cords_info = json_decode($location_geo['body'], true);
                    if (isset($cords_info['results']) && empty($cords_info['results'])) {
                        $location_geo = wp_remote_get('https://maps.googleapis.com/maps/api/geocode/json?address=' . urlencode($address));
                    }
                }

                if (!is_wp_error($location_geo)) {
                    if (isset($location_geo['body'])) {
                        $cords_info = json_decode($location_geo['body'], true);
                        if (isset($cords_info['status']) && $cords_info['status'] == 'OK') {
                            $latitude = isset($cords_info['results'][0]['geometry']['location']['lat']) ? $cords_info['results'][0]['geometry']['location']['lat'] : '';
                            $longitude = isset($cords_info['results'][0]['geometry']['location']['lng']) ? $cords_info['results'][0]['geometry']['location']['lng'] : '';
                            $formatted_address = isset($cords_info['results'][0]['formatted_address']) ? $cords_info['results'][0]['formatted_address'] : '';
                            if (!empty($latitude) && !empty($longitude)) {
                                $cords_array['lat'] = $latitude;
                                $cords_array['lng'] = $longitude;
                            }
                        }
                    }
                }
            }
            if ($cords_array['lat'] == '' || $cords_array['lng'] == '') {
                $mapbox_api_key = isset($foodsearch_plugin_settings['api_settings']['mapbox_api']) ? $foodsearch_plugin_settings['api_settings']['mapbox_api'] : '';
                if ($mapbox_api_key != '') {
                    $geo_loc_url = 'https://api.mapbox.com/geocoding/v5/mapbox.places/' . urlencode($address) . '.json?access_token=' . $mapbox_api_key;
                    $location_geo = wp_remote_get($geo_loc_url);
                    if (!is_wp_error($location_geo)) {
                        if (isset($location_geo['body'])) {
                            $cords_info = json_decode($location_geo['body'], true);
                            $format_address = isset($cords_info['features'][0]['place_name']) ? $cords_info['features'][0]['place_name'] : '';
                            $cords = isset($cords_info['features'][0]['geometry']['coordinates']) ? $cords_info['features'][0]['geometry']['coordinates'] : '';
                            $latitude = isset($cords[1]) ? $cords[1] : '';
                            $longitude = isset($cords[0]) ? $cords[0] : '';
                            if (!empty($latitude) && !empty($longitude)) {
                                $cords_array['lat'] = $latitude;
                                $cords_array['lng'] = $longitude;
                            }
                        }
                    }
                }
            }
        }
        
        return $cords_array;
    }    
    public function get_default_latlng() {
        global $foodsearch_plugin_settings, $foodsearch_countries_list;
        
        $cachetime = 3600;
        $transient = 'foodsearch_client_default_latlng';
        $check_transient = get_transient($transient);
        if (!empty($check_transient)) {
            $latlng = $check_transient;
            return $latlng;
        }
        
        $default_country = isset($foodsearch_plugin_settings['location_settings']['default_country']) ? $foodsearch_plugin_settings['location_settings']['default_country'] : '';
        if (is_array($default_country) && isset($default_country[0])) {
            $default_country = $default_country[0];
        }
        
        $lat = $lng = '';
        if ($default_country != '' && isset($foodsearch_countries_list[$default_country])) {
            $country_name = $foodsearch_countries_list[$default_country];
            $latlng_arr = $this->get_latlng_from_address($country_name);
            $lat = $latlng_arr['lat'];
            $lng = $latlng_arr['lng'];
        }
        if ($lat == '' || $lng == '') {
            $lat = $this->default_lat;
            $lng = $this->default_lng;
        }
        $latlng = array($lat, $lng);
        set_transient($transient, $latlng, $cachetime);
        
        return $latlng;
    }    
    public function get_map_cords_address() {
        $lat = (isset($_POST['lat'])) ? $_POST['lat'] : '';
        $lng = (isset($_POST['lng'])) ? $_POST['lng'] : '';

        $response_array = $this->get_address_from_latlng($lat, $lng);
        
        wp_send_json($response_array);
    }   
    public function set_user_current_address() {
        
        $lat = (isset($_POST['lat'])) ? $_POST['lat'] : '';
        $lng = (isset($_POST['lng'])) ? $_POST['lng'] : '';

        $response_array = $this->get_address_from_latlng($lat, $lng);
        
        wp_send_json($response_array);
    }    
    public static function user_current_location() {
        $geoloc = User_Geolocation::geolocate_ip('', true, true);
        
        return $geoloc;
    }
    

}

new User_Locations;
