<?php

namespace FoodSearch\Emails\Customer;

use FoodSearch\Emails;
use FoodSearch\Common_Functions;
use FoodSearch\user_orders as FoodSearch_Orders;

class OnHold_Order extends Emails {

    public $id;
    public $name;
    public $description;
    public $group;
    public $template_codes;
    public $recipients;
    public $subject;
    public $content;
    //
    public $order_id;

    public function __construct() {
        add_action('init', array($this, 'init'),50);

        add_action('foodsearch_notify_to_customer_onhold_order', array($this, 'send_email'));
    }

    public function init() {
        $this->id = 'to_customer_onhold_order';
        $this->name = esc_html__('onhold order notification to customer', 'wp-foodsearch');
        $this->description = esc_html__('email will generate and send to customer for each onhold order.', 'wp-foodsearch');
        $this->group = 'customer';
        $this->template_codes = array(
            array(
                'var' => '{order_id}',
                'display_text' => esc_html__('order id', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_order_id'),
            ),
            array(
                'var' => '{restaurant_name}',
                'display_text' => esc_html__('restaurant name', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_restaurant_name'),
            ),
            array(
                'var' => '{customer_name}',
                'display_text' => esc_html__('customer name', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_customer_name'),
            ),
            array(
                'var' => '{order_detail}',
                'display_text' => esc_html__('order detail', 'wp-foodsearch'),
                'function_callback' => array($this, 'get_order_detail'),
            ),
        );
        
        $this->subject = esc_html__('order is on-hold', 'wp-foodsearch');
        
        ob_start();
        foodsearch_get_template_part('html', 'onhold-order', 'emails/customer');
        $this->content = ob_get_clean();
    }

    public function get_email_type() {
        return 'html';
    }

    public function get_content_type() {
        switch ($this->get_email_type()) {
            case 'html':
                $content_type = 'text/html';
                break;
            case 'multipart':
                $content_type = 'multipart/alternative';
                break;
            default:
                $content_type = 'text/plain';
                break;
        }

        return apply_filters('foodsearch_email_content_type', $content_type, $this);
    }

    public function get_headers() {
        $header = 'Content-Type: ' . $this->get_content_type() . "\r\n";

        $order_id = $this->order_id;
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);

        $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');
        $restaurant_user_id = Common_Functions::restaurant_user_id($restaurant_id);
        $user_obj = get_user_by('id', $restaurant_user_id);

        $from_name = '';
        if (get_post_type($restaurant_id) == 'restaurants') {
            $from_name = get_the_title($restaurant_id);
        }
        
        $from_email = isset($user_obj->user_email) ? $user_obj->user_email : '';
        
        if ($from_name != '' && $from_email != '') {
            $header .= 'Reply-to: ' . $from_name . ' <' . $from_email . ">\r\n";
        } else if ($this->get_from_address() && $this->get_from_name()) {
            $header .= 'Reply-to: ' . $this->get_from_name() . ' <' . $this->get_from_address() . ">\r\n";
        }

        return apply_filters('foodsearch_email_headers', $header, $this);
    }

    public function send_email($order_id) {
        global $foodsearch_plugin_settings;

        $this->order_id = $order_id;

        $emial_switch = isset($foodsearch_plugin_settings['customer_email_setins']['onhold_order_email']) ? $foodsearch_plugin_settings['customer_email_setins']['onhold_order_email'] : '';

        if ($emial_switch == 'on') {

            $order_meta = FoodSearch_Orders::get_order_meta($order_id);

            $to = FoodSearch_Orders::order_meta_value($order_meta, 'billing_email');
            $subject = $this->subject;
            
            $codes = $this->template_codes;
            $email_template = $this->content;
            
            $subject = $this->replace_variables($subject, $codes);

            $message = $this->replace_variables($email_template, $codes);
            
            $headers = $this->get_headers();
            $attachments = '';

            $send_mail = $this->send($to, $subject, $message, $headers, $attachments, $this);
        }
    }

    public function get_order_id() {
        $order_id = $this->order_id;

        $ret_value = '-';
        
        if ($order_id != '') {
            $ret_value = $order_id;
        }

        return $ret_value;
    }

    public function get_restaurant_name() {
        $order_id = $this->order_id;

        $ret_value = '-';
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $restaurant_id = FoodSearch_Orders::order_meta_value($order_meta, 'restaurant_id');
        if (get_post_type($restaurant_id) == 'restaurants') {
            $ret_value = get_the_title($restaurant_id);
        }

        return $ret_value;
    }

    public function get_customer_name() {
        $order_id = $this->order_id;

        $ret_value = '-';
        
        $order_meta = FoodSearch_Orders::get_order_meta($order_id);
        $first_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_first_name');
        $last_name = FoodSearch_Orders::order_meta_value($order_meta, 'billing_last_name');
        
        if ($first_name != '') {
            $ret_value = $first_name . ' ' . $last_name;
        }

        return $ret_value;
    }

    public function get_order_detail() {
        global $foodsearch_user_orders_obj;
        $order_id = $this->order_id;

        $ret_value = '-';
        
        $detail_html = $foodsearch_user_orders_obj->in_mail_customer_orderdetail($order_id);
        if ($detail_html != '') {
            $ret_value = $detail_html;
        }

        return $ret_value;
    }

}

new OnHold_Order;
