<?php

namespace FoodSearch;

use FoodSearch\Distance_Check;

class Common_Functions {
    
    public function __construct() {
        
        add_action('init', array($this, 'set_plugin_locale'), 5);
        
        add_action('init', array($this, 'restrict_user_from_wp_admin'),20);
        add_action('admin_init', array($this, 'restrict_user_from_wp_admin'),15);
    }

    public function set_plugin_locale() {
        $this->set_locale();
    }
    
    private function set_locale() {

        if (function_exists('determine_locale')) {
            $locale = determine_locale();
        } else {
            // @todo Remove when start supporting WP 5.0 or later.
            $locale = is_admin() ? get_user_locale() : get_locale();
        }
        $locale = apply_filters('plugin_locale', $locale, 'wp-foodsearch');
        unload_textdomain('wp-foodsearch');
        load_textdomain('wp-foodsearch', WP_LANG_DIR . '/plugins/wp-foodsearch-' . $locale . '.mo');
        load_plugin_textdomain('wp-foodsearch', false, dirname(dirname(plugin_basename(__FILE__))) . '/languages');
    }
    
    public static function user_type($user_id) {
        $user_type = get_user_meta($user_id, 'foodsearch_user_type', true);
        
        return $user_type;
    }
    
    public static function user_restaurant_id($user_id) {
        global $wpdb;
        
        if (self::user_type($user_id) != 'restaurant') {
            return false;
        }
        
        $post_query = "SELECT posts.ID FROM $wpdb->posts AS posts";
        $post_query .= " WHERE posts.post_type='restaurants' AND posts.post_status='publish' AND posts.post_author={$user_id}";
        $post_query .= " ORDER BY posts.ID DESC LIMIT 1";
        $get_db_res = $wpdb->get_col($post_query);
        
        if (!empty($get_db_res) && isset($get_db_res[0])) {
            return $get_db_res[0];
        } else {
            $post_query = "SELECT posts.ID FROM $wpdb->posts AS posts";
            $post_query .= " WHERE posts.post_type='restaurants' AND posts.post_author={$user_id}";
            $post_query .= " ORDER BY posts.ID DESC LIMIT 1";
            $get_db_res = $wpdb->get_col($post_query);

            if (!empty($get_db_res) && isset($get_db_res[0])) {
                return $get_db_res[0];
            }
        }
    }
    
    public static function restaurant_user_id($restaurant_id) {
        global $wpdb;
        
        $post_query = "SELECT posts.post_author FROM $wpdb->posts AS posts";
        $post_query .= " WHERE posts.post_type='restaurants' AND posts.ID={$restaurant_id}";
        $post_query .= " LIMIT 1";
        $get_db_res = $wpdb->get_col($post_query);
        
        if (!empty($get_db_res) && isset($get_db_res[0])) {
            return $get_db_res[0];
        }
    }
    
    public static function user_customer_id($user_id) {
        global $wpdb;
        
        if (self::user_type($user_id) != 'customer') {
            return false;
        }
        
        $post_query = "SELECT posts.ID FROM $wpdb->posts AS posts";
        $post_query .= " WHERE posts.post_type='customers' AND posts.post_author={$user_id}";
        $post_query .= " ORDER BY posts.ID DESC LIMIT 1";
        $get_db_res = $wpdb->get_col($post_query);
        
        if (!empty($get_db_res) && isset($get_db_res[0])) {
            return $get_db_res[0];
        }
    }
    
    public static function customer_user_id($customer_id) {
        global $wpdb;
        
        $post_query = "SELECT posts.post_author FROM $wpdb->posts AS posts";
        $post_query .= " WHERE posts.post_type='customers' AND posts.ID={$customer_id}";
        $post_query .= " LIMIT 1";
        $get_db_res = $wpdb->get_col($post_query);
        
        if (!empty($get_db_res) && isset($get_db_res[0])) {
            return $get_db_res[0];
        }
    }
    
    public static function curency_symbol($for = '') {
        global $woocommerce, $foodsearch_plugin_settings, $foodsearch_currencies_list;

        $def_currency_code = isset($foodsearch_plugin_settings['general_options']['foodsearch_default_currency']) ? $foodsearch_plugin_settings['general_options']['foodsearch_default_currency'] : '';
        $def_currency = isset($foodsearch_currencies_list[$def_currency_code]['symbol']) ? $foodsearch_currencies_list[$def_currency_code]['symbol'] : '';

        $currency_sign = $def_currency != '' ? $def_currency : '$';

        $currency_sign = apply_filters('foodsearch_default_currency_symbol', $currency_sign, $for);

        return $currency_sign;
    }
    
    public static function get_formatted_price($price = 0, $for = '', $cur_tag = '') {
        global $foodsearch_plugin_settings;
        if(isset($foodsearch_plugin_settings['payment_settings']['wc_cart_active']) && $foodsearch_plugin_settings['payment_settings']['wc_cart_active']=='on' &&  class_exists( 'WooCommerce' ))
       {
        $ret_price = wc_price($price ,true);
       }
       else{

            $price = preg_replace("/[^0-9.,]+/iu", "", $price);
            $price = $price > 0 ? $price : 0;
            
            $cur_pos = isset($foodsearch_plugin_settings['general_options']['foodsearch_currency_pos']) && $foodsearch_plugin_settings['general_options']['foodsearch_currency_pos'] != '' ? $foodsearch_plugin_settings['general_options']['foodsearch_currency_pos'] : 'left';
            $thousnd_sep = isset($foodsearch_plugin_settings['general_options']['foodsearch_currency_separator']) && $foodsearch_plugin_settings['general_options']['foodsearch_currency_separator'] != '' ? $foodsearch_plugin_settings['general_options']['foodsearch_currency_separator'] : ',';
            $decimal_sep = isset($foodsearch_plugin_options['general_options']['foodsearch_cur_decimal_separator']) && $foodsearch_plugin_options['general_options']['foodsearch_cur_decimal_separator'] != '' ? $foodsearch_plugin_options['general_options']['foodsearch_cur_decimal_separator'] : '.';
            $num_decimls = isset($foodsearch_plugin_settings['general_options']['foodsearch_currency_numdecmls']) && $foodsearch_plugin_settings['general_options']['foodsearch_currency_numdecmls'] != '' ? $foodsearch_plugin_settings['general_options']['foodsearch_currency_numdecmls'] : '2';

            $price = str_replace(array(','), array('.'), $price);
            $price_exp = explode('.', $price);
            if (!empty($price_exp) && count($price_exp) > 1 && $thousnd_sep == '.') {
                $price = str_replace(array('.'), array(''), $price);
            }
            if ($price == '') {
                $price = 0;
            }

            //
            $currency_sign = self::curency_symbol($for);
            $formted_price_str = number_format($price, $num_decimls, $decimal_sep, $thousnd_sep);

            if ($cur_pos == 'left_space') {
                $ret_price = ($cur_tag != '' ? '<' . $cur_tag . '>' : '') . $currency_sign . ' ' . ($cur_tag != '' ? '</' . $cur_tag . '>' : '') . $formted_price_str;
            } else if ($cur_pos == 'right') {
                $ret_price = $formted_price_str . ($cur_tag != '' ? '<' . $cur_tag . '>' : '') . $currency_sign . ($cur_tag != '' ? '</' . $cur_tag . '>' : '');
            } else if ($cur_pos == 'right_space') {
                $ret_price = $formted_price_str . ($cur_tag != '' ? '<' . $cur_tag . '>' : '') . ' ' . $currency_sign . ($cur_tag != '' ? '</' . $cur_tag . '>' : '');
            } else {
                $ret_price = ($cur_tag != '' ? '<' . $cur_tag . '>' : '') . $currency_sign . ($cur_tag != '' ? '</' . $cur_tag . '>' : '') . $formted_price_str;
            }

            $ret_price = apply_filters('foodsearch_return_formatted_price', $ret_price, $cur_tag, $price, $for);
        }
        return $ret_price;
    }
    
    public function array_merge_with_keys($array1, $array2) {
        
        $array2 = !empty($array2) ? $array2 : array();
        if (!empty($array1)) {
            foreach ($array1 as $arr1_key => $arr1_val) {
                if (!isset($array2[$arr1_key])) {
                    $array2[$arr1_key] = $arr1_val;
                }
            }
        }
        return $array2;
    }
    
    public function get_member_locs_address($member_id) {
        
        $locs_list = get_post_meta($member_id, 'foodsearch_locations_list', true);
        if (!empty($locs_list)) {
            $location_itm = '';
            foreach ($locs_list as $loc_itm) {
                $location_itm = $loc_itm;
                break;
            }
            return $location_itm;
        }
    }
    
    public static function restaurant_distance_from_user_loc($visitor_location = '', $restaurant_id = '') {
        
        $restaurant_locs = get_post_meta($restaurant_id, 'foodsearch_locations_list', true);
        if (!empty($restaurant_locs) && isset($visitor_location['lat']) && $visitor_location['lat'] != '' && $visitor_location['lng'] != '') {
            $user_geo_lat = $visitor_location['lat'];
            $user_geo_lng = $visitor_location['lng'];
            $dist_address = array();
            foreach ($restaurant_locs as $addr_loc_id => $addr_loc_itm) {
                $addr_lat = $addr_loc_itm['lat'];
                $addr_lng = $addr_loc_itm['lng'];
                
                $distance_km = Distance_Check::calculate($user_geo_lat, $user_geo_lng, $addr_lat, $addr_lng, 'K', $restaurant_id);
                //echo $restaurant_id . ' [] ' . $addr_lat . ' ; ' . $addr_lng . ' - ' . ($distance_km) . ' || ' . "\n";
                if ($distance_km > 0) {
                    $dist_address[] = array(
                        'address' => $addr_loc_itm['address'],
                        'lat' => $addr_lat,
                        'lng' => $addr_lng,
                        'distance' => $distance_km,
                    );
                }
            }
            //if (!empty($dist_address) && count($dist_address) > 1) {
                usort($dist_address, function ($a, $b) {
                    if ($a['distance'] == $b['distance']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($a['distance'] < $b['distance']) ? -1 : 1;
                    return $ret_val;
                });
            //}
            
            return $dist_address;
        }
    }

    public function get_restaurant_nutritions($restaurant_id) {
        $nutritions_list = get_post_meta($restaurant_id, 'foodsearch_nutritions_list', true);
        
        return $nutritions_list;
    }
    
    public function get_menu_item_nutritions($restaurant_id, $menu_item_id) {
        global $table_prefix, $wpdb;
        
        $restaurant_nutritions = $this->get_restaurant_nutritions($restaurant_id);
        
        $table_name = $table_prefix . 'menu_itemmeta';
        $meta_query = "SELECT meta_value FROM $table_name WHERE menu_item_id=$menu_item_id AND meta_key='item_nutritions'";
        $menu_nutris = $wpdb->get_col($meta_query);
        
        $menu_item_nutrilist = '';
        if (isset($menu_nutris[0])) {
            $menu_nutris_val = $menu_nutris[0];
            $menu_nutris_val = explode(',', $menu_nutris_val);
            
            if (!empty($menu_nutris_val)) {
                $menu_item_nutrilist = array();
                
                foreach ($menu_nutris_val as $menu_nutri_itm) {
                    if (isset($restaurant_nutritions[$menu_nutri_itm])) {
                        $menu_item_nutrilist[$menu_nutri_itm] = $restaurant_nutritions[$menu_nutri_itm];
                    }
                }
            }
        }
        
        return $menu_item_nutrilist;
    }
    
    public function restaurant_fav_list($id, $type = 'restaurant') {
        if ($type == 'customer') {
            $post_type = 'restaurants';
            $fav_itms = get_post_meta($id, 'foodsearch_favourite_restaurants', true);
        } else {
            $post_type = 'customers';
            $fav_itms = get_post_meta($id, 'foodsearch_favourite_by_list', true);
        }
        
        if (!empty($fav_itms)) {
            $filter_itms = [];
            foreach ($fav_itms as $fav_itm) {
                $post_id = $fav_itm['id'];
                if (get_post_type($post_id) == $post_type) {
                    $filter_itms[] = $fav_itm;
                }
            }
            if (!empty($filter_itms)) {
                uasort($filter_itms, function ($a, $b) {
                    if ($a['time'] == $b['time']) {
                        $ret_val = 0;
                    }
                    $ret_val = ($b['time'] < $a['time']) ? -1 : 1;
                    return $ret_val;
                });
                
                return $filter_itms;
            }
        }
    }
            
    public static function is_restaurant_fav_by_customer($user_id, $restaurant_id) {

        $customer_id = self::user_customer_id($user_id);
        $fav_itms = get_post_meta($customer_id, 'foodsearch_favourite_restaurants', true);
        if (!empty($fav_itms)) {
            foreach ($fav_itms as $fav_itm) {
                if (isset($fav_itm['id']) && $fav_itm['id'] == $restaurant_id) {
                    return $fav_itm;
                }
            }
        }
    }
    
    public function restrict_user_from_wp_admin() {
        global $pagenow, $current_user;
        //
        if (is_super_admin() || current_user_can('administrator')) {
            return false;
        }
        
        $to_view = true;
        
        $user_id = isset($current_user->ID) ? $current_user->ID : 0;
        
        $customer_id = self::user_customer_id($user_id);
        $restaurant_id = self::user_restaurant_id($user_id);
        
        if ($customer_id > 0 || $restaurant_id > 0 || current_user_can('subscriber')) {
            $to_view = false;
        }
        
        if (is_admin()) {
            if ($pagenow == 'admin-ajax.php' || $pagenow == 'async-upload.php') {
                $to_view = true;
            }
            if ($to_view === false) {
                $home_url = home_url('/');
                wp_redirect($home_url);
                exit();
            }
        }
    }
            
    public static function restaurant_fav_btn_html($restaurant_id, $view = '', $is_user = 0) {
        
        if ($is_user > 0) {
            $is_user_loggedin = true;
            $user_id = $is_user;
        } else {
            $is_user_loggedin = is_user_logged_in();
            $user_id = get_current_user_id();
        }

        $alredy_added_tofav = self::is_restaurant_fav_by_customer($user_id, $restaurant_id);
        
        if ($alredy_added_tofav) {
            if ($view == 'el') {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav added-to-favourite"><i class="fds-icon fds-heart-fill"></i></a>
                <?php
            } else if ($view == 'list') {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav fds-restaurant-grid-like added-to-favourite fds-link"><i class="fds-icon fds-heart-fill"></i></a>
                <?php
            } else {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav fds-has-bg added-to-favourite fds-link"><i class="fds-icon fds-heart-fill"></i> <?php esc_html_e('added to favourite', 'wp-foodsearch') ?></a>
                <?php
            }
        } else {
            if ($view == 'el') {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav <?php echo (!$is_user_loggedin ? ' foodsearch-user-loginform-open' : '') ?>" data-id="<?php echo ($restaurant_id) ?>" data-view="<?php echo ($view) ?>"<?php echo ($is_user_loggedin ? ' data-nid="' . $user_id . '"' : '') ?>><i class="fds-icon fds-heart-line"></i></a>
                <?php
            } else if ($view == 'list') {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav fds-restaurant-grid-like<?php echo (!$is_user_loggedin ? ' foodsearch-user-loginform-open' : '') ?> fds-link" data-id="<?php echo ($restaurant_id) ?>" data-view="<?php echo ($view) ?>"<?php echo ($is_user_loggedin ? ' data-nid="' . $user_id . '"' : '') ?>><i class="fds-icon fds-heart-line"></i></a>
                <?php
            } else {
                ?>
                <a href="#" class="fds-restaurnt-addto-fav<?php echo (!$is_user_loggedin ? ' foodsearch-user-loginform-open' : '') ?> fds-has-bg fds-link" data-id="<?php echo ($restaurant_id) ?>" data-view="<?php echo ($view) ?>"<?php echo ($is_user_loggedin ? ' data-nid="' . $user_id . '"' : '') ?>><i class="fds-icon fds-heart-line"></i> <?php esc_html_e('add to favorite', 'wp-foodsearch') ?></a>
                <?php
            }
        }
    }
    
    public function restaurant_hours_settings($restaurant_id) {
        global $foodsearch_form_fields;
        
        $daysArray = array(
            array('day' => esc_html__('monday', 'wp-foodsearch'), 'key' => 'monday'),
            array('day' => esc_html__('tuesday', 'wp-foodsearch'), 'key' => 'tuesday'),
            array('day' => esc_html__('wednesday', 'wp-foodsearch'), 'key' => 'wednesday'),
            array('day' => esc_html__('thursday', 'wp-foodsearch'), 'key' => 'thursday'),
            array('day' => esc_html__('friday', 'wp-foodsearch'), 'key' => 'friday'),
            array('day' => esc_html__('saturday', 'wp-foodsearch'), 'key' => 'saturday'),
            array('day' => esc_html__('sunday', 'wp-foodsearch'), 'key' => 'sunday')
        );
        ?>
        <div class="fds-opening-time-wraper">
            <div class="fds-opening-time-con">
                <div class="fds-opening-time-thead">
                    <div><?php esc_html_e('day', 'wp-foodsearch') ?></div>
                    <div><?php esc_html_e('opening hours', 'wp-foodsearch') ?></div>
                    <div><?php esc_html_e('closing hours', 'wp-foodsearch') ?></div>
                    <div><?php esc_html_e('open/closed', 'wp-foodsearch') ?></div>
                </div>
                <?php
                foreach ($daysArray as $day) {
                    $opening_hour = get_post_meta($restaurant_id, 'restaurant_' . $day['key'] . '_opening_hour', true);
                    $closing_hour = get_post_meta($restaurant_id, 'restaurant_' . $day['key'] . '_closing_hour', true);
                    $restaurant_status = get_post_meta($restaurant_id, 'restaurant_' . $day['key'] . '_status', true);
                    ?>
                    <div class="fds-opening-time-tbody">
                        <div class="fds-opening-time-cell"><?= $day['day']; ?></div>
                        <div class="fds-opening-time-cell">
                            <div class="opening-hours-field">
                                <div class="fds-select-field">
                                    <select name="restaurant_<?= $day['key'] ?>_opening_hour" data-placeholder="<?php esc_html_e('select opening time', 'wp-foodsearch') ?>" class="select_dropdown">
                                        <option value=""><?php echo esc_html__('select opening time', 'wp-foodsearch'); ?></option>
                                        <?php
                                        for ($i = 0; $i < 24; $i++) {
                                            for ($x = 0; $x <= 3; $x++) {
                                                $val = $i . ':' . (($x * 15) == 0 ? '00' : ($x * 15));
                                                echo '<option value="' . $val . '" ' . ($opening_hour == $val ? 'selected' : '') . '>' . $val . '</option>';
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="fds-opening-time-cell">
                            <div class="opening-hours-field">
                                <div class="fds-select-field">
                                    <select name="restaurant_<?= $day['key'] ?>_closing_hour" data-placeholder="<?php esc_html_e('select closing time', 'wp-foodsearch') ?>" class="select_dropdown">
                                        <option value=""><?php echo esc_html__('select closing time', 'wp-foodsearch'); ?></option>
                                        <?php
                                        for ($i = 0; $i < 24; $i++) {
                                            for ($x = 0; $x <= 3; $x++) {
                                                $val = $i . ':' . (($x * 15) == 0 ? '00' : ($x * 15));
                                                echo '<option value="' . $val . '" ' . ($closing_hour == $val ? 'selected' : '') . '>' . $val . '</option>';
                                            }
                                        }
                                        ?>
                                    </select>
                                </div>
                            </div>
                        </div>
                        <div class="fds-opening-time-cell"> 
                            <div class="filed-group">
                                <?php
                                $args = array(
                                    'id' => 'restaurant_' . $day['key'] . '_status',
                                    'name' => 'restaurant_' . $day['key'] . '_status',
                                    'classes' => 'fds-intig-val',
                                    'value' => $restaurant_status,
                                );
                                $foodsearch_form_fields->switch_field($args);
                                ?>
                            </div>
                        </div>
                    </div>
                    <?php
                }
                ?>
            </div>
        </div>
        <?php
    }

}

global $foodsearch_common_functions;

$foodsearch_common_functions = new Common_Functions;
