<?php

namespace FoodSearch\User_Forms;

class Submit_Form {

    public function __construct() {
        add_action('rest_api_init', [$this, 'register_api'], 5);
    }
    
    public function register_api() {

        register_rest_route('wp/v1', 'user-login-check', array(
            'methods' => 'POST',
            'callback' => [$this, 'user_login_rest'],
           'permission_callback' =>  'admin_permissions_check',
        ));
    }
    
    public static function verify_nonce($post_key, $nonce_key) {
        if (defined("WP_CACHE")) {
            return true;
        }

        if (!isset($_POST[$post_key]) || !wp_verify_nonce($_POST[$post_key], $nonce_key)) {
            wp_send_json(array('msg' => esc_html__('session token has expired, please reload the page and try again.', 'wp-foodsearch'), 'error' => '2'));
        }
    }
    
    public function signup() {
        self::verify_nonce('security-signup', 'ajax-signup-nonce');
        
        global $foodsearch_plugin_settings;

        $username = isset($_POST['username']) ? foodsearch_esc_html($_POST['username']) : '';
        $user_email = isset($_POST['user_email']) ? foodsearch_esc_html($_POST['user_email']) : '';
        $user_pass = isset($_POST['user_pass']) ? $_POST['user_pass'] : '';
        $user_cpass = isset($_POST['confirm_pass']) ? $_POST['confirm_pass'] : '';
        
        if (!filter_var($user_email, FILTER_VALIDATE_EMAIL)) {
            $ret_data = array('error' => '1', 'msg' => esc_html__('please use a valid email address.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        
        $approval_type = isset($foodsearch_plugin_settings['register_settings']['user_approval_type']) ? $foodsearch_plugin_settings['register_settings']['user_approval_type'] : '';
        if ($approval_type != 'email_verify') {

            if ($user_pass == '') {
                $ret_data = array('error' => '1', 'msg' => esc_html__('password field cannot be empty.', 'wp-foodsearch'));
                wp_send_json($ret_data);
            }
            if ($user_pass != $user_cpass) {
                $ret_data = array('error' => '1', 'msg' => esc_html__('confirm password field does not match with the password field.', 'wp-foodsearch'));
                wp_send_json($ret_data);
            }
        } else {
            $user_pass = wp_generate_password();
        }
        
        $user_id = wp_create_user($username, $user_pass, $user_email);

        if (is_wp_error($user_id)) {
            $errors = implode('<br/>', $user_id->get_error_messages());
            wp_send_json(array(
                'msg' => wp_kses($errors, array('br' => array(), 'strong' => array(), 'p' => array())),
                'error' => '1'
            ));
        }
        
        $userdata = array(
            'ID' => $user_id,
        );

        $display_name = '';
        if (isset($_POST['first_name'])) {
            $first_name = foodsearch_esc_html($_POST['first_name']);
            $display_name = $first_name;
            $userdata['first_name'] = $first_name;
        }
        if (isset($_POST['last_name'])) {
            $last_name = foodsearch_esc_html($_POST['last_name']);
            if ($last_name != '' && $display_name != '') {
                $display_name .= ' ' . $last_name;
            }
            $userdata['last_name'] = $last_name;
        }
        if ($display_name != '') {
            $userdata['display_name'] = $display_name;
        }
        
        //
        if (isset($userdata['first_name'])) {
            wp_update_user($userdata);
        }
        
        //remove user admin bar
        update_user_option($user_id, 'show_admin_bar_front', false);
        
        if ($approval_type == 'email_verify') {
            wp_new_user_notification($user_id);
        }
        
        wp_send_json(array('msg' => esc_html__('thank you for create an account', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function login_common($args = array()) {
        global $foodsearch_plugin_settings;
        
        $dashboard_page = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        $dashboard_page_id = $dashboard_page != '' ? foodsearch__get_post_id($dashboard_page) : '';
        
        $dashpage_id = 0;
        if ($dashboard_page_id > 0 && get_post_type($dashboard_page_id) == 'page') {
            $dashpage_id = $dashboard_page_id;
        }
        $redrect_url = home_url('/');
        if ($dashpage_id > 0) {
            $redrect_url = get_permalink($dashpage_id);
        }
        
        $place = isset($args['place']) ? $args['place'] : '';
        
        if ($place != 'rest') {
            self::verify_nonce('security-login', 'ajax-login-nonce');
        }
        
        $username = isset($_POST['username']) ? $_POST['username'] : '';
        $user_pass = isset($_POST['user_pass']) ? $_POST['user_pass'] : '';
        $remember_me = isset($_POST['remember_me']) ? true : false;
        
        if ($username == '') {
            $ret_data = array('error' => '1', 'msg' => esc_html__('username/email field cannot be empty.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }

        if ($user_pass == '') {
            $ret_data = array('error' => '1', 'msg' => esc_html__('password field cannot be empty.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }

        if ($place == 'rest') {
            $user = wp_authenticate($username, $user_pass);
            if (!is_wp_error($user) && isset($user->first_name)) {
                wp_send_json(array('msg' => esc_html__('logged in successfully.', 'wp-foodsearch'), 'error' => '0'));
            } else {
                $ret_data = array('error' => '1', 'msg' => esc_html__('no user record found.', 'wp-foodsearch'));
                wp_send_json($ret_data);
            }
        }
        
        $user_name = sanitize_user($username);
        $user = get_user_by('login', $user_name);
        if (!$user && strpos($username, '@')) {
            $user = get_user_by('email', $username);
        }
        
        $secure_cookie = is_ssl();
        if (!$secure_cookie && $user && !force_ssl_admin()) {
            if (get_user_option('use_ssl', $user->ID)) {
                $secure_cookie = true;
                force_ssl_admin(true);
            }
        }
        
        $user_info = array();
        $user_info['user_login'] = sanitize_text_field(trim($username));
        $user_info['user_password'] = trim($user_pass);
        $user_info['remember'] = $remember_me;
        
        $user_signon = wp_signon($user_info, $secure_cookie);
        
        if (is_wp_error($user_signon)) {
            $errors = implode('<br/>', $user_signon->get_error_messages());
            wp_send_json(array(
                'msg' => wp_kses($errors, array('br' => array(), 'strong' => array(), 'p' => array())),
                'error' => '1'
            ));
        }
        
        wp_send_json(array('msg' => esc_html__('logged in successfully.', 'wp-foodsearch'), 'error' => '0', 'redirect' => $redrect_url));
    }
    
    public function login() {
        $this->login_common();
    }
    
    public function forgot_pass() {
        self::verify_nonce('security-forgotpass', 'ajax-forgotpass-nonce');
        
        global $foodsearch_plugin_settings;
        $dashboard_page = isset($foodsearch_plugin_settings['dashboard_settings']['dashboard_page']) ? $foodsearch_plugin_settings['dashboard_settings']['dashboard_page'] : '';
        $dashboard_page_id = $dashboard_page != '' ? foodsearch__get_post_id($dashboard_page) : '';
        
        $dashpage_id = 0;
        if ($dashboard_page_id > 0 && get_post_type($dashboard_page_id) == 'page') {
            $dashpage_id = $dashboard_page_id;
        }
        
        $emial_template_switch = isset($foodsearch_plugin_settings['user_email_setins']['forgot_passwrod']) ? $foodsearch_plugin_settings['user_email_setins']['forgot_passwrod'] : '';
        
        $username = isset($_POST['username']) ? $_POST['username'] : '';
        
        if ($username == '') {
            $ret_data = array('error' => '1', 'msg' => esc_html__('username/email field cannot be empty.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        
        $user_name = sanitize_user($username);
        $user = get_user_by('login', $user_name);
        if (!$user && strpos($username, '@')) {
            $user = get_user_by('email', $username);
        }
        
        if (!$user) {
            $ret_data = array('error' => '1', 'msg' => esc_html__('invalid username or email entered.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        
        if ($dashpage_id > 0 && $emial_template_switch == 'on') {
            add_filter('send_password_change_email', '__return_false');
        }

        $password_reset_key = get_password_reset_key($user);
        if (is_wp_error($password_reset_key)) {
            $errors = implode('<br/>', $password_reset_key->get_error_messages());
            wp_send_json(array(
                'msg' => wp_kses($errors, array('br' => array(), 'strong' => array(), 'p' => array())),
                'error' => '1'
            ));
        }
        
        if ($dashpage_id > 0 && $emial_template_switch == 'on') {
            do_action('foodsearch_notify_to_user_forgot_password', $user, $password_reset_key);
        }
        
        wp_send_json(array('msg' => esc_html__('password reset link sent to your email address.', 'wp-foodsearch'), 'error' => '0'));
    }
    
    public function reset_pass() {
        self::verify_nonce('security-resetpass', 'ajax-forgotpass-nonce');
        
        global $foodsearch_plugin_settings;
        $login_page = isset($foodsearch_plugin_settings['register_settings']['loginreg_page']) ? $foodsearch_plugin_settings['register_settings']['loginreg_page'] : '';
        $login_page_id = $login_page != '' ? foodsearch__get_post_id($login_page) : '';
        
        $redirect_url = home_url('/');
        if ($login_page_id > 0 && get_post_type($login_page_id) == 'page') {
            $redirect_url = get_permalink($login_page_id);
        }
        
        $user_id = absint($_POST['uid']);
        $key = ($_POST['key']);
        
        $user_obj = get_user_by('id', $user_id);
        $user_login = isset($user_obj->user_login) ? $user_obj->user_login : '';
        
        $user = check_password_reset_key($key, $user_login);
        if (is_wp_error($user)) {
            $ret_data = array('error' => '1', 'msg' => esc_html__('this key is invalid or has already been used.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        
        $user_pass = isset($_POST['fds_user_password']) ? $_POST['fds_user_password'] : '';
        $user_cpass = isset($_POST['fds_user_confpass']) ? $_POST['fds_user_confpass'] : '';

        if ($user_pass == '') {
            $ret_data = array('error' => '1', 'msg' => esc_html__('password field cannot be empty.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        if ($user_pass != $user_cpass) {
            $ret_data = array('error' => '1', 'msg' => esc_html__('confirm password field does not match with the password field.', 'wp-foodsearch'));
            wp_send_json($ret_data);
        }
        
        do_action('password_reset', $user_obj, $user_pass);
        wp_set_password($user_pass, $user_obj->ID);
        
        wp_send_json(array('msg' => esc_html__('your password has been changed.', 'wp-foodsearch'), 'redirect' => $redirect_url, 'error' => '0'));
    }
    
    public function user_login_rest() {
        $args = array(
            'place' => 'rest',
        );
        $this->login_common($args);
    }

}

new Submit_Form;
