const { registerBlockType } = wp.blocks;
const { RichText, InspectorControls, BlockControls, AlignmentToolbar, BlockAlignmentToolbar, PanelColorSettings } = wp.blockEditor;
const { TabPanel, Button, ButtonGroup, ToggleControl, PanelBody, PanelRow, CheckboxControl, SelectControl, DateTimePicker, RadioControl, RangeControl, Toolbar, ToolbarGroup, ToolbarButton, TextControl  } = wp.components;
const { __ } = wp.i18n;
import { paragraph, formatBold, formatItalic, link } from '@wordpress/icons';
import { useState, useEffect } from '@wordpress/element';

import { select, withSelect, useSelect  } from '@wordpress/data';
import { __experimentalNumberControl as NumberControl } from '@wordpress/components';

import React from 'react';
import Select from 'react-select';

import WebFont from 'webfontloader';
import {Font} from "../assets/font.js";
import {Typography} from "../assets/Typography.js";
import {Padding} from "../assets/Padding.js";
import {Margin} from "../assets/Margin.js";
import {Border} from "../assets/Border.js";
import {Color} from "../assets/Color.js";
import {Background} from "../assets/Background.js";

function foodsearch_set_script_translations() {
  __( 'padding', 'wp-foodsearch' );
  __( 'top', 'wp-foodsearch' );
  __( 'right', 'wp-foodsearch' );
  __( 'bottom', 'wp-foodsearch' );
  __( 'left', 'wp-foodsearch' );
  __( 'top left', 'wp-foodsearch' );
  __( 'top right', 'wp-foodsearch' );
  __( 'bottom right', 'wp-foodsearch' );
  __( 'bottom left', 'wp-foodsearch' );
  __( 'margin', 'wp-foodsearch' );
  __( 'typography', 'wp-foodsearch' );
  __( 'font family', 'wp-foodsearch' );
  __( 'font weight', 'wp-foodsearch' );
  __( 'font style', 'wp-foodsearch' );
  __( 'transform', 'wp-foodsearch' );
  __( 'decoration', 'wp-foodsearch' );
  __( 'font size', 'wp-foodsearch' );
  __( 'line height', 'wp-foodsearch' );
  __( 'letter spacing', 'wp-foodsearch' );
  __( 'border type', 'wp-foodsearch' );
  __( 'width', 'wp-foodsearch' );
  __( 'border color', 'wp-foodsearch' );
  __( 'border radius', 'wp-foodsearch' );
  __( 'box shadow', 'wp-foodsearch' );
  __( 'shadow color', 'wp-foodsearch' );
  __( 'horizontal', 'wp-foodsearch' );
  __( 'vertical', 'wp-foodsearch' );
  __( 'blur', 'wp-foodsearch' );
  __( 'spread', 'wp-foodsearch' );
  __( 'position', 'wp-foodsearch' );
  __( 'background type', 'wp-foodsearch' );
  __( 'color 1', 'wp-foodsearch' );
  __( 'location 1', 'wp-foodsearch' );
  __( 'color 2', 'wp-foodsearch' );
  __( 'location 2', 'wp-foodsearch' );
  __( 'type', 'wp-foodsearch' );
  __( 'angle', 'wp-foodsearch' );
  __( 'position', 'wp-foodsearch' );
  __( 'image', 'wp-foodsearch' );
  __( 'attachment', 'wp-foodsearch' );
  __( 'repeat', 'wp-foodsearch' );
  __( 'size', 'wp-foodsearch' );
  
}

var googleFonts = [];
Font.items.map((item, index) => {
    googleFonts.push({value: item.family, label: item.family});
   
});
const Fonts = [
    { value: 'None', label: 'None' },
    { 
        label: "Standard Fonts",
        options: [
            { value: 'Arial', label: 'Arial' },
            { value: 'Tahoma', label: 'Tahoma' },
            { value: 'Verdana', label: 'Verdana' },
            { value: 'Helvitica', label: 'Helvitica' },
            { value: 'Times New Roman', label: 'Times New Roman' },
            { value: 'Trebuchet MS', label: 'Trebuchet MS' },
            { value: 'Georgia', label: 'Georgia' },
        ]
    },
    { 
        label: "Google Webfonts",
        options: googleFonts
    },

]

registerBlockType('foodsearch/restaurants', {
    title: __( 'restaurant listing', 'wp-foodsearch' ),
    getEditWrapperProps( { postBlockWidth } ) {
        if ( 'wide' === postBlockWidth || 'full' === postBlockWidth ) {
            return { 'data-align': postBlockWidth };
        }
    },

    edit: (props) => {
        const { plugin_dir_url } = localizedVariableName;
        const { attributes, setAttributes, clientId } = props;
        const { view_mod, postBlockWidth, align } = attributes;
        const { blockId } = attributes;
        var custom_block_id;
        if ( blockId ) custom_block_id = blockId.substr(0, 6);
        else custom_block_id = clientId.substr(0, 6);
            setAttributes( { blockId: custom_block_id } );

        function foodsearch_cssMount() {
            var elem = document.getElementById("res-listing-" + custom_block_id );
            var ih = "";
            if ( elem ) {
                ih = elem.innerHTML;
                elem.remove();
            }
            const $style = document.createElement("style");
            $style.setAttribute("id", "res-listing-" + custom_block_id );
            document.head.appendChild($style);
        }
        foodsearch_cssMount();

        const ALLOWED_MEDIA_TYPES = [ 'image' ];

        const { posts, authors } = useSelect ( ( select ) => {
            return {
                posts: select( 'core' ).getEntityRecords( 'postType', 'restaurants', { 'status ':'publish', 'per_page':attributes.number_of_items, 'orderby':'id', 'order':attributes.order_by, } ),
                authors: select( 'core' ).getUsers({ who: 'authors' }),
            };
        } );
        const { res_cat } = useSelect ( ( select ) => {
            return {
                res_cat: select('core').getEntityRecords('taxonomy', 'food_cuisine', {'per_page':-1, 'hide_empty': true })
            };
        } );

        const getPostAuthorName = ( author_id ) => {
            for(let author in authors){
                if( authors[author].id === author_id ){
                    return authors[author].name;
                }
            }
        };

        function foodsearch_getMediaURL2 (id){
            if ( id > 0 ) {
                const { image } = useSelect ( ( select ) => {
                    return {
                        image: wp.data.select('core').getEntityRecords('postType', 'attachment', { include: [id] })
                    };
                } );
                if ( image !== null ) {
                    return (image[0]['media_details']['sizes']['thumbnail'].source_url);
                }
            }
            else {
                return plugin_dir_url + "images/no-image.jpg"
            }
        }

        const getMediaURL = ( id ) => {
            if ( id > 0 ) {
                const image = select('core').getMedia(id);
                if (typeof(image) === "object") {
                    return image.source_url;
                }
            }
            else {
                return plugin_dir_url + "images/no-image.jpg";
            }
        };

        const count_res_cat = () => {
            var counter = 0;
            if ( res_cat && res_cat.length > 0 ){
                res_cat.map((cat) =>
                    counter += cat.count
                )
            }
            return counter
        };

        const layoutControls = [
            {
                icon: 'grid-view',
                title: __( 'grid view' ),
                onClick: () => setAttributes( { view_mod: 'grid' } ),
                isActive: view_mod === 'grid',
            },
            {
                icon: 'list-view',
                title: __( 'list view' ),
                onClick: () => setAttributes( { view_mod: 'list' } ),
                isActive: view_mod === 'list',
            },
        ];
       
        return (
            <div id={"fds-block-" + custom_block_id} className = {attributes.align + ' ' + attributes.view_mod + ' ' + attributes.postBlockWidth} >
            <div className="fds-row fds-typo-wrap">
            { attributes.filter_options === true &&
                <div className="fds-column-3">
                    { attributes.filter_by === true &&

                      <div className='plugin-filter fds-filter-radio'>
                        <div className='plugin-filter-wrap'>
                            <span className='plugin-filter-title'>{__( 'order by', 'wp-foodsearch' )}</span>
                            <ul className='fds-options-wrap order_by'>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-hand-thumb-line'></i> {__( 'best match', 'wp-foodsearch' )}</label></li>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-alphabetical'></i> {__( 'alphabetical', 'wp-foodsearch' )}</label></li>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-star-line'></i> {__( 'ratings', 'wp-foodsearch' )}</label></li>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-hotel'></i> {__( 'minimum order value', 'wp-foodsearch' )}</label></li>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-dollar-coin-circle'></i> {__( 'delivery fee', 'wp-foodsearch' )}</label></li>
                                <li className='fds-list-item'><label className='fds-radio-style'><i className='fds-icon fds-courier-bus'></i> {__( 'fastest delivery', 'wp-foodsearch' )}</label></li>
                            </ul>
                        </div>
                      </div>

                    }

                    { attributes.cuisine_type === true &&
                    <div className="plugin-filter fds-filter-radio">
                        <div className="plugin-filter-wrap">
                            <span className="plugin-filter-title">{__( 'cuisine type', 'wp-foodsearch' )}</span>
                            <ul className='fds-options-wrap'>
                                { ! res_cat && 'Loading... ' }
                                { res_cat && res_cat.length > 0 && (
                                    res_cat.map((cat) =>
                                        <li className='fds-list-item' key={cat.id}>
                                            <input type="radio" name="radio2" value="{cat.id}" />
                                            <label className="fds-radio-style">{cat.name}</label>
                                            <small>{cat.count}</small>
                                        </li>
                                    )
                                )}
                            </ul>
                        </div>
                    </div>
                    }

                    { attributes.options === true &&
                    <div className="plugin-filter fds-filter-radio">
                        <div className="plugin-filter-wrap">
                            <span className="plugin-filter-title">{__( 'options', 'wp-foodsearch' )}</span>
                            <ul className='fds-options-wrap'>
                                <li className='fds-list-item' key="k8">
                                    <input type="radio" name="radio3" value="6" />
                                    <label className="fds-radio-style">{__( 'delivery', 'wp-foodsearch' )}</label>
                                    <small>9</small>
                                </li>
                                <li className='fds-list-item' key="k9">
                                    <input id="radio7" type="radio" name="radio3" value="7" />
                                    <label className="fds-radio-style">{__( 'take away', 'wp-foodsearch' )}</label>
                                    <small>7</small>
                                </li>
                            </ul>
                        </div>
                    </div>
                    }

                    { attributes.rating === true &&
                    <div className="plugin-filter fds-filter-rating">
                        <div className="plugin-filter-wrap">
                            <span className="plugin-filter-title">{__( 'ratings', 'wp-foodsearch' )}</span>
                            <ul className='fds-options-wrap'>
                                <li className='fds-list-item' key="k12">
                                    <div className="fds-filter-radio">
                                        <input type="radio" name="radio1" value="10" />
                                        <label className="fds-radio-style">
                                            <div className="fds-rating-stars">
                                                <span className="fds-rating-stars-fill" style={{width: "78%"}} ></span>
                                            </div>
                                        </label>
                                    </div>
                                    <small className="fds-filter-rating-subtitle">78</small>
                                </li>
                                <li className='fds-list-item' key="k13">
                                    <div className="fds-filter-radio">
                                        <input type="radio" name="radio1" value="10" />
                                        <label className="fds-radio-style">
                                            <div className="fds-rating-stars">
                                                <span className="fds-rating-stars-fill" style={{width: "65%"}} ></span>
                                            </div>
                                        </label>
                                    </div>
                                    <small className="fds-filter-rating-subtitle">65</small>
                                </li>
                                <li className='fds-list-item' key="k14">
                                    <div className="fds-filter-radio">
                                        <input type="radio" name="radio1" value="10" />
                                        <label className="fds-radio-style">
                                            <div className="fds-rating-stars">
                                                <span className="fds-rating-stars-fill" style={{width: "32%"}} ></span>
                                            </div>
                                        </label>
                                    </div>
                                    <small className="fds-filter-rating-subtitle">32</small>
                                </li>
                                <li className='fds-list-item' key="k15">
                                    <div className="fds-filter-radio">
                                        <input type="radio" name="radio1" value="10" />
                                        <label className="fds-radio-style">
                                            <div className="fds-rating-stars">
                                                <span className="fds-rating-stars-fill" style={{width: "12%"}} ></span>
                                            </div>
                                        </label>
                                    </div>
                                    <small className="fds-filter-rating-subtitle">12</small>
                                </li>
                            </ul>
                        </div>
                    </div>
                    }

                </div>
                }
                <div className={attributes.filter_options ? "fds-column-9" : "fds-column-12" }>

                    { attributes.sort_options === true &&
                    <div className="fds-sorting-options fds-filter-radio">
                        <div className="fds-sorting-option">
                            { (attributes.highest_rated == true || attributes.most_reviewed == true || attributes.near_me == true) &&
                                <span className="fds-sorting-bytitle">{__( 'sort by:', 'wp-foodsearch' )}</span>
                            }
                                <ul className="fds-options-wrap fds-sorting-options-list">
                                    { attributes.highest_rated === true &&
                                        <li className='fds-list-item' key="k16"><a href="#"><i className="fds-icon fds-star1"></i> {__( 'highest rated', 'wp-foodsearch' )}</a></li>
                                    }
                                    { attributes.most_reviewed === true &&
                                        <li className='fds-list-item' key="k17"><a href="#"><i className="fds-icon fds-edit"></i> {__( 'most reviewed', 'wp-foodsearch' )}</a></li>
                                    }
                                </ul>
                        </div>
                        
                        { attributes.grid_list === true &&
                        <div className="fds-style-switch">
                            <ul className="fds-options-wrap fds-sorting-options-views">
                                <li className='fds-list-item' key="k19"><a href="#" className="fds-icon fds-list"></a></li>
                                <li className='fds-list-item' key="k20"><a href="#" className="fds-icon fds-menu"></a></li>
                            </ul>
                        </div>
                        }

                    </div>
                    }

                    { attributes.view_mod === "grid" &&
                        <div className="fds-restaurants fds-restaurant-grid">
                            <div className="fds-listing-item-wrap">

                                { ! posts && 'Loading... ' }
                                { posts && posts.length === 0 && 'No Posts' }
                                { posts && posts.length > 0 && (
                                    posts.map((post) =>
                                                        
                                    <div key={post.id} className={"fds-grid-item fds-col-" + attributes.number_of_column} style={{"paddingTop": attributes.desktopPaddingTop, "paddingRight": attributes.desktopPaddingRight, "paddingBottom": attributes.desktopPaddingBottom, "paddingLeft": attributes.desktopPaddingLeft}} >
                                        <div className="fds-restaurant-grid-wrap">
                                            { attributes.show_image === true && 
                                                <div className="fds-item-thumb">
                                                    <a href={post.link} className="fds-link fds-restaurant-grid-thumb" style = 
                                                        {{ background: "center center / cover url(" + getMediaURL(post.featured_media) + ")" }}
                                                    >
                                                    </a>
                                                    { attributes.show_favourite === true && 
                                                      <a href="#" className="fds-link fds-restaurant-grid-like"><i className="fds-icon fds-heart-line"></i></a>
                                                    }
                                                </div>
                                            }
                                            <div className="fds-restaurant-grid-text">
                                                { attributes.show_title === true && 
                                                    <h2 className="fds-ps-title fds-post-title"><a className="fds-link" href={post.link}>{post.title.rendered}</a></h2>
                                                }
                                                { attributes.show_reviews === true && 
                                                    <>
                                                    <div className="fds-rating-stars">
                                                        <span className="fds-rating-stars-fill"></span>
                                                    </div>
                                                    <small>4.5</small>
                                                    <span className="fds-restaurant-rate-count">(260 {__( 'reviews', 'wp-foodsearch' )})</span>
                                                    </>
                                                }
                                                <div className="fds-restaurant-grid-option">
                                                    <a href="#" className="fds-link fds-dessert"><i className="fds-icon fds-cutlery-line"></i> {__('dessert', 'wp-foodsearch')}</a>
                                                    { attributes.show_distance === true && 
                                                        <a href="#" className="fds-link fds-distance"><i className="fds-icon fds-pin-line"></i> 0 {__('km', 'wp-foodsearch')}</a>
                                                    }
                                                    { attributes.show_delFee === true && 
                                                        <a href="#" className="fds-link fds-delivery-fee"><i className=" fds-icon fds-dollar-coin-circle"></i>
                                                        {__('delivery fee:', 'wp-foodsearch')} $
                                                            { post.meta.delivery_fee && (
                                                                post.meta.delivery_fee
                                                            )}
                                                        </a>
                                                    }
                                                    { attributes.show_timing === true && 
                                                        <a href="#" className="fds-link fds-opening-time"><i className="fds-icon fds-clock-fast"></i> {__('opens at', 'wp-foodsearch')} 17:00</a>
                                                    }
                                                </div>
                                                <div className="fds-restaurant-grid-status">
                                                    { post.meta.restaurant_takeaway && (
                                                        <a href="#" className="fds-link fds-take-away"><i className="fds-icon fds-tick-circle-line"></i> {__('take away', 'wp-foodsearch')}</a>
                                                    )}
                                                    { post.meta.restaurant_delivery && (
                                                        <a href="#" className="fds-link fds-delivery-option"><i className=" fds-icon fds-tick-circle-line"></i> {__('delivery', 'wp-foodsearch')}</a>
                                                    )}
                                                </div>
                                                <div className="fds-restaurant-grid-food-type">
                                                    { post._embedded && post._embedded['wp:term'] && (
                                                        <span>__('type of food :', 'wp-foodsearch')</span>
                                                    )}
                                                    { post._embedded && post._embedded['wp:term'] && (
                                                        post._embedded['wp:term'][0].map((key, index) =>
                                                            <a className="fds-link" href="#">
                                                                { post._embedded['wp:term'][0][index].name }
                                                            ,</a>
                                                        )

                                                    )}
                                                </div>
                                            </div>
                                            <div className="fds-restaurant-grid-menu">
                                                <a className="fds-link" href="#">{__('min order', 'wp-foodsearch')} <strong>
                                                </strong> </a>
                                                { attributes.show_menuBTN === true && 
                                                    <a href="" className="fds-link active"><i className="fds-icon fds-menu-one"></i> {__('view menu', 'wp-foodsearch')}</a>
                                                }
                                            </div>
                                        </div>
                                    </div>

                                    )

                                ) }

                            </div>
                        </div>
                    }
                    { attributes.view_mod === "list" &&
                        <div className="fds-restaurants fds-restaurant-list">
                            <div className="fds-listing-item-wrap">
                                { ! posts && 'Loading... ' }
                                { posts && posts.length === 0 && 'No Posts' }
                                { posts && posts.length > 0 && (
                                    posts.map((post) =>

                                    <div key={post.id} className="fds-list-item fds-col-1">
                                        <div className="fds-restaurant-list-wrap">
                                            <div className="fds-item-thumb">
                                                <a className="fds-link fds-restaurant-grid-thumb" href={post.link}><img alt="" src={ getMediaURL(post.featured_media) } /></a>
                                            </div>
                                            <div className="fds-restaurant-list-text">
                                                <div className="fds-restaurant-text-main">
                                                    <div className="fds-restaurant-text-inn">
                                                        <h2 className="fds-ps-title fds-post-title"><a href={post.link}>{post.title.rendered}</a></h2>
                                                        <div className="fds-rating-stars">
                                                            <span className="fds-rating-stars-fill" style={{width: "80%"}}></span>
                                                        </div>
                                                        <small>4.5</small>
                                                        <span className="fds-restaurant-rate-count">(260 {__('reviews', 'wp-foodsearch')})</span>
                                                    </div>
                                                    <a href="#" className="fds-link fds-restaurant-grid-like"><i className="fds-icon fds-heart-line"></i></a>
                                                </div>
                                                <div className="fds-restaurant-list-option">
                                                    <a className="fds-link" href="#"><i className="fds-icon fds-cutlery-line"></i> {__('dessert', 'wp-foodsearch')}</a>
                                                    <a href="#" className="fds-link fds-distance"><i className="fds-icon fds-pin-line"></i> 0 {__('km', 'wp-foodsearch')}</a>
                                                    <a className="fds-link" href="#"><i className="fds-icon fds-dollar-coin-circle"></i> 23/ {__('person', 'wp-foodsearch')}</a>
                                                    <a className="fds-link" href="#"><i className="fds-icon fds-clock-fast"></i>
                                                        <strong>{__('now closed', 'wp-foodsearch')}</strong>
                                                    </a>
                                                </div>
                                                <div className="fds-restaurant-list-status-deliver">
                                                { post.meta.restaurant_takeaway && (
                                                        <a className="fds-link" href="#"><i className="fds-icon fds-tick-circle-line"></i> {__('take away', 'wp-foodsearch')}</a>
                                                )}
                                                { post.meta.restaurant_delivery && (
                                                        <a className="fds-link" href="#"><i className="fds-icon fds-tick-circle-line"></i> {__('delivery', 'wp-foodsearch')}</a>
                                                )}
                                                    <a className="fds-link" href="#">{__('min order', 'wp-foodsearch')} <strong>
                                                        $
                                                    </strong> </a>
                                                    <a href={post.link} className="active">{__('view menu', 'wp-foodsearch')}</a>
                                                </div>
                                                <div className="fds-restaurant-list-food-type">
                                                    { post._embedded && post._embedded['wp:term'] && (
                                                        <span>{__('type of food :', 'wp-foodsearch')}</span>
                                                    )}
                                                    { post._embedded && post._embedded['wp:term'] && (
                                                        post._embedded['wp:term'][0].map((key, index) =>
                                                            <a className="fds-link" href="#">
                                                                { post._embedded['wp:term'][0][index].name }
                                                            ,</a>
                                                        )

                                                    )}
                                                </div>
                                            </div>
                                        </div>
                                    </div>

                                    )
                                )}
                            </div>
                        </div>
                    }

                </div>
            </div>

                <Fragment>
                <BlockControls>
                    <BlockAlignmentToolbar
                        value={ postBlockWidth }
                        onChange={ postBlockWidth => setAttributes( { postBlockWidth } ) }
                        controls={ [ 'wide', 'full' ] }
                    />
                    <AlignmentToolbar
                        value={align}
                        onChange={(newval) => {
                            setAttributes({align: newval});
                        }}
                    />
                    <Toolbar label="Options">
                        <ToolbarGroup controls={ layoutControls }></ToolbarGroup>
                        <ToolbarButton icon={ formatBold } label="Bold" />
                        <ToolbarButton icon={ formatItalic } label="Italic" />
                    </Toolbar>
                </BlockControls>
                </Fragment>


                <InspectorControls>
                    <TabPanel className="tab-panel" activeClass="active-tab"
                        tabs={ [
                            { name: 'settings', title: __('settings', 'wp-foodsearch'), className: 'tab-settings', },
                            { name: 'advanced', title: __('advanced', 'wp-foodsearch'), className: 'tab-advanced', },
                        ] }
                    >
                        { ( tab ) => 
                            <>
                                { tab.name === "settings" && (
                                    <>
                                    <PanelBody title= {__('layout settings', 'wp-foodsearch')} {...posts} initialOpen={false} >
                                        <div className="rd-layout">
                                            <RadioControl label="Layout View" onChange={(newval) => setAttributes({ view_mod: newval })} selected={attributes.view_mod}
                                                options={ [
                                                    { value: 'grid' },
                                                    { value: 'list' },
                                                ] }
                                            />
                                        </div>
                                        { attributes.view_mod === "grid" &&
                                          <div className='fds-option-component'>
                                              <SelectControl label={__('number of column', 'wp-foodsearch')} onChange={ ( newval ) => setAttributes( {number_of_column:newval} ) } value={ attributes.number_of_column }
                                                  options={ [
                                                      { label: __('1 column', 'wp-foodsearch'), value: '1' },
                                                      { label: __('2 column', 'wp-foodsearch'), value: '2' },
                                                      { label: __('3 column', 'wp-foodsearch'), value: '3' },
                                                      { label: __('4 column', 'wp-foodsearch'), value: '4' },
                                                      { label: __('6 column', 'wp-foodsearch'), value: '6' },
                                                  ] }
                                              />
                                          </div>
                                        }
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('search box', 'wp-foodsearch')}
                                                checked={attributes.search_box}
                                                onChange={(newval) => setAttributes({ search_box: newval })}
                                            />
                                        </PanelRow>

                                    </PanelBody>
                                    <PanelBody title={__('sorting and filtering', 'wp-foodsearch')} {...posts} initialOpen={false} >
                                        <div className="responsive-row">
                                            <div className="fds-res-control">{__('number of items', 'wp-foodsearch')}</div>
                                            <RangeControl className="range-control" min={ 1 } max={ 50 }
                                                value={ attributes.number_of_items }
                                                onChange={ ( newval ) => setAttributes( {number_of_items:newval} ) }
                                            />
                                        </div>
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('records count', 'wp-foodsearch')}
                                                checked={attributes.records_count}
                                                onChange={(newval) => setAttributes({ records_count: newval })}
                                            />
                                        </PanelRow>

                                        <div className='fds-option-component'>
                                          <SelectControl label={__('pagination', 'wp-foodsearch')} onChange={ ( newval ) => setAttributes( {pagination:newval} ) } value={ attributes.pagination }
                                              options={ [
                                                { label: __('on scroll', 'wp-foodsearch'), value: 'on_scroll' },
                                                { label: __('load more', 'wp-foodsearch'), value: 'on_click' },
                                                { label: __('pagination numbers', 'wp-foodsearch'), value: 'numbers' },
                                                { label: __('none', 'wp-foodsearch'), value: '' },
                                              ] }
                                          />
                                      </div>
                                        <div className='fds-option-component'>
                                            <SelectControl label={__('order by', 'wp-foodsearch')} onChange={ ( newval ) => setAttributes( {order_by:newval} ) } value={ attributes.order_by }
                                                options={ [
                                                    { label: __('newest to oldest', 'wp-foodsearch'), value: 'desc' },
                                                    { label: __('oldest to newest', 'wp-foodsearch'), value: 'asc' },
                                                ] }
                                            />
                                        </div>
                                    </PanelBody>
                                    <PanelBody title={__('image', 'wp-foodsearch')} {...posts} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show image', 'wp-foodsearch')}
                                                checked={attributes.show_image}
                                                onChange={(newval) => setAttributes({ show_image: newval })}
                                            />
                                        </PanelRow>
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show favourite', 'wp-foodsearch')}
                                                checked={attributes.show_favourite}
                                                onChange={(newval) => setAttributes({ show_favourite: newval })}
                                            />
                                        </PanelRow>
                                        <Color name="backgroundColor" attr={attributes.backgroundColor} title={__('background color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-item-thumb" isbg="1" setAttributes={props.setAttributes} />
                                    </PanelBody>
            
                                    <PanelBody title={__('title', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show title', 'wp-foodsearch')}
                                                checked={attributes.show_title}
                                                onChange={(newval) => setAttributes({ show_title: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_title === true && 
                                            <>
                                            <Color name="titleColor" attr={attributes.titleColor} title={__('color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-post-title a" setAttributes={props.setAttributes} />
                                            <Color name="titleHColor" attr={attributes.titleHColor} title={__('hover color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-post-title a:hover" setAttributes={props.setAttributes} />
                                            <Typography name="titleTypo" isRes="1" attr={attributes.titleTypo} block_id={custom_block_id} class="fds-post-title a" setAttributes={props.setAttributes} />
                                            <Padding name="titlePadding" isRes="1" attr={attributes.titlePadding} block_id={custom_block_id} class="fds-post-title" setAttributes={props.setAttributes} />
                                            <Margin name="titleMargin" isRes="1" attr={attributes.titleMargin} block_id={custom_block_id} class="fds-post-title" setAttributes={props.setAttributes} />
                                            <Border name="titleBorder" isRes="1" attr={attributes.titleBorder} block_id={custom_block_id} class="fds-post-title" setAttributes={props.setAttributes} />
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('reviews', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show reviews', 'wp-foodsearch')}
                                                checked={attributes.show_reviews}
                                                onChange={(newval) => setAttributes({ show_reviews: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_reviews === true && 
                                            <>
                                            <Color name="reviewsColor" attr={attributes.reviewsColor} title={__('color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-restaurant-rate-count" setAttributes={props.setAttributes} />
                                            <Color name="reviewsHColor" attr={attributes.reviewsHColor} title={__('hover color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-restaurant-rate-count:hover" setAttributes={props.setAttributes} />
                                            <Typography name="reviewsTypo" isRes="1" attr={attributes.reviewsTypo} block_id={custom_block_id} class="fds-restaurant-rate-count" setAttributes={props.setAttributes}/>
                                            <Padding name="reviewsPadding" isRes="1" attr={attributes.reviewsPadding} block_id={custom_block_id} class="fds-restaurant-rate-count" setAttributes={props.setAttributes} />
                                            <Margin name="reviewsMargin" isRes="1" attr={attributes.reviewsMargin} block_id={custom_block_id} class="fds-restaurant-rate-count" setAttributes={props.setAttributes} />
                                            <Border name="reviewsBorder" isRes="1" attr={attributes.reviewsBorder} block_id={custom_block_id} class="fds-restaurant-rate-count" setAttributes={props.setAttributes} />
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('distance', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show distance', 'wp-foodsearch')}
                                                checked={attributes.show_distance}
                                                onChange={(newval) => setAttributes({ show_distance: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_distance === true && 
                                            <>
                                            <Color name="distanceColor" attr={attributes.distanceColor} title={__('color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-distance" setAttributes={props.setAttributes} />
                                            <Color name="distanceHColor" attr={attributes.distanceHColor} title={__('hover color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-distance:hover" setAttributes={props.setAttributes} />
                                            <Typography name="distanceTypo" isRes="1" attr={attributes.distanceTypo} block_id={custom_block_id} class="fds-distance" setAttributes={props.setAttributes}/>
                                            <Padding name="distancePadding" isRes="1" attr={attributes.distancePadding} block_id={custom_block_id} class="fds-distance" setAttributes={props.setAttributes} />
                                            <Margin name="distanceMargin" isRes="1" attr={attributes.distanceMargin} block_id={custom_block_id} class="fds-distance" setAttributes={props.setAttributes} />
                                            <Border name="distanceBorder" isRes="1" attr={attributes.distanceBorder} block_id={custom_block_id} class="fds-distance" setAttributes={props.setAttributes} />
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('delivery fee', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show delivery fee', 'wp-foodsearch')}
                                                checked={attributes.show_delFee}
                                                onChange={(newval) => setAttributes({ show_delFee: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_delFee === true && 
                                            <>
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('timing', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show timing', 'wp-foodsearch')}
                                                checked={attributes.show_timing}
                                                onChange={(newval) => setAttributes({ show_timing: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_timing === true && 
                                            <>
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('menu button', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('show menu button', 'wp-foodsearch')}
                                                checked={attributes.show_menuBTN}
                                                onChange={(newval) => setAttributes({ show_menuBTN: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.show_menuBTN === true && 
                                            <>
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('filters settings', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('filter options', 'wp-foodsearch')}
                                                checked={attributes.filter_options}
                                                onChange={(newval) => setAttributes({ filter_options: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.filter_options === true &&
                                            <>
                                            <PanelRow>
                                              <ToggleControl
                                                  label={__('counts', 'wp-foodsearch')}
                                                  checked={attributes.filter_counts}
                                                  onChange={(newval) => setAttributes({ filter_counts: newval })}
                                              />
                                            </PanelRow>
                                            <Color name="filterTitleColor" attr={attributes.filterTitleColor} title={__('title color', 'wp-foodsearch')} block_id={custom_block_id} class="plugin-filter-title" setAttributes={props.setAttributes} />
                                            <Typography name="filterTitleTypo" isRes="1" attr={attributes.filterTitleTypo} title={__('title typography', 'wp-foodsearch')} block_id={custom_block_id} class="plugin-filter-title" setAttributes={props.setAttributes} />
                                            <Color name="filterIconColor" attr={attributes.filterIconColor} title={__('icon color', 'wp-foodsearch')} block_id={custom_block_id} class="fds-filter-radio .fds-icon, .fds-filter-radio input[type=radio]:checked + *:before" setAttributes={props.setAttributes} />
                                            <Color name="filterColor" attr={attributes.filterColor} title={__('text color', 'wp-foodsearch')} block_id={custom_block_id} class="plugin-filter-wrap a, .plugin-filter-wrap label" setAttributes={props.setAttributes} />
                                            <Color name="filterHColor" attr={attributes.filterHColor} title={__('text hover color', 'wp-foodsearch')} block_id={custom_block_id} class="plugin-filter-wrap a:hover, .plugin-filter-wrap label:hover" setAttributes={props.setAttributes} />
                                            <Typography name="filterTypo" isRes="1" attr={attributes.filterTypo} block_id={custom_block_id} class="plugin-filter-wrap li, .plugin-filter-wrap li label" setAttributes={props.setAttributes} />
                                            <Border name="filterBorder" isRes="1" attr={attributes.filterBorder} block_id={custom_block_id} class="plugin-filter-wrap" setAttributes={props.setAttributes} />
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('order by', 'wp-foodsearch')}
                                                    checked={attributes.filter_by}
                                                    onChange={(newval) => setAttributes({ filter_by: newval })}
                                                />
                                            </PanelRow>
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('cuisine type', 'wp-foodsearch')}
                                                    checked={attributes.cuisine_type}
                                                    onChange={(newval) => setAttributes({ cuisine_type: newval })}
                                                />
                                            </PanelRow>
                                            <div className="responsive-row">
                                                <div className="fds-res-control">{__('see more counts', 'wp-foodsearch')}</div>
                                                <RangeControl className="range-control" min={ 2 } max={ 25 }
                                                    value={ attributes.see_more_counts }
                                                    onChange={ ( newval ) => setAttributes( {see_more_counts:newval} ) }
                                                />
                                            </div>

                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('options', 'wp-foodsearch')}
                                                    checked={attributes.options}
                                                    onChange={(newval) => setAttributes({ options: newval })}
                                                />
                                            </PanelRow>
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('rating', 'wp-foodsearch')}
                                                    checked={attributes.rating}
                                                    onChange={(newval) => setAttributes({ rating: newval })}
                                                />
                                            </PanelRow>
                                            </>
                                        }
                                    </PanelBody>
                                    <PanelBody title={__('sort by settings', 'wp-foodsearch')} initialOpen={false} >
                                        <PanelRow>
                                            <ToggleControl
                                                label={__('sort options', 'wp-foodsearch')}
                                                checked={attributes.sort_options}
                                                onChange={(newval) => setAttributes({ sort_options: newval })}
                                            />
                                        </PanelRow>
                                        { attributes.sort_options === true &&
                                            <>
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('highest rated', 'wp-foodsearch')}
                                                    checked={attributes.highest_rated}
                                                    onChange={(newval) => setAttributes({ highest_rated: newval })}
                                                />
                                            </PanelRow>
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('most reviewed', 'wp-foodsearch')}
                                                    checked={attributes.most_reviewed}
                                                    onChange={(newval) => setAttributes({ most_reviewed: newval })}
                                                />
                                            </PanelRow>
                                            <PanelRow>
                                                <CheckboxControl
                                                    label={__('grid & list', 'wp-foodsearch')}
                                                    checked={attributes.grid_list}
                                                    onChange={(newval) => setAttributes({ grid_list: newval })}
                                                />
                                            </PanelRow>
                                            </>
                                        }
                                    </PanelBody>

                                    </>
                                )}
                                { tab.name === "advanced" && (
                                    <div className="fds-tab-panel">
                                        <Background name="blockBackground" isRes="1" attr={attributes.blockBackground} block_id={custom_block_id} class="fds-typo-wrap" setAttributes={props.setAttributes} />
                                        <Padding name="blockPadding" isRes="1" attr={attributes.blockPadding} block_id={custom_block_id} class="fds-typo-wrap" setAttributes={props.setAttributes} />
                                        <Margin name="blockMargin" isRes="1" attr={attributes.blockMargin} block_id={custom_block_id} class="fds-typo-wrap" setAttributes={props.setAttributes} />
                                        <Border name="blockBorder" isRes="1" attr={attributes.blockBorder} block_id={custom_block_id} class="fds-typo-wrap" setAttributes={props.setAttributes} />
                                    </div>
                                )}
                            </>
                            
                        }
                    </TabPanel>

                </InspectorControls>

            </div>
            
        );
    },
    save: (props) => {
        return null;
    }

});