<?php
use FoodSearch\Common_Functions;
use FoodSearch\User_Locations;

require_once foodsearch_plugin_get_path() . 'admin/menu-builder.php';

class foodsearch_post_type_restaurants extends MenuBuilder {

    // The Constructor
    public function __construct() {
        // Adding columns
        add_action('init', [$this, 'foodsearch_restaurants_register'],20);
        add_action('add_meta_boxes', [$this, 'register_restaurant_meta_box']);
        add_action('add_meta_boxes', [$this, 'register_restaurant_opening_metabox']);
        add_action('add_meta_boxes', [$this, 'register_restaurant_nutritions']);
        add_action('add_meta_boxes', [$this, 'register_restaurant_menu_meta_box']);
        add_action('add_meta_boxes', [$this, 'restaurant_banner_meta_box']);
        add_action('add_meta_boxes', [$this, 'attach_author_box']);
        add_action('save_post', [$this, 'save_restaurant_meta_filed'], 10, 3);
        
        add_filter('manage_restaurants_posts_columns', array($this, 'post_columns_add'));
        add_action('manage_restaurants_posts_custom_column', array($this, 'post_columns'), 10, 2);
    }

    public function attach_author_box() {
        add_meta_box(
                'fds-attach-author', esc_html__('attached author', 'wp-foodsearch'), [$this, 'attach_author_callback'], 'restaurants', // $page
                'normal', // $context
                'low' // $priority
        );
    }
    
    public function attach_author_callback() {
        global $post;
        
        $selected_author = $post->post_author;
        
        $author_user = get_user_by('id', $selected_author);
        ?>
        <div class="fds-attached-author">
            <h3><?php esc_html_e('author info', 'wp-foodsearch'); ?></h3>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author ID', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->ID) ?></span>
            </div>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author name', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->display_name) ?></span>
            </div>
            <div class="attach-author-infoitm">
                <span><?php esc_html_e('author email', 'wp-foodsearch'); ?>:</span> &nbsp; <span><?php echo ($author_user->user_email) ?></span> <a href="<?php echo admin_url('user-edit.php?user_id=' . $author_user->ID) ?>" target="_blank"><?php esc_html_e('edit', 'wp-foodsearch'); ?></a>
            </div>
        </div>
        <br><br>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('change author', 'wp-foodsearch'); ?></label></div>
            <div class="fds-select-field">
                <select name="fds_post_selected_user" data-placeholder="<?php esc_html_e('select user', 'wp-foodsearch') ?>" class="fds-user-select2"></select>
            </div>
        </div>
        <?php
    }

    public function register_restaurant_menu_meta_box() {
        add_meta_box(
                'restaurants_menu_meta_filed', esc_html__('menu builder', 'wp-foodsearch'), [$this, 'restaurant_menu_callback'], 'restaurants', // $page
                'normal', // $context
                'high' // $priority
        );
    }

    public function restaurant_menu_callback() {
        global $post;
        $_post_id = $post->ID;
        
        $common_functions = new Common_Functions;
        
        $restaurant_user_id = Common_Functions::restaurant_user_id($_post_id);

        $get_menu_id = isset($_GET['menu_id']) ? $_GET['menu_id'] : '';
        $foodsearch_menu_builder_object = MenuBuilder::instance();
        
        wp_enqueue_style('foodsearch-icons-fds-icons');

        ob_start();
        if ($get_menu_id > 0) {
            $menu_title = $foodsearch_menu_builder_object->menu_title_by_id($get_menu_id)
            ?>
            <strong>: <?php echo ($menu_title) ?></strong> <div class="fds-btn fds-medium-btn"><a href="javascript:void(0);" class="fds-has-bg fds-link"><?php esc_html_e('go back', 'wp-foodsearch'); ?></a></div>
            <?php
        }
        $menu_title_html = ob_get_clean();
        ?>
        <div class="fds-resturant-menubildr-wrap-box" data-view="admin" data-id="<?php echo ($_post_id) ?>">
            <div class="fds-section-title-wrap" id="menuListBox">
                <h2 class="fds-heading-title"><?php echo esc_html__('menu builder', 'wp-foodsearch'); ?> <span class="fds-selected-menu-title"><?php echo ($menu_title_html) ?></span></h2>
                <i class="fds-icon fds-food-1"></i>
            </div>
            <div class="fds-menus-grid"<?php echo ($get_menu_id > 0 ? ' style="display: none;"' : '') ?>>

                <?php
                $have_menus = false;
                $menus = SELF::restaurant_menus();
                if (!empty($menus) && sizeof($menus) > 0) {
                    $have_menus = true;
                }
                
                $foodsearch_menu_builder_object->menu_grid_boxes($menus, 'admin', $_post_id);
                ?>
            </div>

            <div id="menuDetailsID"<?php echo ($get_menu_id > 0 ? '' : ' style="display: none;"') ?>>
                <?php
                if ($get_menu_id > 0) {
                    $menu_content = $foodsearch_menu_builder_object->menu_items_bywhere_id($get_menu_id, $restaurant_user_id, $_post_id);
                    echo ($menu_content);
                }
                ?>
            </div>

            <div class="fds-addmenu-mainbtnsec"<?php echo ($get_menu_id > 0 ? ' style="display: none;"' : '') ?>>
                <div id="fds-emptymenu-btnsec" class="fds-menu-builder-empty empty-menus-btncon"<?php echo ($have_menus ? ' style="display:none;"' : '') ?>>
                    <i class="fds-menu-builder-empty-icon fds-icon fds-menu-one"></i>
                    <div class="fds-menu-builder-empty-dec"><p><?php esc_html_e('you have blank food menu start adding content or select menu from templates', 'wp-foodsearch') ?></p></div>
                    <div class="fds-btn fds-medium-btn">
                        <a href="javascript:void(0);" class="fds-addmenu-inlist fds-has-bg fds-link" data-bplc="y" data-id="<?= get_the_ID(); ?>"><i class="fds-icon fds-writing"></i> <?php esc_html_e('add new menu', 'wp-foodsearch') ?></a>
                        <a href="javascript:void(0);" class="sec-color fds-has-save fds-link"><i class="fds-icon fds-writing fds-link"></i> <?php esc_html_e('import from templates', 'wp-foodsearch') ?></a>
                    </div>
                </div>
                <div id="fds-havemenu-btnsec" class="fds-menu-builder-empty have-menus-btncon"<?php echo ($have_menus ? '' : ' style="display:none;"') ?>>
                    <div class="fds-btn fds-medium-btn">
                        <a href="javascript:void(0);" class="fds-addmenu-inlist fds-has-bg fds-link" data-bplc="y" data-id="<?= get_the_ID(); ?>"><i class="fds-icon fds-writing"></i> <?php esc_html_e('add new menu', 'wp-foodsearch') ?></a>
                    </div>
                </div>
            </div>
        </div>
        <?php
        add_action('admin_footer', function() {
            ?>
            <div id="fds-menuitem-mpopup" class="fds-modal-popup fds-popup-hide fds-menuitem-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <div id="menuitms-templates-popup" class="fds-modal-popup fds-popup-hide fds-menu-templates-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }, 20);
    }

    public function restaurant_menus() {
        global $table_prefix, $wpdb, $post;
        $table_name = $table_prefix . 'menus';
        $results = $wpdb->get_results("SELECT * FROM $table_name WHERE restaurant_id = $post->ID order by id desc");
        if (empty($results)) { // Checking if $results have some values or not
            $results = array();
        }

        return $results;
    }

    public function foodsearch_restaurants_register() {

        $foodsearch__options = get_option('foodsearch_plugin_options');

        $restaurants_slug = isset($foodsearch__options['restaurants_rewrite_slug']) && $foodsearch__options['restaurants_rewrite_slug'] != '' ? $foodsearch__options['restaurants_rewrite_slug'] : 'restaurant';

        $labels = array(
            'name' => _x('Restaurants', 'restaurants post type general name', 'wp-foodsearch'),
            'singular_name' => _x('Restaurant', 'post type singular name', 'wp-foodsearch'),
            'menu_name' => _x('Restaurants', 'admin menu', 'wp-foodsearch'),
            'name_admin_bar' => _x('Restaurant', 'add new on admin bar', 'wp-foodsearch'),
            'add_new' => _x('Add new', 'restaurants', 'wp-foodsearch'),
            'add_new_item' => esc_html__('Add New Restaurant', 'wp-foodsearch'),
            'new_item' => esc_html__('New Restaurant', 'wp-foodsearch'),
            'edit_item' => esc_html__('Edit Restaurant', 'wp-foodsearch'),
            'view_item' => esc_html__('View Restaurant', 'wp-foodsearch'),
            'all_items' => esc_html__('All Restaurants ', 'wp-foodsearch'),
            'search_items' => esc_html__('Search Restaurants', 'wp-foodsearch'),
            'parent_item_colon' => esc_html__('Parent Restaurants:', 'wp-foodsearch'),
            'not_found' => esc_html__('No Restaurant Found.', 'wp-foodsearch'),
            'not_found_in_trash' => esc_html__('No Restaurant Found In Trash.', 'wp-foodsearch')
        );

        $args = array(
            'labels' => $labels,
            'description' => esc_html__('description.', 'wp-foodsearch'),
            'public' => true,
            'publicly_queryable' => true,
            'show_ui' => true,
            'show_in_menu' => true,
            'query_var' => true,
            'rewrite' => array('slug' => $restaurants_slug, 'feed' => false),
            'capability_type' => 'post',
            'has_archive' => false,
            'exclude_from_search' => false,
            'hierarchical' => false,
            'show_in_rest' => true,
            'supports' => array('title', 'slug', 'editor', 'author', 'custom-fields', 'revisions', 'thumbnail')
        );
        $args = apply_filters('foodsearch_reg_post_type_restaurants_args', $args);
        register_post_type('restaurants', $args);

        register_taxonomy('restaurant_tag', array('restaurants'), array(
            'hierarchical' => false,
            'show_ui' => true,
            'show_in_rest' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'rewrite' => array('slug' => 'restaurant_tag'),
        ));
        $ItemCatlabels = array(
            'name' => _x('Categories', 'taxonomy general name', 'wp-foodsearch'),
            'singular_name' => _x('Category', 'taxonomy singular name', 'wp-foodsearch'),
            'search_items' => esc_html__('Search Category', 'wp-foodsearch'),
            'all_items' => esc_html__('All Categories', 'wp-foodsearch'),
            'parent_item' => esc_html__('Parent Category', 'wp-foodsearch'),
            'parent_item_colon' => esc_html__('Parent Category:', 'wp-foodsearch'),
            'edit_item' => esc_html__('Edit Category', 'wp-foodsearch'),
            'update_item' => esc_html__('Update Category', 'wp-foodsearch'),
            'add_new_item' => esc_html__('Add New Category', 'wp-foodsearch'),
            'new_item_name' => esc_html__('New Category Name', 'wp-foodsearch'),
            'menu_name' => esc_html__('Food Item Categories', 'wp-foodsearch'),
        );
        register_taxonomy('food_item_cat', array('restaurants'), array(
            'labels' => $ItemCatlabels,
            'hierarchical' => true,
            'show_ui' => true,
            'show_in_rest' => true,
            'show_in_menu' => false,
            'show_in_quick_edit' => false,
            'show_admin_column' => true,
            'query_var' => true,
        ));
        $cuisine_labels = array(
            'name' => _x('Cuisines', 'taxonomy general name', 'wp-foodsearch'),
            'singular_name' => _x('Cuisine', 'taxonomy singular name', 'wp-foodsearch'),
            'search_items' => esc_html__('Search cuisine', 'wp-foodsearch'),
            'all_items' => esc_html__('All cuisines', 'wp-foodsearch'),
            'parent_item' => esc_html__('Parent cuisine', 'wp-foodsearch'),
            'parent_item_colon' => esc_html__('Parent cuisine:', 'wp-foodsearch'),
            'edit_item' => esc_html__('Edit cuisine', 'wp-foodsearch'),
            'update_item' => esc_html__('Update cuisine', 'wp-foodsearch'),
            'add_new_item' => esc_html__('Add new cuisine', 'wp-foodsearch'),
            'new_item_name' => esc_html__('New cuisine name', 'wp-foodsearch'),
            'menu_name' => esc_html__('Cuisines', 'wp-foodsearch'),
        );
        register_taxonomy('food_cuisine', array('restaurants'), array(
            'hierarchical' => true,
            'show_ui' => true,
            'labels' => $cuisine_labels,
            'show_in_rest' => true,
            'show_admin_column' => true,
            'query_var' => true,
            'show_in_menu' => true,
            'rewrite' => array('slug' => 'cuisine'),
        ));
    }

    public function register_restaurant_meta_box() {
        add_meta_box(
                'restaurants_meta_filed', esc_html__('restaurant details', 'wp-foodsearch'), [$this, 'restaurant_filed_callback'], 'restaurants', // $page
                'normal', // $context
                'high'                     // $priority
        );
    }

    public function register_restaurant_opening_metabox() {
        add_meta_box(
                'restaurants_opening_meta_filed', esc_html__('restaurant opening time', 'wp-foodsearch'), [$this, 'restaurant_opening_filed_callback'], 'restaurants', // $page
                'normal', // $context
                'high'                     // $priority
        );
    }

    public function register_restaurant_nutritions() {
        add_meta_box(
                'restaurants_nutritions_meta_filed', esc_html__('restaurant nutritions', 'wp-foodsearch'), [$this, 'restaurant_nutritions_filed_callback'], 'restaurants', // $page
                'normal', // $context
                'high'                     // $priority
        );
    }

    public function restaurant_filed_callback() {
        global $post, $foodsearch_form_fields;

        $common_functions = new Common_Functions;
        
        // Use nonce for verification to secure data sending
        wp_nonce_field(basename(__FILE__), 'wpse_our_nonce');
        
        $restaurant_contact_no = get_post_meta($post->ID, 'foodsearch_contact_number', true);
        $restaurant_email = get_post_meta($post->ID, 'foodsearch_email_address', true);
        $restaurant_take_away = get_post_meta($post->ID, 'foodsearch_take_away', true);
        $restaurant_delivery = get_post_meta($post->ID, 'foodsearch_delivery', true);
        $manager_no = get_post_meta($post->ID, 'foodsearch_manager_number', true);
        $manager_name = get_post_meta($post->ID, 'foodsearch_manager_name', true);
        $min_order = get_post_meta($post->ID, 'foodsearch_min_delivery_order', true);
        $max_order = get_post_meta($post->ID, 'foodsearch_max_delivery_order', true);
        $delivery_time = get_post_meta($post->ID, 'foodsearch_delivery_time', true);
        $delivery_fee = get_post_meta($post->ID, 'foodsearch_delivery_fee', true);
        $order_process_type = get_post_meta($post->ID, 'foodsearch_order_process_type', true);
        ?>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('restaurant contact no', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_contact_number" value="<?php echo $restaurant_contact_no ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('restaurant email address', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_email_address" value="<?php echo $restaurant_email ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('manager name', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_manager_name" value="<?php echo $manager_name ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('manager contact number', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_manager_number" value="<?php echo $manager_no ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('minimum order', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_min_delivery_order" value="<?php echo $min_order ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('maximum order', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_max_delivery_order" value="<?php echo $max_order ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('delivery time (in minutes)', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_delivery_time" value="<?php echo $delivery_time ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('delivery fee', 'wp-foodsearch'); ?></label></div>
            <!-- my custom value input -->
            <input type="text" name="fds_setting_delivery_fee" value="<?php echo $delivery_fee ?>" class="fds-input-style">
        </div>
        <div class="filed-group fds-form-field">
            <div class="label_wrap"><label class="fds-input-label"><?php echo esc_html__('order process type', 'wp-foodsearch'); ?></label></div>
            <div class="fds-select-field">
                <select name="fds_setting_order_process_type" class="select_dropdown" data-placeholder="<?php echo esc_html__('order process type', 'wp-foodsearch'); ?>">
                    <option value="both"<?php echo ($order_process_type == 'both' ? ' selected' : '') ?>><?php echo esc_html__('delivery &amp; takeaway both', 'wp-foodsearch'); ?></option>
                    <option value="delivery"<?php echo ($order_process_type == 'delivery' ? ' selected' : '') ?>><?php echo esc_html__('delivery only', 'wp-foodsearch'); ?></option>
                    <option value="takeaway"<?php echo ($order_process_type == 'takeaway' ? ' selected' : '') ?>><?php echo esc_html__('takeaway only', 'wp-foodsearch'); ?></option>
                </select>
            </div>
        </div>
        <div class="filed-group fds-form-field" style="display:none;">
            <?php
            $args = array(
                'id' => 'fds_setting_take_away',
                'name' => 'fds_setting_take_away',
                'classes' => 'fds-intig-val',
                'label' => esc_html__('pickup/take away', 'wp-foodsearch'),
                'value' => $restaurant_take_away,
            );
            $foodsearch_form_fields->switch_field($args);
            ?>
        </div>
        <div class="filed-group fds-form-field" style="display:none;">
            <?php
            $args = array(
                'id' => 'fds_setting_delivery',
                'name' => 'fds_setting_delivery',
                'classes' => 'fds-intig-val',
                'label' => esc_html__('delivery', 'wp-foodsearch'),
                'value' => $restaurant_delivery,
            );
            $foodsearch_form_fields->switch_field($args);
            ?>
        </div>
        
        <div class="filed-group">
            <?php
            $restaurant_id = $post->ID;
            $restaurant_user_id = Common_Functions::restaurant_user_id($restaurant_id);
            $user_locations = new User_Locations;
            $loc_atts = array(
                'place' => 'post_type'
            );
            $user_locations->add_locations($restaurant_user_id, $restaurant_id, $loc_atts);
            ?>
        </div>
        <?php
    }

    public function restaurant_banner_meta_box() {
        add_meta_box(
                'restaurant_banner_field', esc_html__('cover image', 'wp-foodsearch'), [$this, 'restaurant_coverimg_callback'], 'restaurants', // $page
                'side', // $context
                'high' // $priority
        );
    }
    
    public function restaurant_coverimg_callback() {
        global $post;
        $restaurant_banner = get_post_meta($post->ID, 'foodsearch_restaurant_banner', true);
        
        $img_url = wp_get_attachment_url($restaurant_banner);
        ?>
        <div class="filed-group">
            <label class="fds-input-label"><?php echo esc_html__('banner image', 'wp-foodsearch'); ?></label>
            <!-- my custom value input -->
            <div class="cover-image-upload">
                <div class="fds-imgfield-con">
                    <input type="hidden" id="fds_restaurant_coverimg" name="fds_setting_restaurant_banner" value="<?php echo ($restaurant_banner) ?>" />
                    <img src="<?php echo ($img_url) ?>" class="fds-imgpreview-withbg" alt="">
                    <div class="img-uploder-btn fds-btn fds-medium-btn">
                        <input type="button" class="fds-upload-file fds-attach-id fds-has-bg" name="fds_restaurant_coverimg" value="<?php esc_html_e('browse', 'wp-foodsearch') ?>" />
                        <input type="button"<?php echo ($img_url == '' ? ' style="display:none;"' : '') ?> class="fds-remvupload-file" value="<?php esc_html_e('remove', 'wp-foodsearch') ?>" />
                    </div>
                </div>
            </div>
        </div>
        <?php
    }
    
    public function restaurant_nutritions_filed_callback() {
        global $post;
        
        $nutritions_list = get_post_meta($post->ID, 'foodsearch_nutritions_list', true);
        ?>
        <div id="fds-restaurant-nutris-list" class="fds-multi-listcon">
            <?php
            if (!empty($nutritions_list)) {
                foreach ($nutritions_list as $nutri_key => $nutrition_itm) {
                    $nutri_title = $nutrition_itm['title'];
                    $nutri_img = $nutrition_itm['image'];
                    $image_thumb = wp_get_attachment_image_src($nutri_img, 'thumbnail');
                    $img_src = isset($image_thumb[0]) ? $image_thumb[0] : '';
                    ?>
                    <div id="nutri-item-<?php echo ($nutri_key) ?>" class="multi-list-itm">
                        <div class="itm-titl-img">
                            <div class="fds-item-thumb"><img src="<?php echo ($img_src) ?>" alt=""></div>
                            <strong class="fds-item-title"><?php echo ($nutri_title) ?></strong>
                        </div>

                        <div class="fds-menu-ations">
                            <a href="javascript:void(0);" class="fds-body-action fds-updte-nutribtn fds-link" data-id="<?php echo ($nutri_key) ?>" data-nid="0" data-rid="<?php echo ($post->ID) ?>"><i class="fds-icon fds-edit"></i></a>
                            <a href="javascript:void(0);" class="fds-body-action fds-remove-action fds-remove-nutribtn fds-link" data-id="<?php echo ($nutri_key) ?>" data-rid="<?php echo ($post->ID) ?>"><i class="fds-icon fds-time-simple"></i></a>
                        </div>
                    </div>
                    <?php
                }
            }
            ?>
        </div>
        <div class="fds-menu-builder-empty have-menus-btncon">
            <div class="fds-btn fds-medium-btn">
                <a href="javascript:void(0);" class="fds-addnutrition-inlist fds-has-bg fds-link" data-id="<?php echo ($post->ID) ?>" data-nid="0"><i class="fds-icon fds-writing"></i> <?php esc_html_e('add new item', 'wp-foodsearch') ?></a>
            </div>
        </div>
        <?php
        add_action('admin_footer', function() {
            ?>
            <div id="restaurant-nutrition-popup" class="fds-modal-popup fds-popup-hide fds-nutrition-modal">
                <div class="fds-modal-container">
                    <a href="javascript:void(0);" class="fds-popup-closebtn fds-link"><i class="fds-icon fds-time-simple"></i></a>
                    <div class="fds-modal-inner-area">
                        <div class="fds-modal-content-area">
                            <div class="fds-dynm-modal-content">
                                <div class="fds-loader-holder"><div class="fds-loader"></div></div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
            <?php
        }, 20);
    }

    public function restaurant_opening_filed_callback() {
        global $post, $foodsearch_common_functions;

        // Use nonce for verification to secure data sending
        wp_nonce_field(basename(__FILE__), 'wpse_our_nonce');

        $foodsearch_common_functions->restaurant_hours_settings($post->ID);
    }

    public function save_restaurant_meta_filed($post_id, $post) {
        if ($post->post_type != 'restaurants') {
            return false;
        }
        global $table_prefix, $wpdb;

        foreach ($_POST as $post_key => $post_value) {
            $post_value = foodsearch_esc_html($post_value);
            if (strstr($post_key, 'fds_setting_')) {
                $meta_key = str_replace('fds_setting_', 'foodsearch_', $post_key);
                update_post_meta($post_id, $meta_key, $post_value);
            }
        }
        
        $daysArray = array(
            array('day' => esc_html__('monday', 'wp-foodsearch'), 'key' => 'monday'),
            array('day' => esc_html__('tuesday', 'wp-foodsearch'), 'key' => 'tuesday'),
            array('day' => esc_html__('wednesday', 'wp-foodsearch'), 'key' => 'wednesday'),
            array('day' => esc_html__('thursday', 'wp-foodsearch'), 'key' => 'thursday'),
            array('day' => esc_html__('friday', 'wp-foodsearch'), 'key' => 'friday'),
            array('day' => esc_html__('saturday', 'wp-foodsearch'), 'key' => 'saturday'),
            array('day' => esc_html__('sunday', 'wp-foodsearch'), 'key' => 'sunday')
        );
        foreach ($daysArray as $day) {
            $opening_hour_key = 'restaurant_' . $day['key'] . '_opening_hour';
            $closing_hour_key = 'restaurant_' . $day['key'] . '_closing_hour';
            $status_key = 'restaurant_' . $day['key'] . '_status';
            
            $opening_hour = isset($_POST[$opening_hour_key]) ? $_POST[$opening_hour_key] : '';
            $closing_hour = isset($_POST[$closing_hour_key]) ? $_POST[$closing_hour_key] : '';
            $status = isset($_POST[$status_key]) ? $_POST[$status_key] : '';
            
            update_post_meta($post_id, $opening_hour_key, $opening_hour);
            update_post_meta($post_id, $closing_hour_key, $closing_hour);
            update_post_meta($post_id, $status_key, $status);
        }
        
        // attach author
        if (isset($_POST['fds_post_selected_user']) && $_POST['fds_post_selected_user'] > 0) {
            $attch_user_id = $_POST['fds_post_selected_user'];
            update_user_meta($attch_user_id, 'foodsearch_user_type', 'restaurant');
            
            $table_name = $table_prefix . 'posts';
            $data = array('post_author' => $attch_user_id);
            $where = array('id' => $post_id);
            $wpdb->update($table_name, $data, $where);
        }
    }
    
    public function post_columns_add($columns) {

        if (class_exists('w357LoginAsUser')) {
            $columns['user_loggin_as'] = esc_html__('login as user', 'wp-foodsearch');
        }

        return $columns;
    }

    public function post_columns($column, $_post_id) {
        
        $post_obj = get_post($_post_id);
        $post_author_user = isset($post_obj->post_author) ? $post_obj->post_author : '';
        switch ($column) {
            case 'user_loggin_as' :
                if (class_exists('w357LoginAsUser')) {
                    $w357LoginAsUser = new w357LoginAsUser;
                    $user_obj = get_user_by('ID', $post_author_user);
                    if (isset($user_obj->ID)) {
                        $user_id = $user_obj->ID;
                        $the_user_obj = new WP_User($user_id);
                        $login_as_user_url = $w357LoginAsUser->build_the_login_as_user_url($the_user_obj);
                        $login_as_link = '<a class="button w357-login-as-user-btn" href="' . esc_url($login_as_user_url) . '" title="'.esc_html__('login as', 'login-as-user').': ' . $w357LoginAsUser->login_as_type($the_user_obj, false) . '"><span class="dashicons dashicons-admin-users"></span> '.esc_html__('login as', 'login-as-user').': <strong>' . $w357LoginAsUser->login_as_type($the_user_obj) . '</strong></a>';
                        echo ($login_as_link);
                    }
                }
            break;
        }
    }
   
   

}

new foodsearch_post_type_restaurants();
